#ifndef _RSCMUC2K_H_
#define _RSCMUC2K_H_

#ifndef _DLL
    #define _REMVXIPNP  
#endif  

#if defined(_MSC_VER) || defined(_CVI_)
    #define _OUTSIDEVEE_
#endif

/******************************************************************************
 *
 * Copyright 2000, Rohde & Schwarz, inc.
 *
 * NAME:        RSCMUC2K.h
 *
 * PURPOSE:     This file includes a list of constants, definitions, and 
 *              prototypes used to define the Rohde & Schwarz CDMA driver
 *              for the CMU.
 *
 * DESCRIPTION: There is no executable code in this file.
 ******************************************************************************/

/* INCLUDE FILES */
#include "RSCMU200.h"

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/* PREPROCESSING DIRECTIVES */

// maximum sizes
#define MAX_PARAMETERS                    15
#define MAX_STRING_SIZE                   31
#define MAX_STATUS_STRING                 256
#define MAX_PARM_SIZE                     40
#define MAX_LIST_OPTIONS                  25

// data type constants for command table
#define INTEGER_TYPE                      0
#define FLOAT_TYPE                        1
#define STRING_30_TYPE                    2


// ********************************************************************
// command indices
// ********************************************************************

#define RSCMU_NEW       2 

// RF Generator - Frame Rate
#define RSCMU_CDMA_EIGHTH                 0
#define RSCMU_CDMA_QUARTER                1
#define RSCMU_CDMA_HALF                   2
#define RSCMU_CDMA_FULL                   3
#define RSCMU_CDMA_DEFAULT                4
#define RSCMU_CDMA_RANDOM                 5

// RF Generator - MCQuality PC Bits
#define RSCMU_BIT_AUTO                    0
#define RSCMU_BIT_HOLD                    1
#define RSCMU_BIT_ADOW                    2
#define RSCMU_BIT_AUP                     3
#define RSCMU_BIT_RTES                    4
#define RSCMU_BIT_OFF                     5              
#define RSCMU_BIT_PATT                    6              

// Power Step Direction
#define RSCMU_UP                          0
#define RSCMU_DOWN                        1

// Test Setup
#define RSCMU_CDMA_T1                     1
#define RSCMU_CDMA_T2                     2
#define RSCMU_CDMA_T3                     3
#define RSCMU_CDMA_T4                     4
#define RSCMU_CDMA_T5                     5
#define RSCMU_CDMA_DEF                    6

// Measurement Modes
#define RSCMU_ALL                         0
#define RSCMU_ARIT                        1
#define RSCMU_MIN                         2
#define RSCMU_MAX                         3

// Measurement Types
#define RSCMU_OVERVIEW                    0
#define RSCMU_PERROR                      1
#define RSCMU_MERROR                      2
#define RSCMU_EVM                         3


// Measured Values Type
#define RSCMU_SCALAR                      0
#define RSCMU_ARRAY                       1

// Network Standards
#define RSCMU_C2K_N45T                    0
#define RSCMU_C2K_USC                     1
#define RSCMU_C2K_KCEL                    2
#define RSCMU_C2K_TACS                    3
#define RSCMU_C2K_JTAC                    4
#define RSCMU_C2K_NA7C                    5
#define RSCMU_C2K_NA9C                    6
#define RSCMU_C2K_NA8S                    7
#define RSCMU_C2K_NAPC                    8
#define RSCMU_C2K_KPCS                    9
#define RSCMU_C2K_B18M                    10
#define RSCMU_C2K_IM2K                    11
#define RSCMU_C2K_PA4M                    12
#define RSCMU_C2K_PA8M                    13
#define RSCMU_C2K_USPC                    14
#define RSCMU_C2K_IEXT                    15
#define RSCMU_C2K_AWS                     16
#define RSCMU_C2K_U25B                    17
#define RSCMU_C2K_U25F                    18
//Measurement Types
#define RSCMU_OEMP_LIM_CMMAX              0
#define RSCMU_OEMP_LIM_AVER               1

// Mobile Station Identity
#define RSCMU_MS_MIN                      0
#define RSCMU_MS_IMSI                     1
#define RSCMU_MS_TMSI                     2
#define RSCMU_MS_INV                      3

//Start/Stop measurements
#define RSCMU_MEAS_OFF                    0
#define RSCMU_MEAS_RUN                    1
#define RSCMU_MEAS_STOP                   2
#define RSCMU_MEAS_ERR                    3
#define RSCMU_MEAS_STEP                   4
#define RSCMU_MEAS_RDY                    5
#define RSCMU_MEAS_NEXT                   6

// Matching      
#define RSCMU_MEAS_STATUS_PASS            0
#define RSCMU_MEAS_STATUS_INV             1
#define RSCMU_MEAS_STATUS_FAIL            2
#define RSCMU_MEAS_STATUS_TMER            3
#define RSCMU_MEAS_STATUS_IMP             4

#define RSCMU_MEAS_MATCH_OK               0
#define RSCMU_MEAS_MATCH_INV              1
#define RSCMU_MEAS_MATCH_NMAU             2
#define RSCMU_MEAS_MATCH_NMAL             3


// CMU Signalling State - Options
#define RSCMU_CDMA_STATE_SOFF             0
#define RSCMU_CDMA_STATE_SON              1
#define RSCMU_CDMA_STATE_REG              2
#define RSCMU_CDMA_STATE_ALRT             3 
#define RSCMU_CDMA_STATE_CEST             4 
#define RSCMU_CDMA_STATE_CPEN             5
#define RSCMU_CDMA_STATE_RPEN             6
#define RSCMU_CDMA_STATE_VCAL             7
#define RSCMU_CDMA_STATE_TCAL             8
#define RSCMU_CDMA_STATE_VCES             9


// CMU Signalling States - Returned
#define RSCMU_SOFF                        0
#define RSCMU_SON                         1
#define RSCMU_CTM                         2
#define RSCMU_SMS                         3
#define RSCMU_CREL                        4 
#define RSCMU_CDMA_HANDOFF                5

#define RSCMU_CDMA_PIN2                   2
#define RSCMU_CDMA_PIN3                   3
#define RSCMU_CDMA_PIN4                   4
#define RSCMU_CDMA_PIN5                   5


// Handoff Targets
#define RSCMU_HANDOFF_CDMA2KCellMS          0
#define RSCMU_HANDOFF_CDMA2KPCSMS           1
#if !defined(_RSCMUK2A_H_)  
    #define RSCMU_HANDOFF_AMPSMS             2
#endif  
#define RSCMU_HANDOFF_CDMA2KIMT2KMS          7
#define RSCMU_HANDOFF_CDMA2K450MS            8


#define RSCMU_HANDOFF_CDMA2KCellMSFallback   3
#define RSCMU_HANDOFF_CDMA2KPCSMSFallback    4

#if !defined(_RSCMUK2A_H_)  
    #define RSCMU_HANDOFF_AMPSMSFallback     5

#define RSCMU_HANDOFF_CDMA2KIMT2KMSFallback  9
#define RSCMU_HANDOFF_CDMA2K450MSFallback   10

#define RSCMU_HANDOFF_NONE                   6
#endif    

// Trigger Source 
#define RSCMU_TRIG_SOUR_INT               0
#define RSCMU_TRIG_SOUR_EXT               1
#define RSCMU_TRIG_SOUR_FRUN              2

// Modulation Mode
#define RSCMU_MODMODE_AUTO                0
#define RSCMU_MODMODE_OFF                 1
#define RSCMU_MODMODE_DEF                 2

// Mode
#define RSCMU_MODE_OFF                    0
#define RSCMU_MODE_ON                     1
#define RSCMU_MODE_DEF                    2

// Measurement Setting
#define RSCMU_MEAS_MOD_CURR               0
#define RSCMU_MEAS_MOD_AVER               1
#define RSCMU_MEAS_MOD_MIN                2 
#define RSCMU_MEAS_MOD_MAX                3

// Measurement Setting 2
#define RSCMU_MEAS_MOD2_CMM               0
#define RSCMU_MEAS_MOD2_AVER              1


// Measurement Setting 3
#define RSCMU_MEAS_MOD3_CURR              0
#define RSCMU_MEAS_MOD3_AVER              1
#define RSCMU_MEAS_MOD3_MMAX              2     


// Measurement Repetition CDMA2000
#define RSCMU_REP_CONTINUOUS              0                         
#define RSCMU_REP_SINGLESHOT              1                         
#define RSCMU_REP_DEF                     2
#define RSCMU_REP_ON                      3 

// Mode
#define RSCMU_MANUAL                      0
#define RSCMU_AUTO                        1

// Result Order
#define RSCMU_HADAMARD                    0               
#define RSCMU_BIT_REVERSE                 1

// Signal Type
#define RSCMU_ISIGNAL                     0
#define RSCMU_QSIGNAL                     1


// Reference Frequency
#define RSCMU_REF_FREQ_NCD1               0
#define RSCMU_REF_FREQ_NCD2               1
#define RSCMU_REF_FREQ_NCD3               2
#define RSCMU_REF_FREQ_NCD4               3

// Stop Condition 2
#define RSCMU_STOP2_ALEX                  0
#define RSCMU_STOP2_CLEX                  1
#define RSCMU_STOP2_FLEX                  2
#define RSCMU_STOP2_NONE                  3
#define RSCMU_STOP2_DEF                   4  

// Stop Condition 3
#define RSCMU_STOP3_NONE                  0
#define RSCMU_STOP3_SON                   1
#define RSCMU_STOP3_DEF                   2

// Step Mode
#define RSCMU_STEP_MODE_NONE              0
#define RSCMU_STEP_MODE_STEP              1
#define RSCMU_STEP_MODE_DEF               2   

// Signal Type
#define RSCMU_OQPSK                       0
#define RSCMU_HPSK                        1
#define RSCMU_QPSK                        2

// Event Reporting
#define RSCMU_EVENT_OFF                   0     
#define RSCMU_EVENT_SRQ                   1
#define RSCMU_EVENT_SOPC                  2
#define RSCMU_EVENT_SRSQ                  3
#define RSCMU_EVENT_DEF                   4    

// Service Mode
#define RSCMU_SERVICE_LOOP                0
#define RSCMU_SERVICE_SPEECH              1
#define RSCMU_SERVICE_TDAT                2
#define RSCMU_SERVICE_WMT                 3

// Local Control
#define RSCMU_LOCAL_CONTROL_NSUP          0
#define RSCMU_LOCAL_CONTROL_SUPP          1


// Paging Channel Rate
#define RSCMU_PAGING_R4K8                 0
#define RSCMU_PAGING_R9K6                 1
#define RSCMU_PAGING_DEF                  2

// Pattern Generation
#define RSCMU_PATTERN_GEN_RAND            0
#define RSCMU_PATTERN_GEN_FIX             1
#define RSCMU_PATTERN_GEN_DEF             2

// Service Option
#define RSCMU_SERV_OPT_S01D               0
#define RSCMU_SERV_OPT_S03D               1
#define RSCMU_SERV_OPT_S17D               2
#define RSCMU_SERV_OPT_S56D               3
#define RSCMU_SERV_OPT_SX8T               4
#define RSCMU_SERV_OPT_S68D               5 

// Service Option 2
#define RSCMU_SERV_OPT2_S02D              0
#define RSCMU_SERV_OPT2_S09D              1
#define RSCMU_SERV_OPT2_S30D              2
#define RSCMU_SERV_OPT2_S31D              3
#define RSCMU_SERV_OPT2_S55D              4
#define RSCMU_SERV_OPT3_S32D              5
#define RSCMU_SERV_OPT3_S33D              6

// Signalling Action 
#define RSCMU_SIG_ACT_SOFF                0
#define RSCMU_SIG_ACT_SON                 1
#define RSCMU_SIG_ACT_UNR                 2 
#define RSCMU_SIG_ACT_CTM                 3
#define RSCMU_SIG_ACT_CREL                4 
#define RSCMU_SIG_ACT_HAND                5
#define RSCMU_SIG_ACT_SMES                6


// Signalling State 
#define RSCMU_SIG_STATE_SOFF              0
#define RSCMU_SIG_STATE_SON               1
#define RSCMU_SIG_STATE_REG               2
#define RSCMU_SIG_STATE_ALER              3 
#define RSCMU_SIG_STATE_CEST              4
#define RSCMU_SIG_STATE_CPEN              5 
#define RSCMU_SIG_STATE_FPEN              6
#define RSCMU_SIG_STATE_SMES              7
#define RSCMU_SIG_STATE_PAG               8


#define RSCMU_CDP_CMAX                    0
#define RSCMU_CDP_AVER                    1

// Vocoder Setting
#define RSCMU_VOCODER_SET_ECHO            0
#define RSCMU_VOCODER_SET_V8              1
#define RSCMU_VOCODER_SET_V8E             2
#define RSCMU_VOCODER_SET_V13             3
#define RSCMU_VOCODER_SET_V8L             4
#define RSCMU_VOCODER_SET_V8EL            5
#define RSCMU_VOCODER_SET_V13L            6
#define RSCMU_VOCODER_SET_CCAL            7
#define RSCMU_VOCODER_SET_ECAL            8
#define RSCMU_VOCODER_SET_DCAL            9
#define RSCMU_VOCODER_SET_DEF             10
#define RSCMU_VOCODER_SET_ON              11
#define RSCMU_VOCODER_SET_OLOW            12

//Indicator Bits
#define RSCMU_INDICATOR_BIT_00            0
#define RSCMU_INDICATOR_BIT_11            1

//Speech Encoder/Decoder
#if defined RSCMU_GENERATOR 
    #undef RSCMU_GENERATOR
#endif  
#if defined RSCMU_ANALYSER 
    #undef RSCMU_ANALYSER
#endif  
#if defined RSCMU_HANDSET 
    #undef RSCMU_HANDSET
#endif  
#if defined RSCMU_ANALYSER2 
    #undef RSCMU_ANALYSER2
#endif  
#if defined RSCMU_BOTH_ANALYSERS 
    #undef RSCMU_BOTH_ANALYSERS
#endif  
    
#define RSCMU_GENERATOR                   0
#define RSCMU_ANALYSER                    0
#define RSCMU_HANDSET                     1
#define RSCMU_ANALYSER2                   2
#define RSCMU_BOTH_ANALYSERS              3

//Traffic Direction
#define RSCMU_FORWARD                     0
#define RSCMU_REVERSE                     1

//Access Probe
#define RSCMU_APR_ACKN                        0
#define RSCMU_APR_IGN                         1
#define RSCMU_APR_DEFAULT                     2

//ACP Selection
#define RSCMU_ACP1                      0
#define RSCMU_ACP2                      1
#define RSCMU_ACP3                      2
#define RSCMU_ACP4                      3

//Trigger Output Routing 
#define RSCMU_TRIG_NONE                 0
#define RSCMU_TRIG_PP2S                 1
#define RSCMU_TRIG_SFR                  2            
#define RSCMU_TRIG_PFR                  3        
#define RSCMU_TRIG_SNCF                 4            
#define RSCMU_TRIG_PCFR                 5            
#define RSCMU_TRIG_DEF                  6
#define RSCMU_TRIG_ETR                  7

//RX & TX Path Routing
#define RSCMU_ROUT_DEF                  0
#define RSCMU_ROUT_BYP                  1           
#define RSCMU_ROUT_BYIQ                 2           
#define RSCMU_ROUT_XOIO                 3           
#define RSCMU_ROUT_IOIO                 4           
#define RSCMU_ROUT_IOXO                 5           
#define RSCMU_ROUT_FPAT                 6           
#define RSCMU_ROUT_UDEF                 7 

//Messaging Information
#define RSCMU_LOUT_ACKN                 0
#define RSCMU_LOUT_NACK                 1      
#define RSCMU_LOUT_FAIL                 2      

//Wireless Messaging Teleservices
#define RSCMU_WMT_S06D                  0
#define RSCMU_WMT_S14D                  1
#define RSCMU_WMT_CCON                  2

#define RSCMU_WMT_HANDLE_INT            0
#define RSCMU_WMT_HANDEL_FILE           1

// Event Symbolic
#define RSCMU_CDMA2K_CFM                0
#define RSCMU_CDMA2K_RFM                1
#define RSCMU_CDMA2K_LORL               2
#define RSCMU_CDMA2K_MREG               3
#define RSCMU_CDMA2K_MINV               4
#define RSCMU_CDMA2K_AMES               5
#define RSCMU_CDMA2K_RFNS               6
#define RSCMU_CDMA2K_MDER               7
#define RSCMU_CDMA2K_RMES               8
#define RSCMU_CDMA2K_FCH                9
#define RSCMU_CDMA2K_PREP               10
#define RSCMU_CDMA2K_RFIO               11
#define RSCMU_CDMA2K_RFIU               12
#define RSCMU_CDMA2K_XTND               13

#define RSCMU_CDMA2K_PPREP              0
#define RSCMU_CDMA2K_PFBA               1
#define RSCMU_CDMA2K_PFBH               2
// Channels
#define RSCMU_CHANNEL_FPIC  0
#define RSCMU_CHANNEL_FFCH  1
#define RSCMU_CHANNEL_FSCH0 2
#define RSCMU_CHANNEL_FSCH1 3

#define RSCMU_CDMA2K_ACCEPTALL  0
#define RSCMU_CDMA2K_ACCEPTSCL1 1
#define RSCMU_CDMA2K_ACCEPTFSC1 2
#define RSCMU_CDMA2K_ACCEPTICAW 3
#define RSCMU_CDMA2K_ACCEPTICFW 4
#define RSCMU_CDMA2K_ACCEPTICOR 5
#define RSCMU_CDMA2K_ACCEPTROAW 6
#define RSCMU_CDMA2K_ACCEPTROFW 7
#define RSCMU_CDMA2K_ACCEPTROOR 8
#define RSCMU_CDMA2K_ACCEPTBUAW 9
#define RSCMU_CDMA2K_ACCEPTBUFW 10
#define RSCMU_CDMA2K_ACCEPTIGNR 11

#define RSCMU_CDMA2K_RFS_WIDE   0
#define RSCMU_CDMA2K_RFS_NARROW 1

#define RSCMU_CDMA2K_CONV   0
#define RSCMU_CDMA2K_TURBO  1

#define RSCMU_CDMA2K_AUTH_NONE  0
#define RSCMU_CDMA2K_AUTH_CHAP  1
#define RSCMU_CDMA2K_AUTH_PAP   2

#define RSCMU_CDMA2K_TPDS_UNCH  0
#define RSCMU_CDMA2K_TPDS_CHAN  1

#define RSCMU_CDMA2K_PIND_PAL   0
#define RSCMU_CDMA2K_PIND_PRES  1
#define RSCMU_CDMA2K_PIND_NNA   2

#define RSCMU_CDMA2K_IP_STAT    0
#define RSCMU_CDMA2K_IP_DYN     1

#define RSCMU_CDMA2K_SPOINT_FCH     0
#define RSCMU_CDMA2K_SPOINT_SCH0    1
#define RSCMU_CDMA2K_SPOINT_SCH1    2

#define RSCMU_CDMA2K_MIP_AUTH_R02   0
#define RSCMU_CDMA2K_MIP_AUTH_R02B  1
    
#define RSCMU_RFAN_SEL_WIDE         0
#define RSCMU_RFAN_SEL_IFL          1
    
#define RSCMU_CHPW_PRM_ATP          0
#define RSCMU_CHPW_PRM_PPOW         1
    
#define RSCMU_ESYNC_MODE_NONE       0
#define RSCMU_ESYNC_MODE_PP2S       1
#define RSCMU_ESYNC_MODE_DEF        2
    
#define RSCMU_ESYNC_STATE_INT       0
#define RSCMU_ESYNC_STATE_EXT       1
    
#define RSCMU_ENC_RATE_R9K3         0
#define RSCMU_ENC_RATE_R8K5         1
#define RSCMU_ENC_RATE_R7K5         2
#define RSCMU_ENC_RATE_R7K0         3
#define RSCMU_ENC_RATE_R6K6         4
#define RSCMU_ENC_RATE_R6K2         5
#define RSCMU_ENC_RATE_R5K8         6
#define RSCMU_ENC_RATE_R4K8         7
#define RSCMU_ENC_RATE_DEF          8
    
#define RSCMU_WMT_HANDLE_INT        0
#define RSCMU_WMT_HANDLE_FILE       1
    
/************************************************************/
/*                      DEFINES                             */
/************************************************************/

#ifndef _OUTSIDEVEE_

/*
// Logical values: 
#define RSCMU_FALSE 0
#define RSCMU_TRUE  1

// On/Off values: 
#define RSCMU_ON      1
#define RSCMU_OFF     0
#define RSCMU_VAL_ON  1
#define RSCMU_VAL_OFF 0

// None value:
#define RSCMU_NONE    0
*/

// Logical values:
#define RSCMU_FALSE (0!=0)
#define RSCMU_TRUE  (0==0)

// On/Off values:
#define RSCMU_ON      VI_ON
#define RSCMU_OFF     VI_OFF
#define RSCMU_VAL_ON  VI_ON
#define RSCMU_VAL_OFF VI_OFF

// None value:
#define RSCMU_NONE    VI_OFF


/*---------------------------------------------------------------------------*/

#define RSCMU_SECONDARY_ADDRESS_MIN  1
#define RSCMU_SECONDARY_ADDRESS_MAX 30

#define RSCMU_TMO_VALUE                     10000

/*---------------------------------------------------------------------------*/
/* File I/O buffer size:
/*---------------------------------------------------------------------------*/

#define WR_BUFFER_SIZE             512L
#define RD_BUFFER_SIZE             512L
#define RD_BUFFER_SIZE_ARRAY     32767L

// Mathematical Values
#define RSCMU_NAN                 9.91e+37
#define RSCMU_NAN_VI_INT32        0x80000000

//Function Group Names FW2.0
#define RSCMU_NOT_MAPPED         -1
#define RSCMU_BASE                0
#define RSCMU_RF_NSIG             1
#define RSCMU_GSM400MS_NSIG       2
#define RSCMU_GSM400MS_SIG        3
#define RSCMU_GSM400BS_NSIG       4
#define RSCMU_GSM400BS_SIG        5
#define RSCMU_GSM900MS_NSIG       6
#define RSCMU_GSM900MS_SIG        7
#define RSCMU_GSM900BS_NSIG       8
#define RSCMU_GSM900BS_SIG        9
#define RSCMU_GSM1800MS_NSIG      10
#define RSCMU_GSM1800MS_SIG       11
#define RSCMU_GSM1800BS_NSIG      12
#define RSCMU_GSM1800BS_SIG       13
#define RSCMU_GSM1900MS_NSIG      14
#define RSCMU_GSM1900MS_SIG       15
#define RSCMU_GSM1900BS_NSIG      16
#define RSCMU_GSM1900BS_SIG       17
#define RSCMU_IS136800MS_NSIG     18
#define RSCMU_IS136800MS_SIG      19
#define RSCMU_IS1361900MS_NSIG    20
#define RSCMU_IS1361900MS_SIG     21
#define RSCMU_AUDIO_NSIG          22
#define RSCMU_AMPSMS_NSIG         23
#define RSCMU_AMPSMS_SIG          24
#define RSCMU_CDMA800MS_NSIG      25
#define RSCMU_CDMA800MS_SIG       26
#define RSCMU_CDMA1900MS_NSIG     27
#define RSCMU_CDMA1900MS_SIG      28
#define RSCMU_BLUETOOTH_NSIG      29
#define RSCMU_BLUETOOTH_SIG       30
#define RSCMU_WCDMA1900FDDMS_NSIG 31
#define RSCMU_WCDMA1900FDDMS_SIG  32
#define RSCMU_CDMA2K450MS_NSIG    33
#define RSCMU_CDMA2K450MS_SIG     34
#define RSCMU_CDMA2KCELLMS_NSIG   35
#define RSCMU_CDMA2KCELLMS_SIG    36
#define RSCMU_CDMA2KPCSMS_NSIG    37
#define RSCMU_CDMA2KPCSMS_SIG     38
#define RSCMU_CDMA2KIMT2KMS_NSIG  39
#define RSCMU_CDMA2KIMT2KMS_SIG   40

//Units
#define RSCMU_HZ                  0
#define RSCMU_KHZ                 1
#define RSCMU_MHZ                 2
#define RSCMU_GHZ                 3
#define RSCMU_US                  0
#define RSCMU_MS                  1
#define RSCMU_S                   2

#define RSCMU_10HZ                0
#define RSCMU_20HZ                1
#define RSCMU_30HZ                2
#define RSCMU_50HZ                3
#define RSCMU_100HZ               4
#define RSCMU_200HZ               5
#define RSCMU_300HZ               6
#define RSCMU_500HZ               7
#define RSCMU_1KHZ                8
#define RSCMU_2KHZ                9
#define RSCMU_3KHZ               10
#define RSCMU_5KHZ               11 
#define RSCMU_10KHZ              12
#define RSCMU_20KHZ              13
#define RSCMU_30KHZ              14
#define RSCMU_50KHZ              15
#define RSCMU_100KHZ             16
#define RSCMU_200KHZ             17
#define RSCMU_300KHZ             18
#define RSCMU_500KHZ             19
#define RSCMU_1MHZ               20
#define RSCMU_WIDE               21    
#define RSCMU_FREQ_AUTO          21

//SCPI Connection
#define RSCMU_GPIB                0
#define RSCMU_COM                 1
#define RSCMU_COM1                1
#define RSCMU_COM2                2

//Parity
#define RSCMU_PARITY_NONE         0
#define RSCMU_PARITY_ODD          1
#define RSCMU_PARITY_EVEN         2
 
//Protocol
#define RSCMU_PROTOCOL_NONE       0
#define RSCMU_PROTOCOL_XON        1
#define RSCMU_PROTOCOL_ACK        2

// Status byte  
#define RSCMU_STB_OFF             0
#define RSCMU_STB_ON              1

//Query
#define RSCMU_DO_QUERY            1
#define RSCMU_SKIP_QUERY          0

//Reset
#define RSCMU_RESET_ON            1
#define RSCMU_RESET_OFF           0

//Reference Frequency
#define RSCMU_INTERNAL            0
#define RSCMU_EXTERNAL            1
#define RSCMU_REF_FRQ_MIN         1.2190
#define RSCMU_REF_FRQ_MAX         39.0

//Attenuation
#define RSCMU_NORM                0
#define RSCMU_LNO                 1
#define RSCMU_LDIS                2
#define RSCMU_LOW_NOISE           1
#define RSCMU_LOW_DIST            2

//Trigger Condition
#define RSCMU_IMM                 0
#define RSCMU_SIGN                0
#define RSCMU_RFP                 1
#define RSCMU_IFP                 2
#define RSCMU_EXT                 3
#define RSCMU_FRUN                3

//Trigger Condition
#define RSCMU_LOW                 0
#define RSCMU_MED                 1
#define RSCMU_HIGH                2

//Measurement Repetition
#define RSCMU_STOP_ON             1
#define RSCMU_STOP_ALIM           1
#define RSCMU_STOP_FLIM           2
#define RSCMU_STEP                1
#define RSCMU_STEP_ON             1
#define RSCMU_ON_LIMIT_FAILURE    1

//Measurement Repetition FW 2.0
#define RSCMU_CONTINUOUS          0
#define RSCMU_SINGLE_SHOT         1
#define RSCMU_MULTIPLE            2

// TimeOuts
#define RSCMU_SENS_TRIG_MEAS_TMO_MIN    1.0
#define RSCMU_SENS_TRIG_MEAS_TMO_MAX    1000.0

/*===========================================================================*/
/*                          Measurement Control                              */
/*===========================================================================*/


// Generator Status
#define RSCMU_GEN_STAT_OFF        0
#define RSCMU_GEN_STAT_RUN        1
#define RSCMU_GEN_STAT_ERR        2

// Measurement Status
#define RSCMU_MEAS_STAT_OFF       0
#define RSCMU_MEAS_STAT_RUN       1
#define RSCMU_MEAS_STAT_STOP      2
#define RSCMU_MEAS_STAT_ERR       3
#define RSCMU_MEAS_STAT_STEP      4
#define RSCMU_MEAS_STAT_RDY       5

// Sensitivity Measurement Status
#define RSCMU_MEAS_STAT_PASS      0
#define RSCMU_MEAS_STAT_INV       1
#define RSCMU_MEAS_STAT_FAIL      2
#define RSCMU_MEAS_STAT_TMER      3
#define RSCMU_MEAS_STAT_IMP       4

/*===========================================================================*/
/*                                                                           */
/*===========================================================================*/


//Frequency Bandwidth
#define RSCMU_BAND_RESTRICT       0
#define RSCMU_BAND_WIDE           1
#define RSCMU_BANDWIDTH_30KHZ     1
#define RSCMU_BANDWIDTH_300KHZ    2

// Generator Modulation
#define RSCMU_SSB                 1

//Input connectors
#define RSCMU_INPUT_RF1           0
#define RSCMU_INPUT_RF2           1
#define RSCMU_INPUT_RF4           2

//Output Connectors
#define RSCMU_OUTPUT_RF1          0
#define RSCMU_OUTPUT_RF2          1
#define RSCMU_OUTPUT_RF3          2

// Audio input signal
#define RSCMU_AFAN_AFIN           0
#define RSCMU_AFAN_AUX1           1

// Audio path coupling
#define RSCMU_AFAN_AC             0
#define RSCMU_AFAN_DC             1

// Speech Encoder Input
#define RSCMU_SPEN_HAND           0
#define RSCMU_SPEN_GEN            1
#define RSCMU_SPEN_AUX1           2

// Speech Decoder Output
#define RSCMU_SPD_HAND            0
#define RSCMU_SPD_ANAL            1
#define RSCMU_SPD_AUX2            2

// Limit Check
#define RSCMU_OK                  0
#define RSCMU_INV                 1
#define RSCMU_NMAU                2
#define RSCMU_NMAL                3

#define RSCMU_MATCH_MATC          0
#define RSCMU_MATCH_INV           1 
#define RSCMU_MATCH_NMAT          2
#define RSCMU_MATCH_NTSC          3
#define RSCMU_MATCH_OUT           4
#define RSCMU_MATCH_NTR           5
#define RSCMU_MATCH_BNF           6
#define RSCMU_MATCH_OFF           7

// IS-95

#define RSCMU_PCL                 2
#define RSCMU_ALWAYS              0

#define RSCMU_CURRENT             0
#define RSCMU_AVERAGE             1
#define RSCMU_MAXMIN              2
#define RSCMU_MAXIMUM             2
#define RSCMU_MINIMUM             3
#define RSCMU_AVERAGED            1 // Do not remove it due to keep the compatibility

//Serial interface
#define RSCMU_APPL_TRAN           0 
#define RSCMU_APPL_REM            1 
#define RSCMU_APPL_PRIN           2 

//Input/output attenuation
#define RSCMU_ATT_MIN             -50
#define RSCMU_ATT_MAX             +50

//Multiple Measurement
#define RSCMU_MULT_MEAS_MIN        1
#define RSCMU_MULT_MEAS_MAX        10000

//Frequency offset
#define RSCMU_FREQ_OFFSET_MIN     -135000
#define RSCMU_FREQ_OFFSET_MAX     +135000

//Power Level Range
#define RSCMU_LEV_RANGE_MIN            10
#define RSCMU_LEV_RANGE_MAX           100

//Test Points Number
#define RSCMU_TEST_PTS_MIN              1
#define RSCMU_TEST_PTS_MAX            560

#define RSCMU_REG_MAX               32767
#define RSCMU_SUB_REG_MAX              15
#define RSCMU_ADDR_PRIM_MAX            30
#define RSCMU_ADDR_SEC_MAX             30  

#define RSCMU_DATABITS_MIN              7
#define RSCMU_DATABITS_MAX              8
#define RSCMU_STOPBITS_MIN              1
#define RSCMU_STOPBITS_MAX              2

#define RSCMU_SUM1                      1
#define RSCMU_SUM2                      2

//Keyboard Assignment
#define RSCMU_KBUS                  0
#define RSCMU_KBGR                  1

//positive / negative
#define RSCMU_POS                 1
#define RSCMU_NEG                 0

// Frequency hopping
#define RSCMU_REL                 0
#define RSCMU_ABS                 1

#endif // end of rscmu200 defines for VEE

/*****************************************************************************/
/*= Define Instrument Specific Error/Warning Codes Here =====================*/
/*****************************************************************************/
/*---------------------------------------------------------------------------*/
/* The codes for instrument specific ERRORS must be in the range             */
/* 0xBFFC0900 to 0xBFFC0FFF and defined as follows:                          */
/* #define PREFIX_SPECIFIC_ERROR (VI_INSTR_ERROR_OFFSET + n)                 */
/*                                                                           */
/* The codes for instrument specific WARNINGS must be in the range           */
/* 0x3FFC0900 to 0x3FFC0FFF and defined as follows:                          */
/* #define PREFIX_SPECIFIC_WARNING (VI_INSTR_WARNINGS_OFFSET + n)            */
/*                                                                           */
/* Where n represents each instrument specific error/warning number.         */
/* The valid range for n is 0x000 to 0x1FF  for CMU Base                     */
/* The valid range for n is 0x200 to 0x2FF  for K2G Option                   */
/* For ease of use the lower 16 bits of warnings and errors should not       */
/* overlap in the same driver.                                               */
/*                                                                           */
/*---------------------------------------------------------------------------*/

#ifdef _OUTSIDEVEE_ 

#if !defined(__K2G_HEADER )

#define RSCMU_LIST_OF_SPECIFIC_ERROR_MESSAGES_CDMA \
CDMA_EXPAND(RSCMU_ERROR_CALL_FROM_MS_FAILED,      (VI_INSTR_ERROR_OFFSET + 0x300L), "Call from mobile station failed") \
CDMA_EXPAND(RSCMU_ERROR_CALL_TO_MS_FAILED,        (VI_INSTR_ERROR_OFFSET + 0x301L), "Call to mobile station failed") \
CDMA_EXPAND(RSCMU_ERROR_RELEASE_TO_MS_FAILED,     (VI_INSTR_ERROR_OFFSET + 0x302L), "Release to mobile station failed") \
CDMA_EXPAND(RSCMU_ERROR_INVALID_SIGN_STAT,        (VI_INSTR_ERROR_OFFSET + 0x303L), "The RSCMU is in an internal signalling state where the command is not allowed") \
CDMA_EXPAND(RSCMU_ERROR_INVALID_HANDOVER_TARGET,  (VI_INSTR_ERROR_OFFSET + 0x304L), "The handover target is not available") \
CDMA_EXPAND(RSCMU_ERROR_CALL_DROP,                (VI_INSTR_ERROR_OFFSET + 0x305L), "Call drop during a call")\
CDMA_EXPAND(RSCMU_WARNING_GPIB_FEATURE,         (VI_INSTR_WARNING_OFFSET + 0x301L), "GPIB Feature not implemanted")

typedef enum {
#define CDMA_EXPAND(id, value, text) id = value,
    RSCMU_LIST_OF_SPECIFIC_ERROR_MESSAGES_CDMA
#undef CDMA_EXPAND
} RSCMU_ErrorList_CDMA;

#endif

// ********************************************************************
// structures for command table definitions
// ********************************************************************

//This is necessary to run AMPS and CDMA2K together

#if !defined (_RSCMUK2A_H_) //JMG 030104 || defined (_REMVXIPNP)

typedef struct listNode {
    ViInt16        num;
    const ViChar *list[MAX_LIST_OPTIONS];
} LIST, *LISTPTR;

typedef struct {
    ViInt32         type;
    ViInt32         min;
    ViInt32         max;
    LISTPTR         params;
} INT_PARAM_INFO;

typedef struct {
    ViInt32         type;
    ViReal64        min;
    ViReal64        max;
    LISTPTR         params;
} FLOAT_PARAM_INFO;

typedef struct {
    ViInt32         type;
    ViUInt8        *min;       // Placeholder ONLY
    ViUInt8        *max;       // Placeholder ONLY
    LISTPTR         params;
} STRING30_PARAM_INFO;

typedef union {
    INT_PARAM_INFO      i;
    FLOAT_PARAM_INFO    f;
    STRING30_PARAM_INFO s30;
} PARAM_INFO_UNION;

typedef struct {
    ViInt32             num;
    STRING30_PARAM_INFO p[MAX_PARAMETERS];
} STRING_PARAM_BLOCK;

typedef struct {
    ViInt32          num;
    PARAM_INFO_UNION p[MAX_PARAMETERS];
} PARAM_BLOCK;

typedef struct {
    const char    *instrCommand;    // ASCII instrument command
    const char    *instrResponse;   // format for response message
    void           (*transmit)();   // transmit routine
    void           (*response)();   // response routine
    PARAM_BLOCK   *xmit;            // pointer to transmit parameter block
    PARAM_BLOCK   *rcvr;            // pointer to receive parameter block
} COMMAND_INFO;


#endif // _RSCMUK2A_H_


#if 0
typedef struct {
   ViReal64 Current;
   ViReal64 Average;
   ViReal64 MaxMin;
} ERROR_LIMITS;

typedef struct {
   ERROR_LIMITS Peak;
   ERROR_LIMITS RMS;
   ERROR_LIMITS CarrierFeedthrough;
   ERROR_LIMITS IQImbalance;
   ERROR_LIMITS FreqErr;
   ERROR_LIMITS TransmitTimeError
   ERROR_LIMITS WaveformQuality;
   ERROR_LIMITS MSPower;
   ViInt32      MeasCount;
   ViReal64     MeasOutOfTolerance;
} ERROR_MOD;

typedef struct {
   ERROR_LIMITS EVMPeak;
   ERROR_LIMITS EVMRMS;
   ERROR_LIMITS MErrPeak;
   ERROR_LIMITS MErrRMS;
   ERROR_LIMITS PErrPeak;
   ERROR_LIMITS PErrRMS;
   ERROR_LIMITS CarrierFeedthrough;
   ERROR_LIMITS IQImbalance;
   ERROR_LIMITS FreqErr;
   ERROR_LIMITS TransmitTimeError;
   ERROR_LIMITS WaveformQuality;
   ERROR_LIMITS MSPower;
   ViInt32      MeasCount;
   ViReal64     MeasOutOfTolerance;
} OVERVIEW;

typedef struct {                
   ERROR_LIMITS expectedMSPower;
   ERROR_LIMITS measuredMSPower;
   ERROR_LIMITS carrierFreqError;
   ERROR_LIMITS expectedCarrierFreq;
   ERROR_LIMITS transmitTimeErr;
   ERROR_LIMITS waveformQuality;
   ERROR_LIMITS sidebandSuppressionLowerACP1;
   ERROR_LIMITS sidebandSuppressionUpperACP1;
   ERROR_LIMITS sidebandSuppressionLowerACP2;
   ERROR_LIMITS sidebandSuppressionUpperACP2;
   ERROR_LIMITS sidebandSuppressionLowerACP3;
   ERROR_LIMITS sidebandSuppressionUpperACP3;
   ERROR_LIMITS sidebandSuppressionLowerACP4;
   ERROR_LIMITS sidebandSuppressionUpperACP4;   
   ViReal64     sidebandSuppression;
} OVERVIEW_C2K;    

typedef struct {                
   ERROR_LIMITS msPower;
   ERROR_LIMITS WaveFormQuality;
   ERROR_LIMITS CarrierFrequencyError;
   ERROR_LIMITS TransmitTimeError;
   ERROR_LIMITS CarrierFeedThrough;
   //Reverse one variable here
   ERROR_LIMITS SideBandSuppresLower;
   ERROR_LIMITS SideBandSuppresUpper;
   ERROR_LIMITS sidebandSuppressionLowerACP2;
   ERROR_LIMITS sidebandSuppressionUpperACP2;
   ERROR_LIMITS sidebandSuppressionLowerACP3;
   ERROR_LIMITS sidebandSuppressionUpperACP3;
   ERROR_LIMITS sidebandSuppressionLowerACP4;
   ERROR_LIMITS sidebandSuppressionUpperACP4;     
   ERROR_LIMITS MeasOutOfTolerance;
} ModQualOver;

typedef struct{
   ERROR_LIMITS msPower;
   ERROR_LIMITS CarrierFeedthrough;
   ERROR_LIMITS FrequencyError;
   ERROR_LIMITS rho;
   ViReal64     OutOfTolernace;
   ViInt32      CurrentStatistics;
} CODE_DOMAIN_POWER;

typedef struct{
  ViReal64  FER;
  ViInt32 FrameError;
  ViInt32 TransmitFrame;
  ViReal64 ConfidenceLevel;
  ViReal64 AdjustLevel;
  ViReal64 FwdChLevel;
  ViReal64 CurrentSetPoint;
  ViReal64 BSCalEbNt;
} FOWARD_POWER_CONTROL;

#else
typedef struct 
{
   ViReal64 Current;
   ViReal64 Average;
   ViReal64 MaxMin;
} ERROR_LIMITS;

typedef struct 
{
   ERROR_LIMITS Peak;
   ERROR_LIMITS RMS;
   ERROR_LIMITS CarrierFeedthrough;
   ERROR_LIMITS IQImbalance;
   ERROR_LIMITS FreqErr;
   ERROR_LIMITS TransmitTimeError;
   ERROR_LIMITS WaveformQuality;
   ERROR_LIMITS MSPower;
   long         MeasCount;
   ViReal64       MeasOutOfTolerance;
} ERROR_MOD; 

typedef struct 
{
   ERROR_LIMITS EVMPeak;
   ERROR_LIMITS EVMRMS;
   ERROR_LIMITS MErrPeak;
   ERROR_LIMITS MErrRMS;
   ERROR_LIMITS PErrPeak;
   ERROR_LIMITS PErrRMS;
   ERROR_LIMITS CarrierFeedthrough;
   ERROR_LIMITS IQImbalance;
   ERROR_LIMITS FreqErr;    
   ERROR_LIMITS TransmitTimeError;
   ERROR_LIMITS WaveformQuality;
   ERROR_LIMITS MSPower;
   long         MeasCount;
   ViReal64       MeasOutOfTolerance;
   } OVERVIEW;    

typedef struct 
{
   ERROR_LIMITS expectedMSPower;
   ERROR_LIMITS measuredMSPower;
   ERROR_LIMITS carrierFreqError;
   ERROR_LIMITS expectedCarrierFreq;
   ERROR_LIMITS transmitTimeErr;
   ERROR_LIMITS waveformQuality;
   ERROR_LIMITS sidebandSuppressionLower;  // JMG 020923 Keep Compatibility with the old FW
   ERROR_LIMITS sidebandSuppressionUpper;
   ERROR_LIMITS sidebandSuppressionLower2; //JMG 020916
   ERROR_LIMITS sidebandSuppressionUpper2; //JMG 020916
   ERROR_LIMITS sidebandSuppressionLower3; //JMG 020916
   ERROR_LIMITS sidebandSuppressionUpper3; //JMG 020916
   ERROR_LIMITS sidebandSuppressionLower4; //JMG 020916
   ERROR_LIMITS sidebandSuppressionUpper4; //JMG 020916
   ViReal64     sidebandSuppression;
} OVERVIEW_C2K;  
/*
typedef struct
{
   ERROR_LIMITS expectedMSPower;
   ERROR_LIMITS measuredMSPower;
   ERROR_LIMITS carrierFreqError;
   ERROR_LIMITS expectedCarrierFreq;
   ERROR_LIMITS transmitTimeErr;
   ERROR_LIMITS waveformQuality;
   ERROR_LIMITS sidebandSuppressionLowerACP1;
   ERROR_LIMITS sidebandSuppressionUpperACP1;
   ERROR_LIMITS sidebandSuppressionLowerACP2;
   ERROR_LIMITS sidebandSuppressionUpperACP2;
   ERROR_LIMITS sidebandSuppressionLowerACP3;
   ERROR_LIMITS sidebandSuppressionUpperACP3;
   ERROR_LIMITS sidebandSuppressionLowerACP4;
   ERROR_LIMITS sidebandSuppressionUpperACP4;
   ViReal64     sidebandSuppression;
} OVERVIEW_C2K;    */

typedef struct 
{
   ERROR_LIMITS msPower;
   ERROR_LIMITS WaveFormQuality;
   ERROR_LIMITS CarrierFrequencyError;
   ERROR_LIMITS TransmitTimeError;
   ERROR_LIMITS CarrierFeedThrough;
   //Reverse one variable here
   ERROR_LIMITS SideBandSuppresLower;
   ERROR_LIMITS SideBandSuppresUpper;
   ERROR_LIMITS sidebandSuppressionLowerACP2;
   ERROR_LIMITS sidebandSuppressionUpperACP2;
   ERROR_LIMITS sidebandSuppressionLowerACP3;
   ERROR_LIMITS sidebandSuppressionUpperACP3;
   ERROR_LIMITS sidebandSuppressionLowerACP4;
   ERROR_LIMITS sidebandSuppressionUpperACP4;     
   //ERROR_LIMITS MeasOutOfTolerance;  
   ViReal64 MeasOutOfTolerance;
} ModQualOver; 

typedef struct{
   ERROR_LIMITS msPower;
   ERROR_LIMITS CarrierFeedthrough;
   ERROR_LIMITS FrequencyError;
   ERROR_LIMITS rho;
   ViReal64       OutOfTolerance;
   long         CurrentStatistics;
} CODE_DOMAIN_POWER;

typedef struct
{
  ViReal64  FER;
  ViInt32   FrameError;
  ViInt32   TransmitFrame;
  ViReal64  ConfidenceLevel;
  ViReal64  AdjustLevel;
  ViReal64  FwdChLevel;
  ViReal64  CurrentSetPoint;
  ViReal64  BSCalEbNt;
} FORWARD_POWER_CONTROL;


typedef struct
{
  ViReal64              actualOutputPower;
  FORWARD_POWER_CONTROL FCH;
  FORWARD_POWER_CONTROL DCCH;
  FORWARD_POWER_CONTROL SCH0;
  FORWARD_POWER_CONTROL SCH1;
} tFPC;

#endif

#endif // _OUTSIDEVEE_ 


/* GLOBAL PROCEDURES PROVIDED */  

ViStatus _VI_FUNC RSCMU_Init_CDMA2K (ViSession instrSessionBase,
                                     ViPSession instrSessionCDMA,
                                     ViInt32 CDMA2KFunctionGroup,
                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNstandard (ViSession instrSession,
                                              ViInt32 CDMA2KStandard,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_InpState (ViSession instrSession,
                                         ViInt32 selection_ofInputConnector,
                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_OutpState (ViSession instrSession,
                                          ViInt32 selection_ofOutputConnector,
                                          ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SenseCorrLossInp (ViSession instrSession,
                                                 ViInt32 selection_ofInputConnector,
                                                 ViReal64 externalAttenuation_dB,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SourceCorrLossOutp (ViSession instrSession,
                                                   ViInt32 selection_ofOutputConnector,
                                                   ViReal64 externalAttenuation_dB,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CorrLossInpOutp (ViSession instrSession,
                                                ViInt32 selection_ofOutputConnector,
                                                ViReal64 outputAttenuation_dB,
                                                ViInt32 selection_ofInputConnector,
                                                ViReal64 inputAttenuation_dB,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_RoutSpenInp (ViSession instrSession,
                                            ViInt32 speechEncoder,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_RoutSpdOutp (ViSession instrSession,
                                            ViInt32 speechDecoder,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfIQIFRxTxPath (ViSession instrSession,
                                                 ViInt32 routingPathForRXTXPath,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfIQIFRxPath (ViSession instrSession,
                                               ViInt32 routingPathForRXPath,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfIQIFTxPath (ViSession instrSession,
                                               ViInt32 routingPathForTXPath,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SensIQIFIfl (ViSession instrSession,
                                            ViPReal64 IFLevel,
                                            ViChar _VI_FAR errorMessage[]);

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfFreqCoupRxTx (ViSession instrSession,
                                                 ViInt32 frequencyCoupling,
                                                 ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_CDMA2K_SenseRfanSel (ViSession instrSession,
                                             ViInt32 selectivity,
                                             ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfLsm (ViSession instrumentHandle,
                                             ViBoolean mode, ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_CDMA2K_SystMiscB83T (ViSession instrumentHandle,
                                             ViBoolean phase_relationship,
                                             ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_CDMA2K_SourceDmClockState (ViSession instrSession,
                                                   ViBoolean referenceFreq_atREFOUT2,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SourceDmClockFreq (ViSession instrSession,
                                                  ViInt32 referenceFrequency,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SenseLevMode (ViSession instrSession,
                                             ViInt32 inputLevelSetting,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SenseLevMax (ViSession instrSession,
                                            ViReal64 inputLevelMaximum_dBm,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SenseLevModeMax (ViSession instrSession,
                                                ViReal64 inputLevelMaximum_dBm,
                                                ViInt32 setRFAnalMode,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SenseRfanChan (ViSession instrSession,
                                              ViInt32 channel,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SenseRfanFreq (ViSession instrSession,
                                              ViReal64 frequency_MHz,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SenseRfanFOffset (ViSession instrSession,
                                                 ViReal64 freqOffset,
                                                 ViBoolean enable,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_DefRfAnalyzer (ViSession instrSession,
                                              ViInt32 RFAnalyzerState,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_TrigSeqSourOQPSK (ViSession instrSession,
                                                 ViInt32 triggerSource,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_TrigSeqSourHPSK (ViSession instrSession,
                                                ViInt32 triggerSource,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_TrigSeqSourQPSK (ViSession instrSession,
                                                ViInt32 triggerSource,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_TrigOutpPinSignal (ViSession instrSession,
                                                  ViInt32 pin,
                                                  ViInt32 triggerOutputRouting,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_TrigSour (ViSession instrSession,
                                         ViInt32 triggerSource,
                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_TrigSlop (ViSession instrSession, ViInt32 slope,
                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_TrigThrRfp (ViSession instrSession,
                                           ViInt32 threshold,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_TrigThrIfp (ViSession instrSession,
                                           ViReal64 threshold,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_DefTrigSource (ViSession instrSession,
                                              ViInt32 triggerSourceState,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_DefTrigSet (ViSession instrSession,
                                           ViInt32 defaultAllTriggerSet,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_DefRfGenerator (ViSession instrSession,
                                               ViInt32 RFGeneratorState,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SourRfGenRfFrequency (ViSession instrSession,
                                                     ViReal64 frequency_MHz,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SourRfGenRfChannel (ViSession instrSession,
                                                   ViInt32 channel,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SourRfGenRfPowCDMA (ViSession instrSession,
                                                   ViReal64 CDMAPower_dBm,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SourRfGenRfPowOut (ViSession instrSession,
                                                  ViPReal64 outputPower_dB,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SourRfGenModMode (ViSession instrSession,
                                                 ViInt32 modulationMode,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SourRfGenFFCHLev (ViSession instrSession,
                                                 ViReal64 FFCHLevel,
                                                 ViBoolean enable,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SourRfGenFFCHCh (ViSession instrSession,
                                                ViInt32 FFCHChannel,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SourRfGenFFCHFrameOffset (ViSession instrSession,
                                                         ViInt32 FFCHFrameOffset,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SourRfGenFFCHFrameRate (ViSession instrSession,
                                                       ViInt32 frameRate,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SourRFGenFSyncLev (ViSession instrSession,
                                                  ViReal64 syncLevel,
                                                  ViBoolean enable,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SourRFGenFPilotChLev (ViSession instrSession,
                                                     ViReal64 pilotLevel,
                                                     ViBoolean enable,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SourRFGenFPagingChLev (ViSession instrSession,
                                                      ViReal64 pagingLevel,
                                                      ViBoolean enable,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SourRfGenProPNOffset (ViSession instrSession,
                                                     ViInt32 PNOffset,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SourRfGenRfLevOCNSEnable (ViSession instrSession,
                                                         ViInt32 OCNSEnable,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SourRfGenRfLevOCNSValue (ViSession instrSession,
                                                        ViPReal64 OCNSValue,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SourImpairRfLevAWGN (ViSession instrSession,
                                                    ViReal64 AWGNLevel,
                                                    ViBoolean enable,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SourImpairRfFreqOffset (ViSession instrSession,
                                                       ViReal64 freqOffset,
                                                       ViBoolean enable,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SourRfGenRc (ViSession instrSession,
                                            ViInt32 radioConfiguration,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SourRfGenRset (ViSession instrSession,
                                              ViPReal64 rateSet,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SourRfGenSid (ViSession instrSession,
                                             ViInt32 SID,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SourRfGenPrev (ViSession instrSession,
                                              ViInt32 protocolRevision,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SourRfGenMprev (ViSession instrSession,
                                               ViInt32 minimumProtocolRevision,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SourRfGenNid (ViSession instrSession,
                                             ViInt32 NID,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SourRfGenPchRate (ViSession instrSession,
                                                 ViInt32 pagingChannelRate,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SourRfGenEsn (ViSession instrSession,
                                             ViString ESN,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SourRfGenZlcm (ViSession instrSession,
                                              ViBoolean zeroLongCodeMask,
                                              ViChar _VI_FAR errorMessage[]);

ViStatus _VI_FUNC RSCMU_CDMA2K_InitRfGenerator (ViSession instrSession,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_AbortRfGenerator (ViSession instrSession,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchRfGeneratorStatus (ViSession instrSession,
                                                       ViPInt32 generatorStatus,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModMQualPCBits (ViSession instrSession,
                                                   ViInt32 powerControlBits,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_DefModMQualCont (ViSession instrSession,
                                                ViInt32 limitDefaultAllSettings,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_DefModMQualAllLim (ViSession instrSession,
                                                  ViInt32 limitDefaultAllSettings,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModMQualCont (ViSession instrSession,
                                                 ViInt32 statistics,
                                                 ViInt32 repetition,
                                                 ViInt32 stopCondition,
                                                 ViInt32 stepMode,
                                                 ViInt32 signalType,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModMQualContRep (ViSession instrSession,
                                                    ViInt32 repetition,
                                                    ViInt32 stopCondition,
                                                    ViInt32 stepMode,
                                                    ViInt32 signalType,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModMQualContStats (ViSession instrSession,
                                                      ViInt32 statistics,
                                                      ViInt32 signalType,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModMQualContSBdFOffs (ViSession instrSession,
                                                         ViReal64 sideBandOffset_Hz,
                                                         ViInt32 signalType,
                                                         ViBoolean enable,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_XtndModMQualSBS (ViSession instrSession,
                                                ViInt32 signalType,
                                                ViInt32 SBSuppressionExtensionMode,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModMQualExtFOffSBS (ViSession instrSession,
                                                       ViInt32 signalType,
                                                       ViInt32 ACPFreqOffset1,
                                                       ViBoolean enable1,
                                                       ViInt32 ACPFreqOffset2,
                                                       ViBoolean enable2,
                                                       ViInt32 ACPFreqOffset3,
                                                       ViBoolean enable3,
                                                       ViInt32 ACPFreqOffset4,
                                                       ViBoolean enable4,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_DefModMQualControl (ViSession instrSession,
                                                   ViInt32 limitDefaultAllSettings,
                                                   ViInt32 signalType,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModMQualLim (ViSession instrSession,
                                                ViReal64 limitWaveFormQuality,
                                                ViBoolean WFEnable,
                                                ViInt32 carrierFreqLimit,
                                                ViBoolean CFEnable,
                                                ViReal64 transmitTimeErrorLimit_us,
                                                ViBoolean TTEnable,
                                                ViInt32 limitCarrierFeedThrough,
                                                ViBoolean CFTEnable,
                                                ViInt32 reverse,
                                                ViInt32 sidebandSupprLimit,
                                                ViBoolean SSEnable,
                                                ViInt32 signalType,
                                                ViInt32 limit_setting,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModMQualLimLev (ViSession instrSession,
                                                   ViReal64 limitWaveFormQuality,
                                                   ViReal64 carrierFreqLimit,
                                                   ViReal64 transmitTimeErrorLimit_us,
                                                   ViReal64 limitCarrierFeedThrough,
                                                   ViInt32 reverse,
                                                   ViReal64 sidebandSupprLimit,
                                                   ViReal64 SBSACP2Limit,
                                                   ViReal64 SBSACP3Limit,
                                                   ViReal64 SBSACP4Limit,
                                                   ViInt32 signalType,
                                                   ViInt32 limit_setting,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModMQualLimEnable (ViSession instrSession,
                                                      ViBoolean waveFormEnable,
                                                      ViBoolean carrierFrequencyEnable,
                                                      ViBoolean transmitTimeErrorEnable,
                                                      ViBoolean carrierFeedthroughEnable,
                                                      ViBoolean reverseEnable,
                                                      ViBoolean SBSEnable,
                                                      ViBoolean SBSACP2Enable,
                                                      ViBoolean SBSACP3Enable,
                                                      ViBoolean SBSACP4Enable,
                                                      ViInt32 signalType,
                                                      ViInt32 limit_setting,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_DefModMQualLim (ViSession instrSession,
                                               ViInt32 limitDefaultAllSettings,
                                               ViInt32 signalType,
                                               ViInt32 limit_setting,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_InitModMQuality (ViSession instrSession,
                                                ViInt32 signalType,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_AbortModMQuality (ViSession instrSession,
                                                 ViInt32 signalType,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_StopModMQuality (ViSession instrSession,
                                                ViInt32 signalType,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ContinueModMQuality (ViSession instrSession,
                                                    ViInt32 signalType,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchModMQualStatus (ViSession instrSession,
                                                    ViPInt32 measurementStatus,
                                                    ViPInt32 counter_forStatisticsCycle,
                                                    ViPInt32 counter_forEvaluationPeriod,
                                                    ViInt32 signalType,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModMQualErep (ViSession instrSession,
                                                 ViInt32 measurementEventReporting,
                                                 ViInt32 signalType,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNPowCont (ViSession instrSession,
                                             ViInt32 statistics, ViInt32 repetition,
                                             ViInt32 stopCondition,
                                             ViInt32 stepMode,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNPowContRep (ViSession instrSession,
                                                ViInt32 repetition,
                                                ViInt32 stopCondition,
                                                ViInt32 stepMode,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNPowContStats (ViSession instrSession,
                                                  ViInt32 statistics,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNPowNCS (ViSession instrSession,
                                            ViInt32 chipSamplePerStatistic,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_InitNPow (ViSession instrSession,
                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_AbortNPow (ViSession instrSession,
                                          ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_StopNPow (ViSession instrSession,
                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ContinueNPow (ViSession instrSession,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchNPowStatus (ViSession instrSession,
                                                ViPInt32 measurementStatus,
                                                ViPInt32 counter_forStatisticsCycle,
                                                ViPInt32 counter_forEvaluationPeriod,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNPowErrReporting (ViSession instrSession,
                                                     ViInt32 reportMode,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadScalNPow (ViSession instrSession,
                                             ViPReal64 currAvePower_dBm,
                                             ViPReal64 currMinPower_dBm,
                                             ViPReal64 currMaxPower_dBm,
                                             ViPReal64 aveAvePower_dBm,
                                             ViPReal64 aveMinPower_dBm,
                                             ViPReal64 aveMaxPower_dBm,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchScalNPow (ViSession instrSession,
                                              ViPReal64 currAvePower_dBm,
                                              ViPReal64 currMinPower_dBm,
                                              ViPReal64 currMaxPower_dBm,
                                              ViPReal64 aveAvePower_dBm,
                                              ViPReal64 aveMinPower_dBm,
                                              ViPReal64 aveMaxPower_dBm,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SampleScalNPow (ViSession instrSession,
                                               ViPReal64 currAvePower_dBm,
                                               ViPReal64 currMinPower_dBm,
                                               ViPReal64 currMaxPower_dBm,
                                               ViPReal64 aveAvePower_dBm,
                                               ViPReal64 aveMinPower_dBm,
                                               ViPReal64 aveMaxPower_dBm,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowXSlotContSDEL (ViSession instrSession,
                                                     ViInt32 triggerStepDelay,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowXSlotContSWID (ViSession instrSession,
                                                     ViReal64 step_width_of_the_measurement,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowXSlotContSCO (ViSession instrSession,
                                                    ViInt32 frameNumber_perStatCycle,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowXSlotContPMWd (ViSession instrSession,
                                                     ViReal64 powerMeasurementWidth,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_DefPowXSlotCont (ViSession instrSession,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowXSlotContRep (ViSession instrSession,
                                                    ViInt32 repetition,
                                                    ViInt32 nbRepetition,
                                                    ViInt32 stopCondition,
                                                    ViInt32 stepMode,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowXSlotContSintComp (ViSession instrSession,
                                                         ViBoolean _VI_FAR enable[],
                                                         ViReal64 _VI_FAR deviations[],
                                                         ViInt32 _VI_FAR steps[],
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowXSlotContSintSC (ViSession instrSession,
                                                       ViInt32 stepIntervalNumber,
                                                       ViBoolean enable,
                                                       ViReal64 deviation,
                                                       ViInt32 step,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowXSlotContSintDC (ViSession instrSession,
                                                       ViBoolean _VI_FAR enable[],
                                                       ViReal64 _VI_FAR deviations[],
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowXSlotContSintNC (ViSession instrSession,
                                                       ViInt32 _VI_FAR steps[],
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowXSlotContSintIS (ViSession instrSession,
                                                       ViInt32 stepIntervalNumber,
                                                       ViInt32 step,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowXSlotContSintDS (ViSession instrSession,
                                                       ViInt32 stepIntervalNumber,
                                                       ViBoolean enable,
                                                       ViReal64 deviation,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_InitPowXSlot (ViSession instrSession,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_AborPowXSlot (ViSession instrSession,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_StopPowXSlot (ViSession instrSession,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ContPowXSlot (ViSession instrSession,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetcPowXSlotStat (ViSession instrSession,
                                                 ViPInt32 measurementStatus,
                                                 ViPInt32 counter_for_current_stat_cycle,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowXSlotErep (ViSession instrSession,
                                                 ViInt32 measurementEventReporting,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadPowXSlot (ViSession instrSession,
                                             ViReal64 _VI_FAR framePowerValues[],
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetcPowXSlot (ViSession instrSession,
                                             ViReal64 _VI_FAR framePowerValues[],
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SampPowXSlot (ViSession instrSession,
                                             ViReal64 _VI_FAR framePowerValues[],
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfWPowContRep (ViSession instrSession,
                                                ViInt32 repetition,
                                                ViInt32 stopCondition,
                                                ViInt32 stepMode,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_InitWPow (ViSession instrSession,
                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_AbortWPow (ViSession instrSession,
                                          ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_StopWPow (ViSession instrSession,
                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ContinueWPow (ViSession instrSession,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchWPowStatus (ViSession instrSession,
                                                ViPInt32 measurementStatus,
                                                ViPInt32 currentStepCycleCount,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfWPowErrReporting (ViSession instrSession,
                                                     ViInt32 reportMode,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadScalWPow (ViSession instrSession,
                                             ViPReal64 widebandPower_dBm,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchScalWPow (ViSession instrSession,
                                              ViPReal64 widebandPower_dBm,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SampleScalWPow (ViSession instrSession,
                                               ViPReal64 widebandPower_dBm,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfIQAccessRXSWEnab (ViSession instrSession,
                                                     ViInt32 RXIQSwappingEnable,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfIQAccessGMUL (ViSession instrSession,
                                                 ViInt32 gainMultiplier,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfIQAccessTCON (ViSession instrSession,
                                                 ViInt32 timingControl,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_DefIQACcessCont (ViSession instrSession,
                                                ViBoolean IQAccessContrlol,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_InitIQAccess (ViSession instrSession,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_AbortIQAccess (ViSession instrSession,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchIQAccessStatus (ViSession instrSession,
                                                    ViPInt32 measurementStatus,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_InitSAPow (ViSession instrSession,
                                          ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_AbortSAPow (ViSession instrSession,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_StopSAPow (ViSession instrSession,
                                          ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ContinueSAPow (ViSession instrSession,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchSAPowStatus (ViSession instrSession,
                                                 ViPInt32 measurementStatus,
                                                 ViPInt32 statisticCount,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSAPowErrReporting (ViSession instrSession,
                                                      ViInt32 reportMode,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadScalSAPow (ViSession instrSession,
                                              ViPReal64 standby_Power_dBm,
                                              ViPReal64 access_Probe_Power_dBm,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchScalSAPow (ViSession instrSession,
                                               ViPReal64 standby_Power_dBm,
                                               ViPReal64 access_Probe_Power_dBm,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SampleScalSAPow (ViSession instrSession,
                                                ViPReal64 standby_Power_dBm,
                                                ViPReal64 access_Probe_Power_dBm,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowOLTRespIBSPow (ViSession instrSession,
                                                     ViReal64 initialBSPower_dBm,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowOLTRespPowStep (ViSession instrSession,
                                                      ViReal64 BSPowerStep_dBm,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowOLTRespPStepDir (ViSession instrSession,
                                                       ViInt32 BSPowerStepDirection,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowOLTRespLev (ViSession instrSession,
                                                  ViReal64 trafficLevel_dB,
                                                  ViReal64 pilotLevel_dB,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowOLTRContImpair (ViSession instrSession,
                                                      ViReal64 AWGN_level_dB,
                                                      ViBoolean AWGNEnable,
                                                      ViReal64 BSFreqOffset_kHz,
                                                      ViBoolean BSFreqOffsetEnable,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowOLTRContFratFFCH (ViSession instrSession,
                                                        ViInt32 frameRate,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalPowOLTREbntFFCH (ViSession instrSession,
                                                   ViPReal64 calculatedEbNtFFCH,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_DefPowOLTResp (ViSession instrSession,
                                              ViBoolean enable,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowOLTEnvEnab (ViSession instrSession,
                                                  ViBoolean enable,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowOLTEnvPowCdma (ViSession instrSession,
                                                     ViReal64 CDMAPower,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowOLTEnvLev (ViSession instrSession,
                                                 ViInt32 channel, ViBoolean state,
                                                 ViReal64 level,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcPowOLTEnvEbntFfch (ViSession instrSession,
                                                      ViPReal64 calculatedEbNtFFCH,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcPowOLTEnvEbntFsch (ViSession instrSession,
                                                      ViInt32 forwardSCH,
                                                      ViPReal64 calculatedEbNtFSCH,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowOLTEnvImpairment (ViSession instrSession,
                                                        ViReal64 AWGN_level_dB,
                                                        ViBoolean AWGNEnable,
                                                        ViReal64 BSFreqOffset_kHz,
                                                        ViBoolean BSFreqEnable,
                                                        ViReal64 txFER,
                                                        ViBoolean txFEREnable,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowOLTEnvPCBits (ViSession instrSession,
                                                    ViPInt32 powerControlBits,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_InitPowOLTimeResponse (ViSession instrSession,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_AbortPowOLTimeResponse (ViSession instrSession,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_StopPowOLTimeResponse (ViSession instrSession,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ContPowOLTimeResponse (ViSession instrSession,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchPowOLTimeRespStatus (ViSession instrSession,
                                                         ViPInt32 measurementStatus,
                                                         ViPInt32 counter_forStatisticsCycle,
                                                         ViPInt32 counter_forEvaluationPeriod,
                                                         ViChar _VI_FAR errorMessage[]);

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowOLTimeRespEReport (ViSession instrSession,
                                                         ViInt32 measurementEventReporting,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadScalPowOLResp (ViSession instrSession,
                                                  ViPReal64 initialMSPower_dBm,
                                                  ViPReal64 initialBSPower_dBm,
                                                  ViPReal64 currentBSPower_dBm,
                                                  ViPInt32 limitLinesMatching,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchScalPowOLResp (ViSession instrSession,
                                                   ViPReal64 initialMSPower_dBm,
                                                   ViPReal64 initialBSPower_dBm,
                                                   ViPReal64 currentBSPower_dBm,
                                                   ViPInt32 limitLinesMatching,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SampleScalPowOLResp (ViSession instrSession,
                                                    ViPReal64 initialMSPower_dBm,
                                                    ViPReal64 initialBSPower_dBm,
                                                    ViPReal64 currentBSPower_dBm,
                                                    ViPInt32 limitLinesMatching,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadArrayPowOLResp (ViSession instrSession,
                                                   ViReal64 _VI_FAR burstPower[],
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchArrayPowOLResp (ViSession instrSession,
                                                    ViReal64 _VI_FAR burstPower[],
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SampleArrayPowOLResp (ViSession instrSession,
                                                     ViReal64 _VI_FAR burstPower[],
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMinOutCont (ViSession instrSession,
                                                  ViInt32 statistics,
                                                  ViInt32 repetition,
                                                  ViInt32 stepMode,
                                                  ViInt32 stopCondition,
                                                  ViInt32 signalType,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMinOutContStats (ViSession instrSession,
                                                       ViInt32 statistics,
                                                       ViInt32 signalType,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMinOutContRep (ViSession instrSession,
                                                     ViInt32 repetition,
                                                     ViInt32 stopCondition,
                                                     ViInt32 stepMode,
                                                     ViInt32 signalType,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMinOutLev (ViSession instrSession,
                                                 ViReal64 CDMAPower_dBm,
                                                 ViReal64 FCHLevel_dB,
                                                 ViReal64 pilotLevel_dB,
                                                 ViInt32 signalType,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMinOutContPowCDMA (ViSession instrSession,
                                                         ViReal64 CDMAPower,
                                                         ViInt32 signalType,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMinOutContLev (ViSession instrSession,
                                                     ViReal64 FCHLevel_dB,
                                                     ViReal64 pilotLevel_dB,
                                                     ViInt32 signalType,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMinOutContImpair (ViSession instrSession,
                                                        ViReal64 AWGN_level_dB,
                                                        ViBoolean AWGNEnable,
                                                        ViReal64 BSFreqOffset_kHz,
                                                        ViBoolean BSFreqOffsetEnable,
                                                        ViInt32 signalType,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMinContFratFFCH (ViSession instrSession,
                                                       ViInt32 signalType,
                                                       ViInt32 frameRate,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalPowMinEbntFFCH (ViSession instrSession,
                                                  ViInt32 signalType,
                                                  ViPReal64 calculatedEbNtFFCH,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_DefPowMinOutCont (ViSession instrSession,
                                                 ViInt32 defaultSetting,
                                                 ViInt32 signalType,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMinEnvEnab (ViSession instrSession,
                                                  ViInt32 signalType,
                                                  ViBoolean enable,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMinEnvPowCdma (ViSession instrSession,
                                                     ViInt32 signalType,
                                                     ViReal64 CDMAPower,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMinEnvLev (ViSession instrSession,
                                                 ViInt32 signalType,
                                                 ViInt32 channel, ViBoolean state,
                                                 ViReal64 level,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcPowMinEnvEbntFfch (ViSession instrSession,
                                                      ViInt32 signalType,
                                                      ViPReal64 calculatedEbNtFFCH,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcPowMinEnvEbntFsch (ViSession instrSession,
                                                      ViInt32 signalType,
                                                      ViInt32 forwardSCH,
                                                      ViPReal64 calculatedEbNtFSCH,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMinEnvFratFfch (ViSession instrSession,
                                                      ViInt32 signalType,
                                                      ViInt32 frameRate,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMinEnvImpairment (ViSession instrSession,
                                                        ViInt32 signalType,
                                                        ViReal64 AWGN_level_dB,
                                                        ViBoolean AWGNEnable,
                                                        ViReal64 BSFreqOffset_kHz,
                                                        ViBoolean BSFreqEnable,
                                                        ViReal64 txFER,
                                                        ViBoolean txFEREnable,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMinEnvPCBits (ViSession instrSession,
                                                    ViInt32 signalType,
                                                    ViPInt32 powerControlBits,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMinOutLimAsymVal (ViSession instrSession,
                                                        ViReal64 absolutMinPower,
                                                        ViReal64 waveFormQuality,
                                                        ViInt32 signalType,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_DefPowMinOutLimits (ViSession instrSession,
                                                   ViInt32 defaultSetting,
                                                   ViInt32 signalType,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_InitPowMinOut (ViSession instrSession,
                                              ViInt32 signalType,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_AbortPowMinOut (ViSession instrSession,
                                               ViInt32 signalType,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_StopPowMinOut (ViSession instrSession,
                                              ViInt32 signalType,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ContinuePowMinOut (ViSession instrSession,
                                                  ViInt32 signalType,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchPowMinOutStatus (ViSession instrSession,
                                                     ViInt32 *measurementStatus,
                                                     ViPInt32 counter_forStatisticsCycle,
                                                     ViPInt32 counter_forEvaluationPeriod,
                                                     ViInt32 signalType,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMinOutErep (ViSession instrSession,
                                                  ViInt32 measurementEventReporting,
                                                  ViInt32 signalType,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadScalPowMinOut (ViSession instrSession,
                                                  ViPReal64 totalPowerCurr_dBm,
                                                  ViPReal64 totalPowerAve_dBm,
                                                  ViPReal64 totalPowerMin_dBm,
                                                  ViPReal64 totalPowerMax_dBm,
                                                  ViPReal64 waveformQualCurr,
                                                  ViPReal64 waveformQualAve,
                                                  ViPReal64 waveformQualMin,
                                                  ViPReal64 waveformQualMax,
                                                  ViPReal64 measurement_out_ofTolerance,
                                                  ViInt32 signalType,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchScalPowMinOut (ViSession instrSession,
                                                   ViPReal64 totalPowerCurr_dBm,
                                                   ViPReal64 totalPowerAve_dBm,
                                                   ViPReal64 totalPowerMin_dBm,
                                                   ViPReal64 totalPowerMax_dBm,
                                                   ViPReal64 waveformQualCurr,
                                                   ViPReal64 waveformQualAve,
                                                   ViPReal64 waveformQualMin,
                                                   ViPReal64 waveformQualMax,
                                                   ViPReal64 measurement_out_ofTolerance,
                                                   ViInt32 signalType,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SampleScalPowMinOut (ViSession instrSession,
                                                    ViPReal64 totalPowerCurr_dBm,
                                                    ViPReal64 totalPowerAve_dBm,
                                                    ViPReal64 totalPowerMin_dBm,
                                                    ViPReal64 totalPowerMax_dBm,
                                                    ViPReal64 waveformQualCurr,
                                                    ViPReal64 waveformQualAve,
                                                    ViPReal64 waveformQualMin,
                                                    ViPReal64 waveformQualMax,
                                                    ViPReal64 measurement_out_ofTolerance,
                                                    ViInt32 signalType,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcScalPowMinOutMAtcLim (ViSession instrSession,
                                                         ViPInt32 totalPowerCurr,
                                                         ViPInt32 totalPowerAve,
                                                         ViPInt32 totalPowerMin,
                                                         ViPInt32 totalPowerMax,
                                                         ViPInt32 waveformQualCurr,
                                                         ViPInt32 waveformQualAve,
                                                         ViPInt32 waveformQualMin,
                                                         ViPInt32 waveformQualMax,
                                                         ViInt32 signalType,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMaxOutCont (ViSession instrSession,
                                                  ViInt32 statistics,
                                                  ViInt32 repetition,
                                                  ViInt32 stopCondition,
                                                  ViInt32 stepMode,
                                                  ViInt32 signalType,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMaxOutContStats (ViSession instrSession,
                                                       ViInt32 statistics,
                                                       ViInt32 signalType,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMaxOutContRep (ViSession instrSession,
                                                     ViInt32 repetition,
                                                     ViInt32 stopCondition,
                                                     ViInt32 stepMode,
                                                     ViInt32 signalType,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMaxOutLev (ViSession instrSession,
                                                 ViReal64 CDMAPower_dBm,
                                                 ViReal64 FCHLevel_dB,
                                                 ViReal64 pilotLevel_dB,
                                                 ViInt32 signalType,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMaxOutContPowCDMA (ViSession instrSession,
                                                         ViReal64 CDMAPower,
                                                         ViInt32 signalType,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMaxOutContLev (ViSession instrSession,
                                                     ViReal64 FCHLevel_dB,
                                                     ViReal64 pilotLevel_dB,
                                                     ViInt32 signalType,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMaxOutContImpair (ViSession instrSession,
                                                        ViReal64 AWGN_level_dB,
                                                        ViBoolean AWGNEnable,
                                                        ViReal64 BSFreqOffset_kHz,
                                                        ViBoolean BSFreqOffsetEnable,
                                                        ViInt32 signalType,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMaxContFratFFCH (ViSession instrSession,
                                                       ViInt32 signalType,
                                                       ViInt32 frameRate,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalPowMaxEbntFFCH (ViSession instrSession,
                                                  ViInt32 signalType,
                                                  ViPReal64 calculatedEbNtFFCH,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_DefPowMaxOutCont (ViSession instrSession,
                                                 ViInt32 defaultSetting,
                                                 ViInt32 signalType,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMaxEnvEnab (ViSession instrSession,
                                                  ViInt32 signalType,
                                                  ViBoolean enable,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMaxEnvPowCdma (ViSession instrSession,
                                                     ViInt32 signalType,
                                                     ViReal64 CDMAPower,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMaxEnvLev (ViSession instrSession,
                                                 ViInt32 signalType,
                                                 ViInt32 channel, ViBoolean state,
                                                 ViReal64 level,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcPowMaxEnvEbntFfch (ViSession instrSession,
                                                      ViInt32 signalType,
                                                      ViPReal64 calculatedEbNtFFCH,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcPowMaxEnvEbntFsch (ViSession instrSession,
                                                      ViInt32 signalType,
                                                      ViInt32 forwardSCH,
                                                      ViPReal64 calculatedEbNtFSCH,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMaxEnvFratFfch (ViSession instrSession,
                                                      ViInt32 signalType,
                                                      ViInt32 frameRate,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMaxEnvImpairment (ViSession instrSession,
                                                        ViInt32 signalType,
                                                        ViReal64 AWGN_level_dB,
                                                        ViBoolean AWGNEnable,
                                                        ViReal64 BSFreqOffset_kHz,
                                                        ViBoolean BSFreqEnable,
                                                        ViReal64 txFER,
                                                        ViBoolean txFEREnable,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMaxEnvPCBits (ViSession instrSession,
                                                    ViInt32 signalType,
                                                    ViPInt32 powerControlBits,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMaxOutLimAsymVal (ViSession instrSession,
                                                        ViReal64 absolutMaxPower,
                                                        ViReal64 waveFormQuality,
                                                        ViInt32 signalType,
                                                        ViReal64 upperLimit,
                                                        ViReal64 lowerLimit,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_DefPowMaxOutLimits (ViSession instrSession,
                                                   ViInt32 defaultSetting,
                                                   ViInt32 signalType,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_InitPowMaxOut (ViSession instrSession,
                                              ViInt32 signalType,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_AbortPowMaxOut (ViSession instrSession,
                                               ViInt32 signalType,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_StopPowMaxOut (ViSession instrSession,
                                              ViInt32 signalType,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ContinuePowMaxOut (ViSession instrSession,
                                                  ViInt32 signalType,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchPowMaxOutStatus (ViSession instrSession,
                                                     ViInt32 *measurementStatus,
                                                     ViPInt32 counter_forStatisticsCycle,
                                                     ViPInt32 counter_forEvaluationPeriod,
                                                     ViInt32 signalType,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMaxOutErep (ViSession instrSession,
                                                  ViInt32 measurementEventReporting,
                                                  ViInt32 signalType,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadScalPowMaxOut (ViSession instrSession,
                                                  ViPReal64 totalPowerCurr_dBm,
                                                  ViPReal64 totalPowerAve_dBm,
                                                  ViPReal64 totalPowerMin_dBm,
                                                  ViPReal64 totalPowerMax_dBm,
                                                  ViPReal64 waveformQualCurr,
                                                  ViPReal64 waveformQualAve,
                                                  ViPReal64 waveformQualMin,
                                                  ViPReal64 waveformQualMax,
                                                  ViPReal64 measurement_out_ofTolerance,
                                                  ViInt32 signalType,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchScalPowMaxOut (ViSession instrSession,
                                                   ViPReal64 totalPowerCurr_dBm,
                                                   ViPReal64 totalPowerAve_dBm,
                                                   ViPReal64 totalPowerMin_dBm,
                                                   ViPReal64 totalPowerMax_dBm,
                                                   ViPReal64 waveformQualCurr,
                                                   ViPReal64 waveformQualAve,
                                                   ViPReal64 waveformQualMin,
                                                   ViPReal64 waveformQualMax,
                                                   ViPReal64 measurement_out_ofTolerance,
                                                   ViInt32 signalType,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SampleScalPowMaxOut (ViSession instrSession,
                                                    ViPReal64 totalPowerCurr_dBm,
                                                    ViPReal64 totalPowerAve_dBm,
                                                    ViPReal64 totalPowerMin_dBm,
                                                    ViPReal64 totalPowerMax_dBm,
                                                    ViPReal64 waveformQualCurr,
                                                    ViPReal64 waveformQualAve,
                                                    ViPReal64 waveformQualMin,
                                                    ViPReal64 waveformQualMax,
                                                    ViPReal64 measurement_out_ofTolerance,
                                                    ViInt32 signalType,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcScalPowMaxOutMatcLim (ViSession instrSession,
                                                         ViPInt32 totalPowerCurr,
                                                         ViPInt32 totalPowerAve,
                                                         ViPInt32 totalPowerMin,
                                                         ViPInt32 totalPowerMax,
                                                         ViPInt32 waveformQualCurr,
                                                         ViPInt32 waveformQualAve,
                                                         ViPInt32 waveformQualMin,
                                                         ViPInt32 waveformQualMax,
                                                         ViInt32 signalType,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGatedOutCont (ViSession instrSession,
                                                    ViInt32 mode,
                                                    ViInt32 statistics,
                                                    ViInt32 repetition,
                                                    ViInt32 stopCondition,
                                                    ViInt32 stepMode,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGatedOutRmode (ViSession instrSession,
                                                     ViInt32 mode,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGatedOutContStats (ViSession instrSession,
                                                         ViInt32 statistics,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGatedOutContRep (ViSession instrSession,
                                                       ViInt32 repetition,
                                                       ViInt32 stopCondition,
                                                       ViInt32 stepMode,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSubArrPowGateOut (ViSession instrSession,
                                                     ViInt32 mode, ViReal64 start_in_uS,
                                                     ViInt32 samples,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGatedOutLev (ViSession instrSession,
                                                   ViReal64 CDMAPower_dBm,
                                                   ViReal64 FCHLevel_dB,
                                                   ViReal64 pilotLevel_dB,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGatOutContPowCDMA (ViSession instrSession,
                                                         ViReal64 CDMAPower,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGatedOutContLev (ViSession instrSession,
                                                       ViReal64 FCHLevel_dB,
                                                       ViReal64 pilotLevel_dB,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGatOutContImpair (ViSession instrSession,
                                                        ViReal64 AWGN_level_dB,
                                                        ViBoolean AWGNEnable,
                                                        ViReal64 BSFreqOffset_kHz,
                                                        ViBoolean BSFreqOffsetEnable,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGatedOutContPCG (ViSession instrSession,
                                                       ViInt32 PCG,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGoutContFratFFCH (ViSession instrSession,
                                                        ViInt32 frameRate,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalPowGoutEbntFFCH (ViSession instrSession,
                                                   ViPReal64 calculatedEbNtFFCH,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_DefPowGatedOutCont (ViSession instrSession,
                                                   ViInt32 defaultSetting,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGatOutEnvEnab (ViSession instrSession,
                                                     ViBoolean enable,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGatOutEnvPowCdma (ViSession instrSession,
                                                        ViReal64 CDMAPower,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGatOutEnvLev (ViSession instrSession,
                                                    ViInt32 channel,
                                                    ViBoolean state, ViReal64 level,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcPowGatOutEnvEbntFfch (ViSession instrSession,
                                                         ViPReal64 calculatedEbNtFFCH,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcPowGatOutEnvEbntFsch (ViSession instrSession,
                                                         ViInt32 forwardSCH,
                                                         ViPReal64 calculatedEbNtFSCH,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGatOutEnvFratFfch (ViSession instrSession,
                                                         ViInt32 frameRate,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGatOutEnvImp (ViSession instrSession,
                                                    ViReal64 AWGN_level_dB,
                                                    ViBoolean AWGNEnable,
                                                    ViReal64 BSFreqOffset_kHz,
                                                    ViBoolean BSFreqEnable,
                                                    ViReal64 txFER,
                                                    ViBoolean txFEREnable,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGatOutEnvPCBits (ViSession instrSession,
                                                       ViPInt32 powerControlBits,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGatedOutLimits (ViSession instrSession,
                                                      ViReal64 aLimit_rise_time_us,
                                                      ViReal64 bLimit_fall_time_us,
                                                      ViReal64 cLimit_dB,
                                                      ViReal64 dLimit_relative_dB,
                                                      ViReal64 dLimit_absolute_dBm,
                                                      ViReal64 eLimit_burst_length_us,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGoutCAMMLimA (ViSession instrSession,
                                                    ViReal64 limitA_us,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGoutCAMMLimBref (ViSession instrSession,
                                                       ViReal64 refence_forBLimit_us,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGoutCAMMLimB (ViSession instrSession,
                                                    ViReal64 limitB_us,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGoutCAMMLimC (ViSession instrSession,
                                                    ViReal64 limitC_dB,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGoutCAMMLimDRel (ViSession instrSession,
                                                       ViReal64 limitDRelative_dB,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGoutCAMMLimDAbs (ViSession instrSession,
                                                       ViReal64 limitDAbsolute_dBm,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGoutCAMMLimEref (ViSession instrSession,
                                                       ViReal64 reference_forELimit_us,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGoutCAMMLimE (ViSession instrSession,
                                                    ViReal64 eLimit_us,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGoutCAMMLimVal (ViSession instrSession,
                                                      ViReal64 limitA_us,
                                                      ViReal64 refence_forBLimit_us,
                                                      ViReal64 limitB_us,
                                                      ViReal64 limitC_dB,
                                                      ViReal64 limitDRelative_dB,
                                                      ViReal64 limitDAbsolute_dBm,
                                                      ViReal64 reference_forELimit_us,
                                                      ViReal64 eLimit_us,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_DefPowGatedOutLimits (ViSession instrSession,
                                                     ViInt32 defaultSetting,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_InitPowGatedOut (ViSession instrSession,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_AbortPowGatedOut (ViSession instrSession,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_StopPowGatedOut (ViSession instrSession,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ContinuePowGatedOut (ViSession instrSession,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchPowGatedOutStatus (ViSession instrSession,
                                                       ViInt32 *measurementStatus,
                                                       ViPInt32 counter_forStatisticsCycle,
                                                       ViPInt32 counter_forEvaluationPeriod,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGatedOutErep (ViSession instrSession,
                                                    ViInt32 measurementEventReporting,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadScalPowGatedOut (ViSession instrSession,
                                                    ViPReal64 meanOutput_dBm,
                                                    ViPInt32 limitLinesMatching,
                                                    ViPReal64 measurement_out_ofTolerance,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchScalPowGatedOut (ViSession instrSession,
                                                     ViPReal64 meanOutput_dBm,
                                                     ViPInt32 limitLinesMatching,
                                                     ViPReal64 measurement_out_ofTolerance,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SampleScalPowGatedOut (ViSession instrSession,
                                                      ViPReal64 meanOutput_dBm,
                                                      ViPInt32 limitLinesMatching,
                                                      ViPReal64 measurement_out_ofTolerance,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalScalPowGatOutMatcRamp (ViSession instrSession,
                                                         ViInt32 *totalRampStatus,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadArrPowGatedOut (ViSession instrSession,
                                                   ViInt32 measurementSetting,
                                                   ViReal64 _VI_FAR burstPower[],
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchArrPowGatedOut (ViSession instrSession,
                                                    ViInt32 measurementSetting,
                                                    ViReal64 _VI_FAR burstPower[],
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SampleArrPowGatedOut (ViSession instrSession,
                                                     ViInt32 measurementSetting,
                                                     ViReal64 _VI_FAR burstPower[],
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalArrPowGatOutMatcLimit (ViSession instrSession,
                                                         ViReal64 *bitFieldUpperLimits,
                                                         ViReal64 *bitFieldLowerLimits,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadSubArrPowGatedOut (ViSession instrSession,
                                                      ViInt32 measurementSetting,
                                                      ViReal64 _VI_FAR burstPower[],
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchSubArrPowGatedOut (ViSession instrSession,
                                                       ViInt32 measurementSetting,
                                                       ViReal64 _VI_FAR burstPower[],
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SampleSubArrPowGatedOut (ViSession instrSession,
                                                        ViInt32 measurementSetting,
                                                        ViReal64 _VI_FAR burstPower[],
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCpcCLev (ViSession instrSession,
                                                 ViReal64 CDMAPower,
                                                 ViReal64 FCHLevel,
                                                 ViReal64 pilotLevel,
                                                 ViReal64 SCH1Level,
                                                 ViReal64 SCH2Level,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCpcCContPCDMA (ViSession instrSession,
                                                       ViReal64 CDMAPower,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCpcCContLev (ViSession instrSession,
                                                     ViReal64 FCHLevel,
                                                     ViReal64 pilotLevel,
                                                     ViReal64 SCH1Level,
                                                     ViReal64 SCH2Level,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCpcCImpairments (ViSession instrSession,
                                                         ViReal64 AWGNLevel,
                                                         ViBoolean AWGNEnable,
                                                         ViReal64 BSFreqOffset,
                                                         ViBoolean BSFreqOffsetEnable,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCpcCPCBits (ViSession instrSession,
                                                    ViInt32 powerControlBits,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowContFratFFCH (ViSession instrSession,
                                                      ViInt32 frameRate,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalCDPowCpccEbntFFCH (ViSession instrSession,
                                                     ViPReal64 calculatedEbNtFFCH,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalCDPowCpccEbntFSCHZero (ViSession instrSession,
                                                         ViPReal64 calculatedEbNtFSCH0,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalCDPowCpccEbntFSCHOne (ViSession instrSession,
                                                        ViPReal64 calculatedEbNtFSCH1,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCpcCCont (ViSession instrSession,
                                                  ViBoolean state,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCpcCEnvEnab (ViSession instrSession,
                                                     ViBoolean enable,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCpcCEnvPowCdma (ViSession instrSession,
                                                        ViReal64 CDMAPower,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCpcCEnvLev (ViSession instrSession,
                                                    ViInt32 channel,
                                                    ViBoolean state, ViReal64 level,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcCDPowCpcCEnvEbntFfch (ViSession instrSession,
                                                         ViPReal64 calculatedEbNtFFCH,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcCDPowCpcCEnvEbntFsch (ViSession instrSession,
                                                         ViInt32 forwardSCH,
                                                         ViPReal64 calculatedEbNtFSCH,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCpcCEnvFratFfch (ViSession instrSession,
                                                         ViInt32 frameRate,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCpcCEnvImp (ViSession instrSession,
                                                    ViReal64 AWGN_level_dB,
                                                    ViBoolean AWGNEnable,
                                                    ViReal64 BSFreqOffset_kHz,
                                                    ViBoolean BSFreqEnable,
                                                    ViReal64 txFER,
                                                    ViBoolean txFEREnable,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCpcCEnvPCBits (ViSession instrSession,
                                                       ViInt32 powerControlBits,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCpcCLimAsym (ViSession instrSession,
                                                     ViInt32 limitLinesSetting,
                                                     ViReal64 carrierFeedthroughLimit,
                                                     ViReal64 freqErrorLimit,
                                                     ViReal64 rhoLimit,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_DefCDPowCpccLimit (ViSession instrSession,
                                                  ViBoolean limitDefault,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCDPWCont (ViSession instrSession,
                                                  ViInt32 resultMode,
                                                  ViInt32 statistics,
                                                  ViInt32 repetition,
                                                  ViInt32 stopCondition,
                                                  ViInt32 stepMode,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCDPWRMode (ViSession instrSession,
                                                   ViInt32 resultMode,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCDPWSfac (ViSession instrSession,
                                                  ViInt32 spreadingFactor,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCDPWROrder (ViSession instrSession,
                                                    ViInt32 resultOrder,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCDPWContStats (ViSession instrSession,
                                                       ViInt32 statistics,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCDPWContRep (ViSession instrSession,
                                                     ViInt32 repetition,
                                                     ViInt32 stopCondition,
                                                     ViInt32 stepMode,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_DefCDPowCDPWCont (ViSession instrSession,
                                                 ViBoolean state,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCDPWLimAsym (ViSession instrSession,
                                                     ViInt32 limitLinesSetting,
                                                     ViReal64 CDPLimitY,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCDPWLimIql (ViSession instrSession,
                                                    ViBoolean IQLeakageCheck,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_DefCDPowCDPWLimit (ViSession instrSession,
                                                  ViBoolean limitDefault,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_InitCDPowCDPW (ViSession instrSession,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_AbortCDPowCDPW (ViSession instrSession,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_StopCDPowCDPW (ViSession instrSession,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ContinueCDPowCDPW (ViSession instrSession,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchCDPowCDPWStatus (ViSession instrSession,
                                                     ViPInt32 measurementStatus,
                                                     ViPInt32 counter_forStatisticsCycle,
                                                     ViPInt32 counter_forEvaluationPeriod,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCDPWErep (ViSession instrSession,
                                                  ViInt32 measurementEventReporting,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadArrCDPowCDPW (ViSession instrSession,
                                                 ViInt32 signalType,
                                                 ViInt32 measurementSetting,
                                                 ViReal64 _VI_FAR measuredPower[],
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchArrCDPowCDPW (ViSession instrSession,
                                                  ViInt32 signalType,
                                                  ViInt32 measurementSetting,
                                                  ViReal64 _VI_FAR measuredPower[],
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SampleArrCDPowCDPW (ViSession instrSession,
                                                   ViInt32 signalType,
                                                   ViInt32 measurementSetting,
                                                   ViReal64 _VI_FAR measuredPower[],
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetcArrCDPowCDPWStat (ViSession instrSession,
                                                     ViInt32 signalType,
                                                     ViInt32 _VI_FAR signalState[],
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcArrCDPowCDPWMatcLim (ViSession instrSession,
                                                        ViInt32 signalType,
                                                        ViInt32 measurementSetting,
                                                        ViPInt32 iQSignalTolerance,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowPCDEPCont (ViSession instrSession,
                                                   ViInt32 resultMode,
                                                   ViInt32 statistics,
                                                   ViInt32 repetition,
                                                   ViInt32 stopCondition,
                                                   ViInt32 stepMode,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowPCDEPRMode (ViSession instrSession,
                                                    ViInt32 resultMode,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowPCDEPSfac (ViSession instrSession,
                                                   ViInt32 spreadingFactor,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowPCDEPROrder (ViSession instrSession,
                                                     ViInt32 resultOrder,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowPCDEPContStats (ViSession instrSession,
                                                        ViInt32 statistics,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowPCDEPContRep (ViSession instrSession,
                                                      ViInt32 repetition,
                                                      ViInt32 stopCondition,
                                                      ViInt32 stepMode,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_DefCDPowPCDEPCont (ViSession instrSession,
                                                  ViBoolean state,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowPCDEPLimAsym (ViSession instrSession,
                                                      ViInt32 limitLinesSetting,
                                                      ViReal64 CDPLimitY,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_DefCDPowPCDEPLimit (ViSession instrSession,
                                                   ViBoolean limitDefault,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_InitCDPowPCDEP (ViSession instrSession,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_AbortCDPowPCDEP (ViSession instrSession,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_StopCDPowPCDEP (ViSession instrSession,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ContinueCDPowPCDEP (ViSession instrSession,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchCDPowPCDEPStatus (ViSession instrSession,
                                                      ViPInt32 measurementStatus,
                                                      ViPInt32 counter_forStatisticsCycle,
                                                      ViPInt32 counter_forEvaluationPeriod,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowPCDEPErep (ViSession instrSession,
                                                   ViInt32 measurementEventReporting,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadArrCDPowPCDEP (ViSession instrSession,
                                                  ViInt32 signalType,
                                                  ViInt32 measurementSetting,
                                                  ViReal64 _VI_FAR measuredPower[],
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchArrCDPowPCDEP (ViSession instrSession,
                                                   ViInt32 signalType,
                                                   ViInt32 measurementSetting,
                                                   ViReal64 _VI_FAR measuredPower[],
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SampleArrCDPowPCDEP (ViSession instrSession,
                                                    ViInt32 signalType,
                                                    ViInt32 measurementSetting,
                                                    ViReal64 _VI_FAR measuredPower[],
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetcArrCDPowPCDEPStat (ViSession instrSession,
                                                      ViInt32 signalType,
                                                      ViInt32 _VI_FAR signalState[],
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcArrCDPowPCDEPMatcLim (ViSession instrSession,
                                                         ViInt32 signalType,
                                                         ViInt32 measurementSetting,
                                                         ViPInt32 iQSignalTolerance,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCHPWCont (ViSession instrSession,
                                                  ViInt32 resultMode,
                                                  ViInt32 statistics,
                                                  ViInt32 repetition,
                                                  ViInt32 stopCondition,
                                                  ViInt32 stepMode,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCHPWRMode (ViSession instrSession,
                                                   ViInt32 resultMode,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCHPWContStats (ViSession instrSession,
                                                       ViInt32 statistics,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCHPWContRep (ViSession instrSession,
                                                     ViInt32 repetition,
                                                     ViInt32 stopCondition,
                                                     ViInt32 stepMode,
                                                     ViChar _VI_FAR errorMessage[]);

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCHPWContPrm (ViSession instrSession,
                                                     ViInt32 referencePowerMode,
                                                     ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_CDMA2K_DefCDPowCHPWCont (ViSession instrSession,
                                                 ViBoolean state,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCHPWLimAsym (ViSession instrSession,
                                                     ViInt32 limitLinesSetting,
                                                     ViReal64 CDPLimitY,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_DefCDPowCHPWLimit (ViSession instrSession,
                                                  ViBoolean limitDefault,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_InitCDPowCHPW (ViSession instrSession,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_AbortCDPowCHPW (ViSession instrSession,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_StopCDPowCHPW (ViSession instrSession,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ContinueCDPowCHPW (ViSession instrSession,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchCDPowCHPWStatus (ViSession instrSession,
                                                     ViPInt32 measurementStatus,
                                                     ViPInt32 counter_forStatisticsCycle,
                                                     ViPInt32 counter_forEvaluationPeriod,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCHPWErep (ViSession instrSession,
                                                  ViInt32 measurementEventReporting,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadArrCDPowCHPW (ViSession instrSession,
                                                 ViInt32 signalType,
                                                 ViInt32 measurementSetting,
                                                 ViReal64 _VI_FAR measuredPower[],
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchArrCDPowCHPW (ViSession instrSession,
                                                  ViInt32 signalType,
                                                  ViInt32 measurementSetting,
                                                  ViReal64 _VI_FAR measuredPower[],
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SampleArrCDPowCHPW (ViSession instrSession,
                                                   ViInt32 signalType,
                                                   ViInt32 measurementSetting,
                                                   ViReal64 _VI_FAR measuredPower[],
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetcArrCDPowCHPWStat (ViSession instrSession,
                                                     ViInt32 signalType,
                                                     ViInt32 _VI_FAR signalState[],
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcArrCDPowCHPWMatcLim (ViSession instrSession,
                                                        ViInt32 signalType,
                                                        ViInt32 measurementSetting,
                                                        ViPUInt32 iQLimitMatching,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowPoffRmode (ViSession instrSession,
                                                   ViInt32 mode,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowPoffStats (ViSession instrSession,
                                                   ViInt32 statistics,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowPoffContRep (ViSession instrSession,
                                                     ViInt32 repetition,
                                                     ViInt32 nbRepetition,
                                                     ViInt32 stopCondition,
                                                     ViInt32 stepMode,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_DefCDPowPoffCont (ViSession instrSession,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowPoffLim (ViSession instrSession,
                                                 ViInt32 limitLinesSetting,
                                                 ViReal64 phaseOffsetLimit,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_DefCDPowPoffLim (ViSession instrSession,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_InitCDPowPoff (ViSession instrSession,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_AborCDPowPoff (ViSession instrSession,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_StopCDPowPoff (ViSession instrSession,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ContCDPowPoff (ViSession instrSession,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchCDPowPoffStatus (ViSession instrSession,
                                                     ViPInt32 measurementStatus,
                                                     ViPInt32 counter_forStatisticsCycle,
                                                     ViPInt32 counter_forCurrentEvalPer,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowPoffErep (ViSession instrSession,
                                                  ViInt32 measurementEventReporting,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadCDPowPoff (ViSession instrSession,
                                              ViReal64 _VI_FAR MSPower[],
                                              ViReal64 _VI_FAR carrierFeedthrough[],
                                              ViReal64 _VI_FAR frequencyError[],
                                              ViReal64 _VI_FAR rho[],
                                              ViPReal64 out_ofTolerance,
                                              ViPInt32 currentStatistics,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetcCDPowPoff (ViSession instrSession,
                                              ViReal64 _VI_FAR MSPower[],
                                              ViReal64 _VI_FAR carrierFeedthrough[],
                                              ViReal64 _VI_FAR frequencyError[],
                                              ViReal64 _VI_FAR rho[],
                                              ViPReal64 out_ofTolerance,
                                              ViPInt32 currentStatistics,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SampCDPowPoff (ViSession instrSession,
                                              ViReal64 _VI_FAR MSPower[],
                                              ViReal64 _VI_FAR carrierFeedthrough[],
                                              ViReal64 _VI_FAR frequencyError[],
                                              ViReal64 _VI_FAR rho[],
                                              ViPReal64 out_ofTolerance,
                                              ViPInt32 currentStatistics,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcCDPowPoffMatcLimt (ViSession instrSession,
                                                      ViInt32 _VI_FAR carrierFeedthrough[],
                                                      ViInt32 _VI_FAR frequencyError[],
                                                      ViInt32 _VI_FAR rho[],
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadArrCDPowPoff (ViSession instrSession,
                                                 ViInt32 signalType,
                                                 ViInt32 measurementSetting,
                                                 ViReal64 _VI_FAR result[],
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetcArrCDPowPoff (ViSession instrSession,
                                                 ViInt32 signalType,
                                                 ViInt32 measurementSetting,
                                                 ViReal64 _VI_FAR result[],
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SampArrCDPowPoff (ViSession instrSession,
                                                 ViInt32 signalType,
                                                 ViInt32 measurementSetting,
                                                 ViReal64 _VI_FAR result[],
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetcArrCDPowPoffIsigStat (ViSession instrSession,
                                                         ViPInt32 r_PICH,
                                                         ViPInt32 r_DCCH,
                                                         ViPInt32 r_SCH1,
                                                         ViPInt32 reserved,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetcArrCDPowPoffQsigStat (ViSession instrSession,
                                                         ViPInt32 r_FCH,
                                                         ViPInt32 r_SCH0,
                                                         ViPInt32 r_EACH,
                                                         ViPInt32 r_CCCH,
                                                         ViPInt32 r_ACKCH,
                                                         ViPInt32 r_CQICH,
                                                         ViPInt32 reserved1,
                                                         ViPInt32 reserved2,
                                                         ViPInt32 reserved3,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcArrCDPowPoffMatcLimt (ViSession instrSession,
                                                         ViInt32 signalType,
                                                         ViInt32 measurementSetting,
                                                         ViPUInt32 signalTolerance,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowToffRmode (ViSession instrSession,
                                                   ViInt32 mode,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowToffStats (ViSession instrSession,
                                                   ViInt32 statistics,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowToffContRep (ViSession instrSession,
                                                     ViInt32 repetition,
                                                     ViInt32 nbRepetition,
                                                     ViInt32 stopCondition,
                                                     ViInt32 stepMode,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_DefCDPowToffCont (ViSession instrSession,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowToffLim (ViSession instrSession,
                                                 ViInt32 limitLinesSetting,
                                                 ViReal64 timeOffsetLimit,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_DefCDPowToffLim (ViSession instrSession,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_InitCDPowToff (ViSession instrSession,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_AborCDPowToff (ViSession instrSession,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_StopCDPowToff (ViSession instrSession,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ContCDPowToff (ViSession instrSession,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchCDPowToffStatus (ViSession instrSession,
                                                     ViPInt32 measurementStatus,
                                                     ViPInt32 counter_forStatisticsCycle,
                                                     ViPInt32 counter_forCurrentEvalPer,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowToffErep (ViSession instrSession,
                                                  ViInt32 measurementEventReporting,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadCDPowToff (ViSession instrSession,
                                              ViReal64 _VI_FAR MSPower[],
                                              ViReal64 _VI_FAR carrierFeedthrough[],
                                              ViReal64 _VI_FAR frequencyError[],
                                              ViReal64 _VI_FAR rho[],
                                              ViPReal64 out_ofTolerance,
                                              ViPInt32 currentStatistics,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetcCDPowToff (ViSession instrSession,
                                              ViReal64 _VI_FAR MSPower[],
                                              ViReal64 _VI_FAR carrierFeedthrough[],
                                              ViReal64 _VI_FAR frequencyError[],
                                              ViReal64 _VI_FAR rho[],
                                              ViPReal64 out_ofTolerance,
                                              ViPInt32 currentStatistics,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SampCDPowToff (ViSession instrSession,
                                              ViReal64 _VI_FAR MSPower[],
                                              ViReal64 _VI_FAR carrierFeedthrough[],
                                              ViReal64 _VI_FAR frequencyError[],
                                              ViReal64 _VI_FAR rho[],
                                              ViPReal64 out_ofTolerance,
                                              ViPInt32 currentStatistics,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcCDPowToffMatcLimt (ViSession instrSession,
                                                      ViInt32 _VI_FAR carrierFeedthrough[],
                                                      ViInt32 _VI_FAR frequencyError[],
                                                      ViInt32 _VI_FAR rho[],
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadArrCDPowToff (ViSession instrSession,
                                                 ViInt32 signalType,
                                                 ViInt32 measurementSetting,
                                                 ViReal64 _VI_FAR result[],
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetcArrCDPowToff (ViSession instrSession,
                                                 ViInt32 signalType,
                                                 ViInt32 measurementSetting,
                                                 ViReal64 _VI_FAR result[],
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SampArrCDPowToff (ViSession instrSession,
                                                 ViInt32 signalType,
                                                 ViInt32 measurementSetting,
                                                 ViReal64 _VI_FAR result[],
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetcArrCDPowToffIsigStat (ViSession instrSession,
                                                         ViPInt32 r_PICH,
                                                         ViPInt32 r_DCCH,
                                                         ViPInt32 r_SCH1,
                                                         ViPInt32 reserved,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetcArrCDPowToffQsigStat (ViSession instrSession,
                                                         ViPInt32 r_FCH,
                                                         ViPInt32 r_SCH0,
                                                         ViPInt32 r_EACH,
                                                         ViPInt32 r_CCCH,
                                                         ViPInt32 r_ACKCH,
                                                         ViPInt32 r_CQICH,
                                                         ViPInt32 reserved1,
                                                         ViPInt32 reserved2,
                                                         ViPInt32 reserved3,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcArrCDPowToffMatcLimt (ViSession instrSession,
                                                         ViInt32 signalType,
                                                         ViInt32 measurementSetting,
                                                         ViPUInt32 signalTolerance,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverMCQLev (ViSession instrSession,
                                               ViReal64 CDMAPower_dBm,
                                               ViReal64 FCHLevel_dB,
                                               ViReal64 pilotLevel_dB,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverMCQContPowCDMA (ViSession instrSession,
                                                       ViReal64 CDMAPower_dBm,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverMCQContLev (ViSession instrSession,
                                                   ViReal64 FCHLevel_dB,
                                                   ViReal64 pilotLevel_dB,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverMCQImpairment (ViSession instrSession,
                                                      ViReal64 AWGN_level_dB,
                                                      ViBoolean AWGNEnable,
                                                      ViReal64 BSFreqOffset_kHz,
                                                      ViBoolean BSFreqEnable,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverMCQPCBits (ViSession instrSession,
                                                  ViInt32 powerControlBits,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverPilotPowEnable (ViSession instrSession,
                                                       ViBoolean enable,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverMCQContFratFFCH (ViSession instrSession,
                                                        ViInt32 frameRate,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalOverMCQEbntFFCH (ViSession instrSession,
                                                   ViPReal64 calculatedEbNtFFCH,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverMcqEnvEnab (ViSession instrSession,
                                                   ViBoolean enable,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverMcqEnvPowCdma (ViSession instrSession,
                                                      ViReal64 CDMAPower,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverMcqEnvLev (ViSession instrSession,
                                                  ViInt32 channel, ViBoolean state,
                                                  ViReal64 level,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcOverMcqEnvEbntFfch (ViSession instrSession,
                                                       ViPReal64 calculatedEbNtFFCH,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcOverMcqEnvEbntFsch (ViSession instrSession,
                                                       ViInt32 forwardSCH,
                                                       ViPReal64 calculatedEbNtFSCH,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverMcqEnvFratFfch (ViSession instrSession,
                                                       ViInt32 frameRate,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverMcqEnvImpairment (ViSession instrSession,
                                                         ViReal64 AWGN_level_dB,
                                                         ViBoolean AWGNEnable,
                                                         ViReal64 BSFreqOffset_kHz,
                                                         ViBoolean BSFreqEnable,
                                                         ViReal64 txFER,
                                                         ViBoolean txFEREnable,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverMcqEnvPCBits (ViSession instrSession,
                                                     ViInt32 powerControlBits,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverCont (ViSession instrSession,
                                             ViInt32 signalType, ViInt32 statistics,
                                             ViInt32 repetition,
                                             ViInt32 stopCondition,
                                             ViInt32 stepMode,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverContRep (ViSession instrSession,
                                                ViInt32 signalType,
                                                ViInt32 repetition,
                                                ViInt32 stopCondition,
                                                ViInt32 stepMode,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverContStats (ViSession instrSession,
                                                  ViInt32 signalType,
                                                  ViInt32 statistics,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_DefOverCont (ViSession instrSession,
                                            ViInt32 signalType, ViBoolean enable,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverContFOffSBS (ViSession instrSession,
                                                    ViInt32 signalType,
                                                    ViInt32 SBSuppressionFreqOffset_Hz,
                                                    ViBoolean enable,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_XtndOverOverSBS (ViSession instrSession,
                                                ViInt32 signalType,
                                                ViInt32 SBSuppressionExtensionMode,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverExtFOffSBS (ViSession instrSession,
                                                   ViInt32 signalType,
                                                   ViInt32 ACPFreqOffset1,
                                                   ViBoolean enable1,
                                                   ViInt32 ACPFreqOffset2,
                                                   ViBoolean enable2,
                                                   ViInt32 ACPFreqOffset3,
                                                   ViBoolean enable3,
                                                   ViInt32 ACPFreqOffset4,
                                                   ViBoolean enable4,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverLimSymVal (ViSession instrSession,
                                                  ViInt32 signalType,
                                                  ViInt32 limitType,
                                                  ViReal64 carrierFreqErr_Hz,
                                                  ViReal64 transmitTimeErr_Usec,
                                                  ViReal64 waveformQuality,
                                                  ViReal64 SBSLimit,
                                                  ViReal64 SBSACP2Limit,
                                                  ViReal64 SBSACP3Limit,
                                                  ViReal64 SBSACP4Limit,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverLimSymEnable (ViSession instrSession,
                                                     ViInt32 signalType,
                                                     ViInt32 limitType,
                                                     ViBoolean carrieFreqErrorEnable,
                                                     ViBoolean txTimeErrorEnable,
                                                     ViBoolean waveformQualEnable,
                                                     ViBoolean SBSEnable,
                                                     ViBoolean SBSAC2Enable,
                                                     ViBoolean SBSAC3Enable,
                                                     ViBoolean SBSAC4Enable,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_DefOverOverLimits (ViSession instrSession,
                                                  ViInt32 signalType,
                                                  ViInt32 defaultSetting,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_InitOverview (ViSession instrSession,
                                             ViInt32 signalType,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_AbortOverview (ViSession instrSession,
                                              ViInt32 signalType,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_StopOverview (ViSession instrSession,
                                             ViInt32 signalType,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ContinueOverview (ViSession instrSession,
                                                 ViInt32 signalType,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchOverStatus (ViSession instrSession,
                                                ViInt32 signalType,
                                                ViPInt32 measurementStatus,
                                                ViPInt32 statisticsCycle,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverErep (ViSession instrSession,
                                             ViInt32 signalType,
                                             ViInt32 measurementEventReporting,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SensOverPPower (ViSession instrSession,
                                               ViPReal64 reportedPilotPower_dB,
                                               ViPReal64 actualPilotPower_dB,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverCQualContRep (ViSession instrSession,
                                                     ViInt32 repetition,
                                                     ViInt32 stopCondition,
                                                     ViInt32 stepMode,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_XTNDOverCQualClev (ViSession instrSession,
                                                  ViInt32 confidenceLevelExtension,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverCQualContFrame (ViSession instrSession,
                                                       ViInt32 maxFrames,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_DefOverCQualCont (ViSession instrSession,
                                                 ViBoolean enable,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverCQualLimMaxFER (ViSession instrSession,
                                                       ViReal64 maxFrameErrorRateLimit_,
                                                       ViBoolean enable,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverCQualLimCLEV (ViSession instrSession,
                                                     ViReal64 minConfidenceLevel,
                                                     ViBoolean enable,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverCQualLimSymVal (ViSession instrSession,
                                                       ViReal64 maxFrameErrorRate_,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_DefOverCQualLim (ViSession instrSession,
                                                ViBoolean enable,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_InitOverCQuality (ViSession instrSession,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_AbortOverCQuality (ViSession instrSession,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_StopOverCQuality (ViSession instrSession,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ContinueOverCQuality (ViSession instrSession,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchOverCQualStatus (ViSession instrSession,
                                                     ViPInt32 measurementStatus,
                                                     ViPInt32 counter_forStatisticsCycle,
                                                     ViPInt32 counter_forEvaluationPeriod,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverCQualErep (ViSession instrSession,
                                                  ViInt32 measurementEventReporting,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadOverCQuality (ViSession instrSession,
                                                 ViPInt32 framesTransmitted,
                                                 ViPReal64 frameErrorRate_,
                                                 ViPReal64 confidenceLevel_,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchOverCQuality (ViSession instrSession,
                                                  ViPInt32 framesTransmitted,
                                                  ViPReal64 frameErrorRate_,
                                                  ViPReal64 confidenceLevel_,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SampleOverCQuality (ViSession instrSession,
                                                   ViPInt32 framesTransmitted,
                                                   ViPReal64 frameErrorRate_,
                                                   ViPReal64 confidenceLevel_,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcOverCQualMatcLim (ViSession instrSession,
                                                     ViPInt32 FERLimit,
                                                     ViPInt32 confidenceLevelLimit,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModOempLev (ViSession instrSession,
                                               ViReal64 CDMAPower_dBm,
                                               ViReal64 trafficLevel_dB,
                                               ViReal64 pilotLevel_dB,
                                               ViInt32 signalType,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModOempContPowCDMA (ViSession instrSession,
                                                       ViReal64 CDMAPower_dBm,
                                                       ViInt32 signalType,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModOempContLev (ViSession instrSession,
                                                   ViReal64 trafficLevel_dB,
                                                   ViBoolean FCHEnable,
                                                   ViReal64 pilotLevel_dB,
                                                   ViBoolean FPICHEnable,
                                                   ViInt32 signalType,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModOempImpairments (ViSession instrSession,
                                                       ViReal64 AWGNLevel_dB,
                                                       ViBoolean AWGNEnable,
                                                       ViReal64 BSFreqOffset_kHz,
                                                       ViBoolean BSFreqEnable,
                                                       ViInt32 signalType,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModOempPCBits (ViSession instrSession,
                                                  ViInt32 signalType,
                                                  ViInt32 powerControlBits,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModOempContFrFFCH (ViSession instrSession,
                                                      ViInt32 signalType,
                                                      ViInt32 frameRate,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalOverOempEbntFFCH (ViSession instrSession,
                                                    ViInt32 signalType,
                                                    ViPReal64 calculatedEbNtFFCH,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModOempEnvEnab (ViSession instrSession,
                                                   ViInt32 signalType,
                                                   ViBoolean enable,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModOempEnvPowCdma (ViSession instrSession,
                                                      ViInt32 signalType,
                                                      ViReal64 CDMAPower,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModOempEnvLev (ViSession instrSession,
                                                  ViInt32 signalType,
                                                  ViInt32 channel, ViBoolean state,
                                                  ViReal64 level,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcModOempEnvEbntFfch (ViSession instrSession,
                                                       ViInt32 signalType,
                                                       ViPReal64 calculatedEbNtFFCH,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcModOempEnvEbntFsch (ViSession instrSession,
                                                       ViInt32 signalType,
                                                       ViInt32 forwardSCH,
                                                       ViPReal64 calculatedEbNtFSCH,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModOempEnvFratFfch (ViSession instrSession,
                                                       ViInt32 signalType,
                                                       ViInt32 frameRate,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModOempEnvImpairment (ViSession instrSession,
                                                         ViInt32 signalType,
                                                         ViReal64 AWGN_level_dB,
                                                         ViBoolean AWGNEnable,
                                                         ViReal64 BSFreqOffset_kHz,
                                                         ViBoolean BSFreqEnable,
                                                         ViReal64 txFER,
                                                         ViBoolean txFEREnable,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModOempEnvPCBits (ViSession instrSession,
                                                     ViInt32 signalType,
                                                     ViInt32 powerControlBits,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModOempLimSymVal (ViSession instrSession,
                                                     ViReal64 EVMErrorPeak,
                                                     ViReal64 EVMErrorRMS,
                                                     ViReal64 magErrorPeak,
                                                     ViReal64 magErrorRMS,
                                                     ViReal64 phaseErrorPeak,
                                                     ViReal64 phaseErrorRMS,
                                                     ViReal64 carrierFeedthrough,
                                                     ViReal64 iQImbalance_dB,
                                                     ViReal64 carrierFreqErr,
                                                     ViReal64 transmitTimeErr_Us,
                                                     ViReal64 waveformQuality,
                                                     ViInt32 measurementMode,
                                                     ViInt32 signalType,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModOempLimSymEnable (ViSession instrSession,
                                                        ViInt32 EVMErrorPeak,
                                                        ViInt32 EVMErrorRMS,
                                                        ViInt32 magErrorPeak,
                                                        ViInt32 magErrorRMS,
                                                        ViInt32 phaseErrorPeak,
                                                        ViInt32 phaseErrorRMS,
                                                        ViInt32 carrierFeedthrough,
                                                        ViInt32 iQImbalance,
                                                        ViInt32 carrierFreqErr,
                                                        ViInt32 transmitTimeError,
                                                        ViInt32 waveformQuality,
                                                        ViInt32 measurementMode,
                                                        ViInt32 signalType,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_DefModOempLim (ViSession instrSession,
                                              ViBoolean enable, ViInt32 signalType,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModCont (ViSession instrSession,
                                            ViInt32 mode, ViInt32 statistics,
                                            ViInt32 repetition,
                                            ViInt32 stopCondition, ViInt32 stepMode,
                                            ViInt32 type, ViInt32 signalType,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModContRMode (ViSession instrSession,
                                                 ViInt32 mode, ViInt32 type,
                                                 ViInt32 signalType,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModContStats (ViSession instrSession,
                                                 ViInt32 statistics, ViInt32 type,
                                                 ViInt32 signalType,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModContRep (ViSession instrSession,
                                               ViInt32 repetition,
                                               ViInt32 stopCondition,
                                               ViInt32 stepMode, ViInt32 type,
                                               ViInt32 signalType,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSubArrayMod (ViSession instrSession,
                                                ViInt32 valueMode,
                                                ViInt32 startTime_in_uS,
                                                ViInt32 sample, ViInt32 type,
                                                ViInt32 signalType,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_DefModCont (ViSession instrSession, ViInt32 type,
                                           ViInt32 signalType, ViBoolean defaultSet,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_InitMod (ViSession instrSession, ViInt32 type,
                                        ViInt32 signalType,
                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_AbortMod (ViSession instrSession, ViInt32 type,
                                         ViInt32 signalType,
                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_StopMod (ViSession instrSession, ViInt32 type,
                                        ViInt32 signalType,
                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ContinueMod (ViSession instrSession,
                                            ViInt32 type, ViInt32 signalType,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchModStatus (ViSession instrSession,
                                               ViPInt32 measurementStatus,
                                               ViPInt32 counter_forStatisticsCycle,
                                               ViPInt32 counter_forEvaluationPeriod,
                                               ViInt32 type, ViInt32 signalType,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModErep (ViSession instrSession,
                                            ViInt32 measurementEventReporting,
                                            ViInt32 type, ViInt32 signalType,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadArrayMod (ViSession instrSession,
                                             ViReal64 _VI_FAR bursts[],
                                             ViInt32 measurementSetting,
                                             ViInt32 measurementType,
                                             ViInt32 signalType,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchArrayMod (ViSession instrSession,
                                              ViReal64 _VI_FAR bursts[],
                                              ViInt32 measurementSetting,
                                              ViInt32 measurementType,
                                              ViInt32 signalType,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SampleArrayMod (ViSession instrSession,
                                               ViReal64 _VI_FAR bursts[],
                                               ViInt32 measurementSetting,
                                               ViInt32 measurementType,
                                               ViInt32 signalType,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadSubArrayMod (ViSession instrSession,
                                                ViReal64 _VI_FAR bursts[],
                                                ViInt32 measurementSetting,
                                                ViInt32 measurementType,
                                                ViInt32 signalType,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchSubArrayMod (ViSession instrSession,
                                                 ViReal64 _VI_FAR bursts[],
                                                 ViInt32 measurementSetting,
                                                 ViInt32 measurementType,
                                                 ViInt32 signalType,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SampleSubArrayMod (ViSession instrSession,
                                                  ViReal64 _VI_FAR bursts[],
                                                  ViInt32 measurementSetting,
                                                  ViInt32 measurementType,
                                                  ViInt32 signalType,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSpecAcpContFOffsAcp (ViSession instrSession,
                                                        ViInt32 ACP,
                                                        ViReal64 frequencyOffset_Hz,
                                                        ViBoolean enable,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSpecAcpLimAcp (ViSession instrSession,
                                                  ViInt32 ACP, ViReal64 powerLimit,
                                                  ViBoolean enable,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSpecAcpStats (ViSession instrSession,
                                                 ViInt32 statistics,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_XtndSpecAcpStat (ViSession instrSession,
                                                ViBoolean statistical_results,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSpecAcpContRep (ViSession instrSession,
                                                   ViInt32 repetition,
                                                   ViInt32 nbRepetition,
                                                   ViInt32 stopCondition,
                                                   ViInt32 stepMode,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_DefSpecAcpCont (ViSession instrSession,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_InitSpecAcp (ViSession instrSession,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_AbortSpecAcp (ViSession instrSession,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_StopSpecAcp (ViSession instrSession,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ContinueSpecAcp (ViSession instrSession,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchSpecAcpStatus (ViSession instrSession,
                                                   ViPInt32 measurementStatus,
                                                   ViPInt32 counter_forStatisticsCycle,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSpecAcpErep (ViSession instrSession,
                                                ViInt32 measurementEventReporting,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadSpecAcp (ViSession instrSession,
                                            ViReal64 _VI_FAR ACP_Current[],
                                            ViReal64 _VI_FAR ACP_Average[],
                                            ViReal64 _VI_FAR ACP_Maximum[],
                                            ViReal64 _VI_FAR channelPower[],
                                            ViPReal64 outOfTolerance,
                                            ViPInt32 currentStatistics,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetcSpecAcp (ViSession instrSession,
                                            ViReal64 _VI_FAR ACP_Current[],
                                            ViReal64 _VI_FAR ACP_Average[],
                                            ViReal64 _VI_FAR ACP_Maximum[],
                                            ViReal64 _VI_FAR channelPower[],
                                            ViPReal64 outOfTolerance,
                                            ViPInt32 currentStatistics,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SampSpecAcp (ViSession instrSession,
                                            ViReal64 _VI_FAR ACP_Current[],
                                            ViReal64 _VI_FAR ACP_Average[],
                                            ViReal64 _VI_FAR ACP_Maximum[],
                                            ViReal64 _VI_FAR channelPower[],
                                            ViPReal64 outOfTolerance,
                                            ViPInt32 currentStatistics,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcSpecAcpMatcLimt (ViSession instrSession,
                                                    ViInt32 _VI_FAR toleranceChannel_Current[],
                                                    ViInt32 _VI_FAR toleranceChannel_Average[],
                                                    ViInt32 _VI_FAR toleranceChannel_Maximum[],
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModIqanContRMode (ViSession instrSession,
                                                     ViInt32 mode,
                                                     ViInt32 signalType,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModIqanContRep (ViSession instrSession,
                                                   ViInt32 repetition,
                                                   ViInt32 nbRepetition,
                                                   ViInt32 stopCondition,
                                                   ViInt32 stepMode,
                                                   ViInt32 signalType,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_DefModIqanCont (ViSession instrSession,
                                               ViInt32 signalType,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_InitModIqan (ViSession instrSession,
                                            ViInt32 signalType,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_AbortModIqan (ViSession instrSession,
                                             ViInt32 signalType,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_StopModIqan (ViSession instrSession,
                                            ViInt32 signalType,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ContinueModIqan (ViSession instrSession,
                                                ViInt32 signalType,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchModIqanStatus (ViSession instrSession,
                                                   ViPInt32 measurementStatus,
                                                   ViPInt32 counter_forStatisticsCycle,
                                                   ViInt32 signalType,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModIqanErep (ViSession instrSession,
                                                ViInt32 measurementEventReporting,
                                                ViInt32 signalType,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadModIqan (ViSession instrSession,
                                            ViPReal64 EVM_RMS,
                                            ViPReal64 magnitudeError_RMS,
                                            ViPReal64 phaseError_RMS,
                                            ViPReal64 waveformQuality,
                                            ViPReal64 iQImbalance,
                                            ViPReal64 carrierFeedthrough,
                                            ViPReal64 MSPower, ViInt32 signalType,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetcModIqan (ViSession instrSession,
                                            ViPReal64 EVM_RMS,
                                            ViPReal64 magnitudeError_RMS,
                                            ViPReal64 phaseError_RMS,
                                            ViPReal64 waveformQuality,
                                            ViPReal64 iQImbalance,
                                            ViPReal64 carrierFeedthrough,
                                            ViPReal64 MSPower, ViInt32 signalType,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SampModIqan (ViSession instrSession,
                                            ViPReal64 EVM_RMS,
                                            ViPReal64 magnitudeError_RMS,
                                            ViPReal64 phaseError_RMS,
                                            ViPReal64 waveformQuality,
                                            ViPReal64 iQImbalance,
                                            ViPReal64 carrierFeedthrough,
                                            ViPReal64 MSPower, ViInt32 signalType,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadArrayModIqan (ViSession instrSession,
                                                 ViReal64 _VI_FAR results[],
                                                 ViInt32 measurementType,
                                                 ViInt32 signalType,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetcArrayModIqan (ViSession instrSession,
                                                 ViReal64 _VI_FAR results[],
                                                 ViInt32 measurementType,
                                                 ViInt32 signalType,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SampArrayModIqan (ViSession instrSession,
                                                 ViReal64 _VI_FAR results[],
                                                 ViInt32 measurementType,
                                                 ViInt32 signalType,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerFSSCTset (ViSession instrSession,
                                                  ViInt32 testSetup,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerFSSCContTsetLev (ViSession instrSession,
                                                         ViInt32 testSetup,
                                                         ViReal64 pilotLevel_dB,
                                                         ViReal64 FCHLevel_dB,
                                                         ViReal64 SCHSCCHLevel_dB,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerFSSCTsetLevFPIC (ViSession instrSession,
                                                         ViInt32 testSetup,
                                                         ViReal64 pilotLevel_dB,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerFSSCTsetLevFFCH (ViSession instrSession,
                                                         ViInt32 testSetup,
                                                         ViReal64 FCHLevel_dB,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerFSSCTsetPowCDMA (ViSession instrSession,
                                                         ViInt32 testSetup,
                                                         ViReal64 CDMAPower_dBm,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerFSSCContTsetImp (ViSession instrSession,
                                                         ViInt32 testSetup,
                                                         ViReal64 AWGNLevel_dB,
                                                         ViBoolean AWGNEnable,
                                                         ViReal64 BSFrequencyOffset_KHz,
                                                         ViBoolean BSFreqOffsetEnable,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerFSSCTsetFraFFCH (ViSession instrSession,
                                                         ViInt32 testSetup,
                                                         ViInt32 frameRate,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerFSSCConLevFschZ (ViSession instrSession,
                                                         ViInt32 testSetup,
                                                         ViReal64 SCH0Level,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2k_RQFerFsscTsetEbntFFCH (ViSession instrSession,
                                                      ViInt32 testSetup,
                                                      ViPReal64 calculatedEbNtFFCH_dB,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2k_RQFerFsscTsetEbntFSCHZ (ViSession instrSession,
                                                       ViInt32 testSetup,
                                                       ViPReal64 calculatedEbNtSCH0_dB,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2k_RQFerFsscTsetEbntFSCHOne (ViSession instrSession,
                                                         ViInt32 testSetup,
                                                         ViPReal64 calculatedEbNtSCH1_dB,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_DefRQFerFSSCTset (ViSession instrSession,
                                                 ViInt32 testSetup,
                                                 ViBoolean defaultFERCommonSetting,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerFSSCTsetEnvEnab (ViSession instrSession,
                                                         ViInt32 testSetup,
                                                         ViBoolean enable,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerFSSCTEnvPowCdma (ViSession instrSession,
                                                         ViInt32 testSetup,
                                                         ViReal64 CDMAPower,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerFSSCTsetEnvLev (ViSession instrSession,
                                                        ViInt32 testSetup,
                                                        ViInt32 channel,
                                                        ViBoolean state,
                                                        ViReal64 level,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcRQFerFSSCEnvEbntFfch (ViSession instrSession,
                                                         ViInt32 testSetup,
                                                         ViPReal64 calculatedEbNtFFCH,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcRQFerFSSCEnvEbntFsch (ViSession instrSession,
                                                         ViInt32 testSetup,
                                                         ViInt32 forwardSCH,
                                                         ViPReal64 calculatedEbNtFSCH,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerFSSCEnvFratFfch (ViSession instrSession,
                                                         ViInt32 testSetup,
                                                         ViInt32 frameRate,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerFSEnvImpairment (ViSession instrSession,
                                                         ViInt32 testSetup,
                                                         ViReal64 AWGN_level_dB,
                                                         ViBoolean AWGNEnable,
                                                         ViReal64 BSFreqOffset_kHz,
                                                         ViBoolean BSFreqEnable,
                                                         ViReal64 txFER,
                                                         ViBoolean txFEREnable,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerFSSCTsEnvPCBits (ViSession instrSession,
                                                         ViInt32 testSetup,
                                                         ViPInt32 powerControlBits,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerFCHContTsetFram (ViSession instrSession,
                                                         ViInt32 testSetup,
                                                         ViInt32 frameCount,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerFCHContTsetRep (ViSession instrSession,
                                                        ViInt32 testSetup,
                                                        ViInt32 repetition,
                                                        ViInt32 stopCondition,
                                                        ViInt32 stepMode,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_DefRQFerFchContTset (ViSession instrSession,
                                                    ViInt32 testSetup,
                                                    ViBoolean defaultFERFCHSetting,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerFCHLimTsetMFer (ViSession instrSession,
                                                        ViInt32 testSetup,
                                                        ViReal64 maxFER_,
                                                        ViBoolean enable,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerFCHLimTsetCLev (ViSession instrSession,
                                                        ViInt32 testSetup,
                                                        ViReal64 minConfidenceLevel,
                                                        ViBoolean enable,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_DefRQFerFchLimTset (ViSession instrSession,
                                                   ViInt32 testSetup,
                                                   ViBoolean defaultFERFCHLimits,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_InitRQFerFCH (ViSession instrSession,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_AbortRQFerFCH (ViSession instrSession,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_StopRQFerFCH (ViSession instrSession,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ContRQFerFCH (ViSession instrSession,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchRQFerFCHStats (ViSession instrSession,
                                                   ViPInt32 measurementStatus,
                                                   ViPInt32 counter_forStatisticsCycle,
                                                   ViPInt32 counter_forEvaluationPeriod,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerFCHERep (ViSession instrSession,
                                                 ViInt32 reportMode,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadRQFerFCH (ViSession instrSession,
                                             ViPReal64 FER, ViPInt32 frameErrors,
                                             ViPInt32 elapsedFrames,
                                             ViPReal64 confidenceLevel,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchRQFerFCH (ViSession instrSession,
                                              ViPReal64 FER, ViPInt32 frameErrors,
                                              ViPInt32 elapsedFrames,
                                              ViPReal64 confidenceLevel,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SampleRQFerFCH (ViSession instrSession,
                                               ViPReal64 FER, ViPInt32 frameErrors,
                                               ViPInt32 elapsedFrames,
                                               ViPReal64 confidenceLevel,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcRQFerFCHMatcLim (ViSession instrSession,
                                                    ViPInt32 maximumFER,
                                                    ViPInt32 confidenceLevel,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerSCHSContTsetFr (ViSession instrSession,
                                                        ViInt32 testSetup,
                                                        ViInt32 frameCount,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerSCHSContTsetRep (ViSession instrSession,
                                                         ViInt32 testSetup,
                                                         ViInt32 repetition,
                                                         ViInt32 stopCondition,
                                                         ViInt32 stepMode,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_XtndRxqFerSchsSchOne (ViSession instrSession,
                                                     ViBoolean enable,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_DefRQFerSchsContTset (ViSession instrSession,
                                                     ViInt32 testSetup,
                                                     ViBoolean defaultFERSCHSetting,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerSCHSLimTsetMFer (ViSession instrSession,
                                                         ViInt32 testSetup,
                                                         ViReal64 maxFER_,
                                                         ViBoolean enable,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerSCHSLimTsetSMFr (ViSession instrSession,
                                                         ViInt32 testSetup,
                                                         ViInt32 SCH,
                                                         ViReal64 maxFER_,
                                                         ViBoolean enable,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerSCHSLimTsetCLev (ViSession instrSession,
                                                         ViInt32 testSetup,
                                                         ViReal64 minConfidenceLevel,
                                                         ViBoolean enable,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerSCHSLimTsetSCLv (ViSession instrSession,
                                                         ViInt32 testSetup,
                                                         ViInt32 SCH,
                                                         ViReal64 minConfidenceLevel,
                                                         ViBoolean enable,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_DefRQFerSchsLimTset (ViSession instrSession,
                                                    ViInt32 testSetup,
                                                    ViBoolean defaultFERSCHLimits,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_InitRQFerSCHS (ViSession instrSession,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_AbortRQFerSCHS (ViSession instrSession,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_StopRQFerSCHS (ViSession instrSession,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ContRQFerSCHS (ViSession instrSession,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchRQFerSCHSStats (ViSession instrSession,
                                                    ViPInt32 measurementStatus,
                                                    ViPInt32 counter_forStatisticsCycle,
                                                    ViPInt32 counter_forEvaluationPeriod,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerSCHSERep (ViSession instrSession,
                                                  ViInt32 reportMode,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadRQFerSCHS (ViSession instrSession,
                                              ViPReal64 FER, ViPInt32 frameErrors,
                                              ViPInt32 elapsedFrames,
                                              ViPReal64 confidenceLevel,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchRQFerSCHS (ViSession instrSession,
                                               ViPReal64 FER, ViPInt32 frameErrors,
                                               ViPInt32 elapsedFrames,
                                               ViPReal64 confidenceLevel,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SampleRQFerSCHS (ViSession instrSession,
                                                ViPReal64 FER, ViPInt32 frameErrors,
                                                ViPInt32 elapsedFrames,
                                                ViPReal64 confidenceLevel,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcRQFerSCHSMatcLim (ViSession instrSession,
                                                     ViPInt32 maximumFER,
                                                     ViPInt32 confidenceLevel,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcCont (ViSession instrSession,
                                              ViInt32 statistics,
                                              ViInt32 repetition,
                                              ViInt32 stopCondition,
                                              ViInt32 stepMode,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcContRep (ViSession instrSession,
                                                 ViInt32 repetition,
                                                 ViInt32 stopCondition,
                                                 ViInt32 stepMode,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcContStats (ViSession instrSession,
                                                   ViInt32 statistics,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcContFPCMode (ViSession instrSession,
                                                     ViInt32 FPCMode,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcContRDelay (ViSession instrSession,
                                                    ViInt32 reportDelay,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcContRFrames (ViSession instrSession,
                                                     ViInt32 reportFrames,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_RXFpcContCPRimary (ViSession instrSession,
                                                  ViInt32 CPrimiary,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_RXFpcContCSECondary (ViSession instrSession,
                                                    ViInt32 CSecondary,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcContPowCDMA (ViSession instrSession,
                                                     ViReal64 CDMAPower_dBm,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcContLevFPIC (ViSession instrSession,
                                                     ViReal64 pilotLevel_dB,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcContLevFFCH (ViSession instrSession,
                                                     ViReal64 FCHLevel_dB,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcContLevFSCH0 (ViSession instrSession,
                                                      ViReal64 SCH0Level_dB,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcContImp (ViSession instrSession,
                                                 ViReal64 AWGNLevel_dB,
                                                 ViInt32 AWGNEnable,
                                                 ViReal64 BSFrequencyOffset_KHz,
                                                 ViInt32 BSFreqOffsetEnable,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcContFraFFCH (ViSession instrSession,
                                                     ViInt32 frameRate,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcEnvEnab (ViSession instrSession,
                                                 ViBoolean enable,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcEnvPowCdma (ViSession instrSession,
                                                    ViReal64 CDMAPower,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcEnvLev (ViSession instrSession,
                                                ViInt32 channel, ViBoolean state,
                                                ViReal64 level,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcEnvFratFfch (ViSession instrSession,
                                                     ViInt32 frameRate,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcEnvImpairment (ViSession instrSession,
                                                       ViReal64 AWGN_level_dB,
                                                       ViBoolean AWGNEnable,
                                                       ViReal64 BSFreqOffset_kHz,
                                                       ViBoolean BSFreqEnable,
                                                       ViReal64 txFER,
                                                       ViBoolean txFEREnable,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcEnvPCBits (ViSession instrSession,
                                                   ViPInt32 powerControlBits,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcContLspInit (ViSession instrSession,
                                                     ViInt32 channel,
                                                     ViReal64 initialEbNtSetpoint,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcContLspThr (ViSession instrSession,
                                                    ViInt32 channel,
                                                    ViInt32 enable,
                                                    ViReal64 ebNtSetpointThreshold,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcContFchTFer (ViSession instrSession,
                                                     ViReal64 targetFERFCH,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcContFchLSL (ViSession instrSession,
                                                    ViReal64 lowerStaticLevel,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcContFchLSU (ViSession instrSession,
                                                    ViReal64 upperStaticLevel,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_RQFpcContFchLDL (ViSession instrSession,
                                                ViInt32 lowerDynamicLevelSetting,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_RQFpcContFchLDU (ViSession instrSession,
                                                ViInt32 upperDynamicLevelSetting,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcContSchZTFer (ViSession instrSession,
                                                      ViReal64 targetFERFCH,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcContSchZLSL (ViSession instrSession,
                                                     ViReal64 lowerStaticLevel,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcContSchZLSU (ViSession instrSession,
                                                     ViReal64 upperStaticLevel,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_RQFpcContSchZLDL (ViSession instrSession,
                                                 ViInt32 lowerDynamicLevelSetting,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_RQFpcContSchZLDU (ViSession instrSession,
                                                 ViInt32 upperDynamicLevelSetting,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcContSchOTFer (ViSession instrSession,
                                                      ViReal64 targetFERSCH1,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcContSchOLSL (ViSession instrSession,
                                                     ViReal64 lowerStaticLevel,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcContSchOLSU (ViSession instrSession,
                                                     ViReal64 upperStaticLevel,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcContSchOLDL (ViSession instrSession,
                                                     ViInt32 lowerDynamicLevelSetting,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcContSchOLDU (ViSession instrSession,
                                                     ViInt32 upperDynamicLevelSetting,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_DefRQFpcCont (ViSession instrSession,
                                             ViBoolean defaultFPCControl,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_InitRQFpc (ViSession instrSession,
                                          ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_AbortRQFpc (ViSession instrSession,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_StopRQFpc (ViSession instrSession,
                                          ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ContRQFPControl (ViSession instrSession,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchRQFpcStats (ViSession instrSession,
                                                ViPInt32 measurementStatus,
                                                ViPInt32 counter_forStatisticsCycle,
                                                ViPInt32 elapsedFrames,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcERep (ViSession instrSession,
                                              ViInt32 reportMode,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRLPSRint (ViSession instrSession,
                                             ViReal64 refreshInterval,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_InitRLPS (ViSession instrSession,
                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_AborRLPS (ViSession instrSession,
                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_StopRLPS (ViSession instrSession,
                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ContRLPS (ViSession instrSession,
                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetcRLPSStat (ViSession instrSession,
                                             ViPInt32 measurementStatus,
                                             ViInt32 _VI_FAR statResult[],
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetcRLPS (ViSession instrSession,
                                         ViReal64 _VI_FAR rx[],
                                         ViReal64 _VI_FAR rxTotal[],
                                         ViReal64 _VI_FAR tx[],
                                         ViReal64 _VI_FAR txTotal[],
                                         ViPReal64 rxPPPTotalBytes,
                                         ViPReal64 rxDataRate,
                                         ViPReal64 txPPPTotalBytes,
                                         ViPReal64 txDataRate,
                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPingContPco (ViSession instrSession,
                                                ViInt32 pingCount,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPingContRint (ViSession instrSession,
                                                 ViReal64 repeatInterval,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPingContTout (ViSession instrSession,
                                                 ViReal64 pingTimeout,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPingContPsiz (ViSession instrSession,
                                                 ViInt32 packetSize,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPingContMsip (ViSession instrSession,
                                                 ViBoolean useMSIPAddress,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPingContIpad (ViSession instrSession,
                                                 ViInt32 IPAddress_part1,
                                                 ViInt32 IPAddress_part2,
                                                 ViInt32 IPAddress_part3,
                                                 ViInt32 IPAddress_part4,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_DefPingCont (ViSession instrSession,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPingContRep (ViSession instrSession,
                                                ViInt32 repetition,
                                                ViInt32 nbRepetition,
                                                ViInt32 stopCondition,
                                                ViInt32 stepMode,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_InitPing (ViSession instrSession,
                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_AborPing (ViSession instrSession,
                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_StopPing (ViSession instrSession,
                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ContPing (ViSession instrSession,
                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetcPingStat (ViSession instrSession,
                                             ViPInt32 measurementStatus,
                                             ViPInt32 counter_for_current_stat_cycle,
                                             ViPInt32 counter_for_current_ping,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPingErep (ViSession instrSession,
                                             ViInt32 measurementEventReporting,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadPing (ViSession instrSession,
                                         ViInt32 _VI_FAR IPAddress_part1[],
                                         ViInt32 _VI_FAR IPAddress_part2[],
                                         ViInt32 _VI_FAR IPAddress_part3[],
                                         ViInt32 _VI_FAR IPAddress_part4[],
                                         ViInt32 _VI_FAR packetSize[],
                                         ViInt32 _VI_FAR pingStatus[],
                                         ViReal64 _VI_FAR pingTime[],
                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetcPing (ViSession instrSession,
                                         ViInt32 _VI_FAR IPAddress_part1[],
                                         ViInt32 _VI_FAR IPAddress_part2[],
                                         ViInt32 _VI_FAR IPAddress_part3[],
                                         ViInt32 _VI_FAR IPAddress_part4[],
                                         ViInt32 _VI_FAR packetSize[],
                                         ViInt32 _VI_FAR pingStatus[],
                                         ViReal64 _VI_FAR pingTime[],
                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SampPing (ViSession instrSession,
                                         ViInt32 _VI_FAR IPAddress_part1[],
                                         ViInt32 _VI_FAR IPAddress_part2[],
                                         ViInt32 _VI_FAR IPAddress_part3[],
                                         ViInt32 _VI_FAR IPAddress_part4[],
                                         ViInt32 _VI_FAR packetSize[],
                                         ViInt32 _VI_FAR pingStatus[],
                                         ViReal64 _VI_FAR pingTime[],
                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSigAction (ViSession instrSession,
                                              ViInt32 signallingAction,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSigState (ViSession instrSession,
                                             ViPInt32 state,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SenseSCInfo (ViSession instrSession,
                                            ViPInt32 forwardRC, ViPInt32 reverseRC,
                                            ViChar _VI_FAR serviceOption[],
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_DefSCON (ViSession instrSession,
                                        ViBoolean defaultServiceConfiguration,
                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSconAmoc (ViSession instrSession,
                                             ViInt32 service,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSRfChannel (ViSession instrSession,
                                                 ViInt32 channel,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSRfFrequency (ViSession instrSession,
                                                   ViReal64 frequency_MHz,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSRfPowCDMA (ViSession instrSession,
                                                 ViReal64 CDMAPower_dBm,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSRfPowOut (ViSession instrSession,
                                                ViPReal64 outputPower_dB,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSFSyncLevel (ViSession instrSession,
                                                  ViReal64 syncLevel,
                                                  ViBoolean enable,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSFPilotChLevel (ViSession instrSession,
                                                     ViReal64 pilotLevel,
                                                     ViBoolean enable,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfImpairRfLevAWGNLev (ViSession instrSession,
                                                       ViReal64 AWGNLevel,
                                                       ViBoolean enable,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfImpairRfFreqOffset (ViSession instrSession,
                                                       ViReal64 freqOffset,
                                                       ViBoolean enable,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfImpItf (ViSession instrSession,
                                           ViReal64 injectedTxFER, ViBoolean enable,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSRfLevOCNSValue (ViSession instrSession,
                                                      ViPReal64 OCNSValue,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSRfLevOCNSEnable (ViSession instrSession,
                                                       ViBoolean OCNSEnable,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSPowerCntrlBit (ViSession instrSession,
                                                     ViInt32 BSPowerControlBitsMode,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSPCBSsize (ViSession instrSession,
                                                ViReal64 powerStepSize,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_DefBSSignal (ViSession instrSession,
                                            ViBoolean BSSignalDefault,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSPCBPattSqm (ViSession instrSession,
                                                  ViInt32 powerStepSize,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSPCBPattAreaNob (ViSession instrSession,
                                                      ViInt32 area,
                                                      ViInt32 numberOfBits,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSPCBPattAreaLhb (ViSession instrSession,
                                                      ViInt32 lastHoldBit,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSPCBPattAreaPol (ViSession instrSession,
                                                      ViInt32 area,
                                                      ViInt32 polarity,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSFFCHLevel (ViSession instrSession,
                                                 ViReal64 FFCHLevel,
                                                 ViBoolean enable,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSFFCHChannel (ViSession instrSession,
                                                   ViInt32 FFCHChannel,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSFFCHFrameOffset (ViSession instrSession,
                                                       ViInt32 FFCHFrameOffset,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSQofFFCH (ViSession instrSession,
                                               ViInt32 QOF,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalBSSEbntFFCH (ViSession instrSession,
                                               ViPReal64 calculatedEbNtFFCH,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSFSCHLevelZero (ViSession instrSession,
                                                     ViReal64 FSCHLevel,
                                                     ViBoolean enable,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSFSCHChannelZero (ViSession instrSession,
                                                       ViInt32 FSCHChannel,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSFSCHFrameOffZero (ViSession instrSession,
                                                        ViInt32 FSCHFrameOffset,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSQofFSCHZero (ViSession instrSession,
                                                   ViInt32 QOF,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalBSSEbntFSCHZ (ViSession instrSession,
                                                ViPReal64 calculatedEbNtFSCH0,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSFSCHLevelOne (ViSession instrSession,
                                                    ViReal64 FSCHLevel,
                                                    ViBoolean enable,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSFSCHChannelOne (ViSession instrSession,
                                                      ViInt32 FSCHChannel,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSFSCHFrameOffOne (ViSession instrSession,
                                                       ViInt32 FSCHFrameOffset,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSQofFSCHOne (ViSession instrSession,
                                                  ViInt32 QOF,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalBSSEbntFSCHO (ViSession instrSession,
                                                ViPReal64 calculatedEbNtFSCH0,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSFPCHLevel (ViSession instrSession,
                                                 ViReal64 FPCHLevel,
                                                 ViBoolean enable,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSFPCHChannel (ViSession instrSession,
                                                   ViInt32 FPCHChannel,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSUsageFQPCH (ViSession instrSession,
                                                  ViBoolean QPCHUsage,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSChFQPCH (ViSession instrSession,
                                               ViPInt32 quickPagingChannel,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSLevFQPCH (ViSession instrSession,
                                                ViReal64 QPCHLevel,
                                                ViBoolean enable,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSIbitsFQPCH (ViSession instrSession,
                                                  ViInt32 indicatorBit,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSDutPagingFQPCH (ViSession instrSession,
                                                      ViBoolean DUTPaging,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSProPNOffset (ViSession instrSession,
                                                   ViInt32 PNOffset,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSProIDNumber (ViSession instrSession,
                                                   ViInt32 IDNumber,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSPropCLDTime (ViSession instrSession,
                                                   ViReal64 callLossDetectTime,
                                                   ViBoolean enable,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSProPrt (ViSession instrSession,
                                              ViReal64 pageResponseTimeout,
                                              ViChar _VI_FAR errorMessage[]);

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSProLsec (ViSession instrSession,
                                               ViInt32 leapSeconds,
                                               ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSProLtof (ViSession instrSession,
                                               ViInt32 localTimeOffset,
                                               ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSProDls (ViSession instrSession,
                                              ViBoolean daylightSavings,
                                              ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_CDMA2K_NetIdenMCC (ViSession instrSession, char MCC[],
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_NetIdenNID (ViSession instrSession, ViInt32 NID,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfMSSigID (ViSession instrSession,
                                            ViChar _VI_FAR mobileID[],
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfMSSigIDURData (ViSession instrSession,
                                                  ViInt32 mobileRegistrationDataMINIMSI,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetMSSigMCC (ViSession instrSession,
                                                char MCC[],
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetMSSigMCR (ViSession instrSession,
                                                ViBoolean mobileCapabilitiesReport,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetCindCid (ViSession instrSession,
                                               ViBoolean enableTransfer_ofCallerID,
                                               ViString callerID,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetCindPind (ViSession instrSession,
                                                ViInt32 callerIDPresentationInd,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetCindCwin (ViSession instrSession,
                                                ViBoolean callWaitingIndicator,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetSysSID (ViSession instrSession,
                                              ViInt32 systemID,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetSysBSID (ViSession instrSession,
                                               ViInt32 stationID,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetSysSWA (ViSession instrSession,
                                              ViInt32 windowSize,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetSysSWN (ViSession instrSession,
                                              ViInt32 windowSize,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetSysSWR (ViSession instrSession,
                                              ViInt32 windowSize,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetSysPRevision (ViSession instrSession,
                                                    ViInt32 protocolRevision,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetSysMinPrev (ViSession instrSession,
                                                  ViInt32 minimumProtocolRevision,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetSysIMSIEtwelve (ViSession instrSession,
                                                      ViChar _VI_FAR IMSI11_12[],
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetSysUWCard (ViSession instrSession,
                                                 ViBoolean stateUseWildcard,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetSysAuthentication (ViSession instrSession,
                                                         ViBoolean authenticationState,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetSysAuthChallenge (ViSession instrSession,
                                                        ViChar _VI_FAR authenticationChallenge[],
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetRegTBReg (ViSession instrSession,
                                                ViReal64 timerBaseRegistration,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetRegHome (ViSession instrSession,
                                               ViBoolean homeMode,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetRegFSID (ViSession instrSession,
                                               ViBoolean foreignSID,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetRegFNID (ViSession instrSession,
                                               ViBoolean foreignNID,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CofNetRegPowUp (ViSession instrSession,
                                               ViBoolean powerUp,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetRegPowDown (ViSession instrSession,
                                                  ViBoolean powerDown,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetRegParReg (ViSession instrSession,
                                                 ViBoolean parameterRegister,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetPCHRate (ViSession instrSession,
                                               ViInt32 pagingChannelRate,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetPCHSCIndex (ViSession instrSession,
                                                  ViInt32 slotCycleIndex,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetPCHMaxSCIndex (ViSession instrSession,
                                                     ViInt32 maxSlotCycleIndex,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetAPRMode (ViSession instrSession,
                                               ViInt32 accessProbeMode,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetAPRNoffset (ViSession instrSession,
                                                  ViReal64 nominalOffsetPower,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetAPRIoffset (ViSession instrSession,
                                                  ViReal64 initialPowerOffset,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetAPRPIncrement (ViSession instrSession,
                                                     ViReal64 powerIncrement,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetAPRPPSequence (ViSession instrSession,
                                                     ViInt32 probesPerSequence,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetAPRSPAttempt (ViSession instrSession,
                                                    ViInt32 number_ofAccessProbeSequence,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_Origination (ViSession instrSession,
                                            ViInt32 timeout,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_PagingCallToMS (ViSession instrSession,
                                               ViInt32 timeout,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ReleaseCallFromMS (ViSession instrSession,
                                                  ViInt32 timeout,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ReleaseCallfromBTS (ViSession instrSession,
                                                   ViInt32 timeout,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSconCurrRc (ViSession instrSession,
                                               ViInt32 f_RC, ViInt32 r_RC,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclService (ViSession instrSession,
                                                    ViInt32 service,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclLoopSOption (ViSession instrSession,
                                                        ViInt32 serviceOption,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclLoopFCH (ViSession instrSession,
                                                    ViPInt32 f_RC, ViPInt32 f_MO,
                                                    ViPInt32 r_RC, ViPInt32 r_MO,
                                                    ViInt32 serviceOption,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclLoopFCHRC (ViSession instrSession,
                                                      ViInt32 f_RC, ViInt32 r_RC,
                                                      ViInt32 serviceOption,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclLoopFCHFr (ViSession instrSession,
                                                      ViInt32 frameRate,
                                                      ViInt32 serviceOption,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclLoopPattern (ViSession instrSession,
                                                        ViChar _VI_FAR pattern[],
                                                        ViInt32 serviceOption,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclLoopPattGen (ViSession instrSession,
                                                        ViInt32 patternGeneration,
                                                        ViInt32 serviceOption,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclSpeechSOpt (ViSession instrSession,
                                                       ViInt32 serviceOption,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclSpeechFCH (ViSession instrSession,
                                                      ViPInt32 f_RC, ViPInt32 f_MO,
                                                      ViPInt32 r_RC, ViPInt32 r_MO,
                                                      ViInt32 serviceOption,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclSpeechFCHRC (ViSession instrSession,
                                                        ViInt32 f_RC, ViInt32 r_RC,
                                                        ViInt32 serviceOption,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConSclSpeechVcoder (ViSession instrSession,
                                                        ViInt32 serviceOption,
                                                        ViInt32 voiceCoder,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSconSclSpeechEDelay (ViSession instrSession,
                                                        ViInt32 serviceOption,
                                                        ViReal64 echoDelay,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_InitSconSclSpeechVCoder (ViSession instrSession,
                                                        ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSconSclSpeechEncRate (ViSession instrSession,
                                                         ViInt32 encodingRate,
                                                         ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATSOption (ViSession instrSession,
                                                        ViInt32 currentServiceOption,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATFch (ViSession instrSession,
                                                    ViPInt32 f_RC, ViPInt32 f_MO,
                                                    ViPInt32 r_RC, ViPInt32 r_MO,
                                                    ViInt32 currentServiceOption,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATComFchRc (ViSession instrSession,
                                                         ViInt32 f_RC, ViInt32 r_RC,
                                                         ViInt32 currentServiceOption,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATFchRc (ViSession instrSession,
                                                      ViPInt32 f_RC, ViPInt32 r_RC,
                                                      ViInt32 currentServiceOption,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATPattern (ViSession instrSession,
                                                        ViChar _VI_FAR pattern[],
                                                        ViInt32 trafficChannelDirection,
                                                        ViInt32 currentServiceOption,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATPattGen (ViSession instrSession,
                                                        ViInt32 patternGeneration,
                                                        ViInt32 trafficChannelDirection,
                                                        ViInt32 currentServiceOption,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATCBFrame (ViSession instrSession,
                                                        ViInt32 circularBufferFrames,
                                                        ViInt32 trafficChannelDirection,
                                                        ViInt32 currentServiceOption,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATTxon (ViSession instrSession,
                                                     ViInt32 transmitOnPeriod,
                                                     ViInt32 trafficChannelDirection,
                                                     ViInt32 currentServiceOption,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATTxoff (ViSession instrSession,
                                                      ViInt32 transmitOffPeriod,
                                                      ViInt32 trafficChannelDirection,
                                                      ViInt32 currentServiceOption,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATSchZEn (ViSession instrSession,
                                                       ViBoolean SCH0Enable,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATZMppl (ViSession instrSession,
                                                      ViInt32 MPPL,
                                                      ViInt32 trafficChannelDirection,
                                                      ViInt32 currentServiceOption,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATZFType (ViSession instrSession,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViInt32 frameType,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATZPattGen (ViSession instrSession,
                                                         ViInt32 patternGeneration,
                                                         ViInt32 trafficChannelDirection,
                                                         ViInt32 currentServiceOption,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATZPattern (ViSession instrSession,
                                                         ViChar _VI_FAR pattern[],
                                                         ViInt32 trafficChannelDirection,
                                                         ViInt32 currentServiceOption,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATZCBFrame (ViSession instrSession,
                                                         ViInt32 circularBufferFrames,
                                                         ViInt32 trafficChannelDirection,
                                                         ViInt32 currentServiceOption,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATZTxon (ViSession instrSession,
                                                      ViInt32 transmitOnPeriod,
                                                      ViInt32 trafficChannelDirection,
                                                      ViInt32 currentServiceOption,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATZTxoff (ViSession instrSession,
                                                       ViInt32 transmitOffPeriod,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATZFsize (ViSession instrSession,
                                                       ViPInt32 frameSize,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATZCoding (ViSession instrSession,
                                                        ViChar _VI_FAR coding[],
                                                        ViInt32 trafficChannelDirection,
                                                        ViInt32 currentServiceOption,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATZeroRc (ViSession instrSession,
                                                       ViPInt32 f_RC, ViPInt32 r_RC,
                                                       ViInt32 currentServiceOption,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATZDataR (ViSession instrSession,
                                                       ViPInt32 dataRate,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATSchZero (ViSession instrSession,
                                                        ViPInt32 f_RC,
                                                        ViPInt32 f_MO,
                                                        ViPInt32 r_RC,
                                                        ViPInt32 r_MO,
                                                        ViInt32 currentServiceOption,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATOSchOn (ViSession instrSession,
                                                       ViBoolean SCH1Enable,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATOMppl (ViSession instrSession,
                                                      ViInt32 MPPL,
                                                      ViInt32 trafficChannelDirection,
                                                      ViInt32 currentServiceOption,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATOFType (ViSession instrSession,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViInt32 frameType,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATOPattGn (ViSession instrSession,
                                                        ViInt32 patternGeneration,
                                                        ViInt32 trafficChannelDirection,
                                                        ViInt32 currentServiceOption,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATOPat (ViSession instrSession,
                                                     ViChar _VI_FAR pattern[],
                                                     ViInt32 trafficChannelDirection,
                                                     ViInt32 currentServiceOption,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATOCBFrm (ViSession instrSession,
                                                       ViInt32 circularBufferFrames,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATOTxon (ViSession instrSession,
                                                      ViInt32 transmitOnPeriod,
                                                      ViInt32 trafficChannelDirection,
                                                      ViInt32 currentServiceOption,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATOTxoff (ViSession instrSession,
                                                       ViInt32 transmitOffPeriod,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATOCoding (ViSession instrSession,
                                                        ViInt32 coding,
                                                        ViInt32 trafficChannelDirection,
                                                        ViInt32 currentServiceOption,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATODataR (ViSession instrSession,
                                                       ViPReal64 dataRate,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATOSch (ViSession instrSession,
                                                     ViPInt32 f_RC, ViPInt32 f_MO,
                                                     ViPInt32 r_RC, ViPInt32 r_MO,
                                                     ViInt32 currentServiceOption,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATMipSam (ViSession instrSession,
                                                       ViInt32 currentServiceOption,
                                                       ViBoolean MIPStandAloneMode,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATMipHas (ViSession instrSession,
                                                       ViInt32 currentServiceOption,
                                                       ViString secret,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATMipMhip (ViSession instrSession,
                                                        ViInt32 currentServiceOption,
                                                        ViInt32 IPAddress_part1,
                                                        ViInt32 IPAddress_part2,
                                                        ViInt32 IPAddress_part3,
                                                        ViInt32 IPAddress_part4,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATMipFaip (ViSession instrSession,
                                                        ViInt32 currentServiceOption,
                                                        ViInt32 IPAddress_part1,
                                                        ViInt32 IPAddress_part2,
                                                        ViInt32 IPAddress_part3,
                                                        ViInt32 IPAddress_part4,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATMipHaip (ViSession instrSession,
                                                        ViInt32 currentServiceOption,
                                                        ViPInt32 IPAddress_part1,
                                                        ViPInt32 IPAddress_part2,
                                                        ViPInt32 IPAddress_part3,
                                                        ViPInt32 IPAddress_part4,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATMipCoad (ViSession instrSession,
                                                        ViInt32 currentServiceOption,
                                                        ViPInt32 IPAddress_part1,
                                                        ViPInt32 IPAddress_part2,
                                                        ViPInt32 IPAddress_part3,
                                                        ViPInt32 IPAddress_part4,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATMipAadv (ViSession instrSession,
                                                        ViInt32 currentServiceOption,
                                                        ViBoolean MIPAgentAdvertisements,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATMipRrc (ViSession instrSession,
                                                       ViInt32 currentServiceOption,
                                                       ViInt32 codeNo,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATMipRrlt (ViSession instrSession,
                                                        ViInt32 currentServiceOption,
                                                        ViReal64 time,
                                                        ViChar _VI_FAR errorMessage[]);

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATMipAuth (ViSession instrSession,
                                                        ViInt32 currentServiceOption,
                                                        ViInt32 authenticationType,
                                                        ViChar _VI_FAR errorMessage[]);

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATSOption (ViSession instrSession,
                                                        ViInt32 currentServiceOption,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATFch (ViSession instrSession,
                                                    ViPInt32 f_RC, ViPInt32 f_MO,
                                                    ViPInt32 r_RC, ViPInt32 r_MO,
                                                    ViInt32 currentServiceOption,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATComFchRc (ViSession instrSession,
                                                         ViInt32 f_RC, ViInt32 r_RC,
                                                         ViInt32 currentServiceOption,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATSchIpad (ViSession instrSession,
                                                        ViInt32 IPAddress_part1,
                                                        ViInt32 IPAddress_part2,
                                                        ViInt32 IPAddress_part3,
                                                        ViInt32 IPAddress_part4,
                                                        ViInt32 trafficChannelDirection,
                                                        ViInt32 currentServiceOption,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATDynIpad (ViSession instrSession,
                                                        ViInt32 trafficChannelDirection,
                                                        ViInt32 currentServiceOption,
                                                        ViPInt32 IPAddress_part1,
                                                        ViPInt32 IPAddress_part2,
                                                        ViPInt32 IPAddress_part3,
                                                        ViPInt32 IPAddress_part4,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATAuthType (ViSession instrSession,
                                                         ViInt32 currentServiceOption,
                                                         ViInt32 type,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATAuthUnam (ViSession instrSession,
                                                         ViInt32 currentServiceOption,
                                                         ViString username,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATAuthPwor (ViSession instrSession,
                                                         ViInt32 currentServiceOption,
                                                         ViString password,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATAuthCint (ViSession instrSession,
                                                         ViInt32 currentServiceOption,
                                                         ViReal64 CHAPInterval,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATIacNiat (ViSession instrSession,
                                                        ViInt32 currentServiceOption,
                                                        ViBoolean state,
                                                        ViReal64 networkInactivityTimer,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATIacMsdc (ViSession instrSession,
                                                        ViInt32 currentServiceOption,
                                                        ViBoolean MSDormantControl,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATIacMsdt (ViSession instrSession,
                                                        ViInt32 currentServiceOption,
                                                        ViReal64 MSDormantTimer,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_InitSConfSclPDATIacSocm (ViSession instrSession,
                                                        ViInt32 currentServiceOption,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SensSConfSclPDATIacSOS (ViSession instrSession,
                                                       ViInt32 currentServiceOption,
                                                       ViPInt32 SOCtrlMessageState,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATPzonId (ViSession instrSession,
                                                       ViInt32 currentServiceOption,
                                                       ViInt32 packetZoneID,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATPzonTpds (ViSession instrSession,
                                                         ViInt32 currentServiceOption,
                                                         ViInt32 targetPDSN,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATPzonCctr (ViSession instrSession,
                                                         ViInt32 currentServiceOption,
                                                         ViInt32 packetZoneConnectControl,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATPzonLlen (ViSession instrSession,
                                                         ViInt32 currentServiceOption,
                                                         ViInt32 packetZoneListLength,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_InitSConfSclPDATPzonSocm (ViSession instrSession,
                                                         ViInt32 currentServiceOption,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SensSConfSclPDATPzonSOS (ViSession instrSession,
                                                        ViInt32 currentServiceOption,
                                                        ViPInt32 SOCtrlMessageState,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATSchZEn (ViSession instrSession,
                                                       ViBoolean SCH0Enable,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATZMppl (ViSession instrSession,
                                                      ViInt32 MPPL,
                                                      ViInt32 trafficChannelDirection,
                                                      ViInt32 currentServiceOption,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATZFType (ViSession instrSession,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViInt32 frameType,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATZCoding (ViSession instrSession,
                                                        ViInt32 coding,
                                                        ViInt32 trafficChannelDirection,
                                                        ViInt32 currentServiceOption,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATZDataR (ViSession instrSession,
                                                       ViPReal64 dataRate,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATSchZero (ViSession instrSession,
                                                        ViPInt32 f_RC,
                                                        ViPInt32 f_MO,
                                                        ViPInt32 r_RC,
                                                        ViPInt32 r_MO,
                                                        ViInt32 currentServiceOption,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATSchOEn (ViSession instrSession,
                                                       ViBoolean SCH1Enable,
                                                       ViInt32 currentServiceOption,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATOMppl (ViSession instrSession,
                                                      ViInt32 MPPL,
                                                      ViInt32 trafficChannelDirection,
                                                      ViInt32 currentServiceOption,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATOFType (ViSession instrSession,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViInt32 frameType,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATOCoding (ViSession instrSession,
                                                        ViInt32 coding,
                                                        ViInt32 trafficChannelDirection,
                                                        ViInt32 currentServiceOption,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATODataR (ViSession instrSession,
                                                       ViPReal64 dataRate,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATSchOne (ViSession instrSession,
                                                       ViPInt32 f_RC, ViPInt32 f_MO,
                                                       ViPInt32 r_RC, ViPInt32 r_MO,
                                                       ViInt32 currentServiceOption,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSconSclWMTSOpt (ViSession instrSession,
                                                   ViInt32 WMTServiceOption,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSconSclWMTSOption (ViSession instrSession,
                                                      ViPInt32 WMTCurrentSet,
                                                      ViChar _VI_FAR errorMessage[]);

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSconSclWMTSMSFile (ViSession instrSession,
                                                      ViInt32 file,
                                                      ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSconSclWMTSmsFilStat (ViSession instrSession,
                                                         ViInt32 *state,
                                                         ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSconSclWMTSmsFilLen (ViSession instrSession,
                                                        ViInt32 *outgoingLength,
                                                        ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSconSclWMTSmsLeng (ViSession instrSession,
                                                      ViInt32 maxOutgoingSMSLength,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSconSclWMTSmsText (ViSession instrSession,
                                                      ViChar _VI_FAR messageText[],
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSconSclWMTSmsAckEnab (ViSession instrSession,
                                                         ViInt32 acknowledgeFromMobile,
                                                         ViChar _VI_FAR errorMessage[]);

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSconSclWMTSMSHand (ViSession instrSession,
                                                      ViInt32 handle,
                                                      ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSconSclWMTSmsTSTEnab (ViSession instrSession,
                                                         ViInt32 timeStampOnOutgoingMessage,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclWMTFCH (ViSession instrSession,
                                                   ViInt32 serviceOption,
                                                   ViPInt32 f_RC, ViPInt32 f_MO,
                                                   ViPInt32 r_RC, ViPInt32 r_MO,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSconSclWMTFCHRC (ViSession instrSession,
                                                    ViInt32 serviceOption,
                                                    ViInt32 f_RC, ViInt32 r_RC,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSconSclWMTSMSFCHRC (ViSession instrSession,
                                                       ViInt32 serviceOption,
                                                       ViInt32 f_RC, ViInt32 r_RC,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcBSSRfChannel (ViSession instrSession,
                                                 ViInt32 channel,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcBSSRfFrequency (ViSession instrSession,
                                                   ViReal64 frequency_MHz,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcBSSRfPowCDMA (ViSession instrSession,
                                                 ViReal64 CDMAPower_dBm,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcBSSFFCHChannel (ViSession instrSession,
                                                   ViInt32 FFCHChannel,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcBSSFFCHLevel (ViSession instrSession,
                                                 ViReal64 FFCHLevel,
                                                 ViBoolean enable,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcBSSFFCHFrameOffset (ViSession instrSession,
                                                       ViInt32 FFCHFrameOffset,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcBSSQofFFCH (ViSession instrSession,
                                               ViInt32 QOF,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcBSSFSCHLevelZero (ViSession instrSession,
                                                     ViReal64 FSCHLevel,
                                                     ViBoolean enable,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcBSSFSCHChannelZero (ViSession instrSession,
                                                       ViInt32 FSCHChannel,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcBSSFSCHFrameOffZero (ViSession instrSession,
                                                        ViInt32 FSCHFrameOffset,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcBSSQofFSCHZero (ViSession instrSession,
                                                   ViInt32 QOF,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcBSSFSCHLevelOne (ViSession instrSession,
                                                    ViReal64 FSCHLevel,
                                                    ViBoolean enable,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcBSSFSCHChannelOne (ViSession instrSession,
                                                      ViInt32 FSCHChannel,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcBSSFSCHFrameOffOne (ViSession instrSession,
                                                       ViInt32 FSCHFrameOffset,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcBSSQofFSCHOne (ViSession instrSession,
                                                  ViInt32 QOF,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcBSSFPCHLevel (ViSession instrSession,
                                                 ViReal64 FPCHLevel,
                                                 ViBoolean enable,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcBSSFPCHChannel (ViSession instrSession,
                                                   ViInt32 FPCHChannel,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcBSSUsageFQPCH (ViSession instrSession,
                                                  ViBoolean QPCHUsage,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcBSSLevFQPCH (ViSession instrSession,
                                                ViReal64 QPCHLevel,
                                                ViBoolean enable,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcBSSChFQPCH (ViSession instrSession,
                                               ViInt32 quickPagingChannel,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcBSSIbitsFQPCH (ViSession instrSession,
                                                  ViInt32 indicatorBit,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcBSSDutPagingFQPCH (ViSession instrSession,
                                                      ViBoolean DUTPaging,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcBSSProPNOffset (ViSession instrSession,
                                                   ViInt32 PNOffset,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclService (ViSession instrSession,
                                                    ViInt32 service,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclLoopSOption (ViSession instrSession,
                                                        ViInt32 serviceOption,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclLoopFCH (ViSession instrSession,
                                                    ViPInt32 f_RC, ViPInt32 f_MO,
                                                    ViPInt32 r_RC, ViPInt32 r_MO,
                                                    ViInt32 serviceOption,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclLoopFCHRC (ViSession instrSession,
                                                      ViInt32 f_RC, ViInt32 r_RC,
                                                      ViInt32 serviceOption,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclLoopFCHFr (ViSession instrSession,
                                                      ViInt32 frameRate,
                                                      ViInt32 serviceOption,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclLoopPattern (ViSession instrSession,
                                                        ViChar _VI_FAR pattern[],
                                                        ViInt32 serviceOption,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclLoopPattGen (ViSession instrSession,
                                                        ViInt32 patternGeneration,
                                                        ViInt32 serviceOption,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclSpeechSOpt (ViSession instrSession,
                                                       ViInt32 serviceOption,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclSpeechFCH (ViSession instrSession,
                                                      ViPInt32 f_RC, ViPInt32 f_MO,
                                                      ViPInt32 r_RC, ViPInt32 r_MO,
                                                      ViInt32 serviceOption,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclSpeechFCHRC (ViSession instrSession,
                                                        ViInt32 f_RC, ViInt32 r_RC,
                                                        ViInt32 serviceOption,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATSOption (ViSession instrSession,
                                                        ViInt32 currentServiceOption,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATFch (ViSession instrSession,
                                                    ViPInt32 f_RC, ViPInt32 f_MO,
                                                    ViPInt32 r_RC, ViPInt32 r_MO,
                                                    ViInt32 currentServiceOption,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATComFchRc (ViSession instrSession,
                                                         ViInt32 f_RC, ViInt32 r_RC,
                                                         ViInt32 currentServiceOption,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATPattern (ViSession instrSession,
                                                        ViChar _VI_FAR pattern[],
                                                        ViInt32 trafficChannelDirection,
                                                        ViInt32 currentServiceOption,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATPattGen (ViSession instrSession,
                                                        ViInt32 patternGeneration,
                                                        ViInt32 trafficChannelDirection,
                                                        ViInt32 currentServiceOption,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATCBFrame (ViSession instrSession,
                                                        ViInt32 circularBufferFrames,
                                                        ViInt32 trafficChannelDirection,
                                                        ViInt32 currentServiceOption,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATTxon (ViSession instrSession,
                                                     ViInt32 transmitOnPeriod,
                                                     ViInt32 trafficChannelDirection,
                                                     ViInt32 currentServiceOption,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATTxoff (ViSession instrSession,
                                                      ViInt32 transmitOffPeriod,
                                                      ViInt32 trafficChannelDirection,
                                                      ViInt32 currentServiceOption,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATSchZEn (ViSession instrSession,
                                                       ViBoolean SCH0Enable,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATSchZero (ViSession instrSession,
                                                        ViPInt32 f_RC,
                                                        ViPInt32 f_MO,
                                                        ViPInt32 r_RC,
                                                        ViPInt32 r_MO,
                                                        ViInt32 currentServiceOption,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATZPattern (ViSession instrSession,
                                                         ViChar _VI_FAR pattern[],
                                                         ViInt32 trafficChannelDirection,
                                                         ViInt32 currentServiceOption,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATZPattGen (ViSession instrSession,
                                                         ViInt32 patternGeneration,
                                                         ViInt32 trafficChannelDirection,
                                                         ViInt32 currentServiceOption,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATZCBFrame (ViSession instrSession,
                                                         ViInt32 circularBufferFrames,
                                                         ViInt32 trafficChannelDirection,
                                                         ViInt32 currentServiceOption,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATZTxon (ViSession instrSession,
                                                      ViInt32 transmitOnPeriod,
                                                      ViInt32 trafficChannelDirection,
                                                      ViInt32 currentServiceOption,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATZTxoff (ViSession instrSession,
                                                       ViInt32 transmitOffPeriod,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATZDataR (ViSession instrSession,
                                                       ViPInt32 dataRate,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATOSchOn (ViSession instrSession,
                                                       ViBoolean SCH1Enable,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATOPattGn (ViSession instrSession,
                                                        ViInt32 patternGeneration,
                                                        ViInt32 trafficChannelDirection,
                                                        ViInt32 currentServiceOption,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATOPat (ViSession instrSession,
                                                     ViChar _VI_FAR pattern[],
                                                     ViInt32 trafficChannelDirection,
                                                     ViInt32 currentServiceOption,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATOCBFrm (ViSession instrSession,
                                                       ViInt32 circularBufferFrames,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATOTxon (ViSession instrSession,
                                                      ViInt32 transmitOnPeriod,
                                                      ViInt32 trafficChannelDirection,
                                                      ViInt32 currentServiceOption,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATOTxoff (ViSession instrSession,
                                                       ViInt32 transmitOffPeriod,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATODataR (ViSession instrSession,
                                                       ViPReal64 dataRate,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATOSch (ViSession instrSession,
                                                     ViPInt32 f_RC, ViPInt32 f_MO,
                                                     ViPInt32 r_RC, ViPInt32 r_MO,
                                                     ViInt32 currentServiceOption,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclPDATSOption (ViSession instrSession,
                                                        ViInt32 currentServiceOption,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclPDATFch (ViSession instrSession,
                                                    ViPInt32 f_RC, ViPInt32 f_MO,
                                                    ViPInt32 r_RC, ViPInt32 r_MO,
                                                    ViInt32 currentServiceOption,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclPDATComFchRc (ViSession instrSession,
                                                         ViInt32 f_RC, ViInt32 r_RC,
                                                         ViInt32 currentServiceOption,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclPDATSchZEn (ViSession instrSession,
                                                       ViBoolean SCH0Enable,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclPDATSchZero (ViSession instrSession,
                                                        ViPInt32 f_RC,
                                                        ViPInt32 f_MO,
                                                        ViPInt32 r_RC,
                                                        ViPInt32 r_MO,
                                                        ViInt32 currentServiceOption,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclPDATZDataR (ViSession instrSession,
                                                       ViPReal64 dataRate,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclPDATSchOEn (ViSession instrSession,
                                                       ViBoolean SCH1Enable,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclPDATSchOne (ViSession instrSession,
                                                       ViPInt32 f_RC, ViPInt32 f_MO,
                                                       ViPInt32 r_RC, ViPInt32 r_MO,
                                                       ViInt32 currentServiceOption,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclPDATODataR (ViSession instrSession,
                                                       ViPReal64 dataRate,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_Handoff (ViSession originatingHandle,
                                        ViSession destinationHandle, ViInt32 target,
                                        ViInt32 timeout,
                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SenseMSInfo (ViSession instrSession,
                                            ViPInt32 protocal_revision,
                                            ViChar _VI_FAR MCC[],
                                            ViChar _VI_FAR NMSI[],
                                            ViChar _VI_FAR ESN[],
                                            ViChar _VI_FAR EIRP[],
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SenseMSInfoPrev (ViSession instrSession,
                                                ViPInt32 protocal_revision,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SenseMSInfoBCLSupport (ViSession instrSession,
                                                      ViInt32 _VI_FAR bandClass[],
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SenseMSInfoSCLSupport (ViSession instrSession,
                                                      ViInt32 _VI_FAR subClass[],
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SenseMSInfoTerminal (ViSession instrSession,
                                                    ViPInt32 manufacturerCode,
                                                    ViPInt32 modelNumber,
                                                    ViPInt32 firmwareRevision,
                                                    ViPInt32 localControl,
                                                    ViChar _VI_FAR serOption[],
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SenseMSInfoAuth (ViSession instrSession,
                                                ViPInt32 authenticMode,
                                                ViChar _VI_FAR authenticResponse[],
                                                ViPInt32 RANDC,
                                                ViPInt32 callHistoryCount,
                                                ViChar _VI_FAR errorMessage[]);

ViStatus _VI_FUNC RSCMU_CDMA2K_SenseMSInfoMeid (ViSession instrSession,
                                                ViChar MEID[],
                                                ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_CDMA2K_ConnInfoDialedNumber (ViSession instrSession,
                                                     ViChar _VI_FAR dialedNumber[],
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConnInfoGlobalECall (ViSession instrSession,
                                                    ViPInt32 globalEmergencyNumber,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConnInfoServiceOption (ViSession instrSession,
                                                      ViPInt32 number_ofConnectedSO,
                                                      ViChar _VI_FAR SOName[],
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConnInfoFCHMUXOption (ViSession instrSession,
                                                     ViChar _VI_FAR connectedFwdMUXOption[],
                                                     ViChar _VI_FAR connectedRevMUXOption[],
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConnInfoSCHZeroMUXOpt (ViSession instrSession,
                                                      ViChar _VI_FAR connectedFwdMUXOption[],
                                                      ViChar _VI_FAR connectedRevMUXOption[],
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConnInfoFCHRC (ViSession instrSession,
                                              ViPInt32 connectedFwdRC,
                                              ViPInt32 connectredRevRC,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConnInfoSCHRC (ViSession instrSession,
                                              ViPInt32 connectedFwdRC,
                                              ViPInt32 connectredRevRC,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SenMINFSmsLoutTSTA (ViSession instrSession,
                                                   ViChar _VI_FAR lastOutgoingTimeStamp[],
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SenMINFSmsLoutACKN (ViSession instrSession,
                                                   ViPInt32 lastOutgoingAcknowledge,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_MINFSmsLoutCCOD (ViSession instrSession,
                                                ViPInt32 lastOutgoingCauseCode,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_MINFSmsLrecTSTA (ViSession instrSession,
                                                ViChar _VI_FAR lastReceivedTimeStamp[],
                                                ViChar _VI_FAR errorMessage[]);

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSconSclWMTSmsFilEnc (ViSession instrSession,
                                                        ViInt32 *outgoingEncoding,
                                                        ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSconSclWMTSmsFilText (ViSession instrSession,
                                                         ViChar outgoingText[],
                                                         ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSconSclWMTSmsIncSav (ViSession instrSession,
                                                        ViBoolean incomingSMSSave,
                                                        ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSconSclWMTSmsIncAinc (ViSession instrSession,
                                                         ViBoolean increment,
                                                         ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSconSclWMTSmsIncLast (ViSession instrumentHandle,
                                                         ViInt32 arraySize,
                                                         ViChar lastSavedSMS[],
                                                         ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_CDMA2K_MINFSmsLrecTEX (ViSession instrSession,
                                               ViChar _VI_FAR lastReceivedText[],
                                               ViChar _VI_FAR errorMessage[]);

ViStatus _VI_FUNC RSCMU_CDMA2K_MINFSmsLrecENC (ViSession instrSession,
                                               ViInt32 *lastReceivedEncoding,
                                               ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_CDMA2K_MINFSmsLrecLEN (ViSession instrSession,
                                               ViInt32 *lastReceivedLength,
                                               ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_CDMA2K_DefIpad (ViSession instrSession,
                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfIpadMode (ViSession instrSession,
                                             ViInt32 addressing,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfIpadStat (ViSession instrSession,
                                             ViInt32 IPAddress_part1,
                                             ViInt32 IPAddress_part2,
                                             ViInt32 IPAddress_part3,
                                             ViInt32 IPAddress_part4,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSmasStat (ViSession instrSession,
                                             ViInt32 mask_part1, ViInt32 mask_part2,
                                             ViInt32 mask_part3, ViInt32 mask_part4,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfDgatStat (ViSession instrSession,
                                             ViInt32 IPAddress_part1,
                                             ViInt32 IPAddress_part2,
                                             ViInt32 IPAddress_part3,
                                             ViInt32 IPAddress_part4,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfHnamDyn (ViSession instrSession,
                                            ViString host_name,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SensIpadDynFcod (ViSession instrSession,
                                                ViPInt32 failureCode,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfDNSDyn (ViSession instrSession,
                                           ViPInt32 IPAddress_part1,
                                           ViPInt32 IPAddress_part2,
                                           ViPInt32 IPAddress_part3,
                                           ViPInt32 IPAddress_part4,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfIpadDyn (ViSession instrSession,
                                            ViPInt32 IPAddress_part1,
                                            ViPInt32 IPAddress_part2,
                                            ViPInt32 IPAddress_part3,
                                            ViPInt32 IPAddress_part4,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSmasDyn (ViSession instrSession,
                                            ViPInt32 mask_part1,
                                            ViPInt32 mask_part2,
                                            ViPInt32 mask_part3,
                                            ViPInt32 mask_part4,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfDgatDyn (ViSession instrSession,
                                            ViPInt32 IPAddress_part1,
                                            ViPInt32 IPAddress_part2,
                                            ViPInt32 IPAddress_part3,
                                            ViPInt32 IPAddress_part4,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfMenuCctriAop (ViSession instrSession,
                                                 ViBoolean open_autom_if_not_connected,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfMenuCctriAcl (ViSession instrSession,
                                                 ViBoolean close_autom_if_not_connected,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfEsyncMode (ViSession instrSession,
                                              ViInt32 syncMode,
                                              ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfEsyncTimeout (ViSession instrSession,
                                                 ViReal64 syncTimeout,
                                                 ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_InitEsync (ViSession instrSession,
                                          ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SensEsyncState (ViSession instrSession,
                                               ViInt32 *syncState,
                                               ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_CDMA2K_InitEsyncSystTime (ViSession instrSession,
                                                  ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_CDMA2K_SensEsyncSystTimeState (ViSession instrSession,
                                                       ViInt32 *systemTimeState,
                                                       ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfEsyncAlign (ViSession instrSession,
                                               ViInt32 alignWithEvent,
                                               ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_CDMA2K_XtndPowMioResNban (ViSession instrumentHandle_CDMA,
                                                  ViBoolean enable,
                                                  ViChar errorMessage[]);


ViStatus _VI_FUNC RSCMU_CDMA2K_Close (ViSession instrSession_CDMA,
                                      ViChar _VI_FAR errorMessage[]);

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSystemTime (ViSession instrSession,
                                               ViInt32 month, ViInt32 day,
                                               ViInt32 year, ViInt32 hours,
                                               ViInt32 minutes, ViInt32 seconds,
                                               ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRFS (ViSession instrSession,
                                        ViInt32 RFSelectivity,
                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2k_MmemSaveCurr (ViSession instrSession,
                                             ViChar _VI_FAR fileName[],
                                             ViInt32 storageDevice,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2k_MmemRecCurr (ViSession instrSession,
                                            ViChar _VI_FAR fileName[],
                                            ViInt32 storageDevice,
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2k_SysVerSwMMI (ViSession instrSession,
                                            ViChar _VI_FAR MMIVersionString[],
                                            ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_AbortALL (ViSession instrSession,
                                         ViInt32 abortAllApplications,
                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_Reset (ViSession instrSession,
                                      ViUInt32 MAXTimeout_in_ms,
                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_GPIB_Timeout (ViSession instrSession,
                                             ViUInt32 timeout_in_ms,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SetCmuVersion (ViSession instrSession,
                                              ViChar _VI_FAR CMUVersion[],
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA_errorMessage (ViSession instrSession,
                                           ViStatus errorCode,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_StatOperSymbEnab (ViSession instrSession,
                                                 ViBoolean CFM, ViBoolean RFM,
                                                 ViBoolean LORL, ViBoolean MREG,
                                                 ViBoolean MINV, ViBoolean AMES,
                                                 ViBoolean RFNS, ViBoolean MDER,
                                                 ViBoolean RMES, ViBoolean FCH,
                                                 ViBoolean PREP, ViBoolean RFIO,
                                                 ViBoolean RFIU,
                                                 ViBoolean XTND,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_StatOperSymbEvent (ViSession instrSession,
                                                  ViPInt32 nbreEvent,
                                                  ViPInt32 statusOperEvent,
                                                  ViChar _VI_FAR eventList[],
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_XtndStatOperFgrEvent (ViSession instrSession,
                                                     ViPInt32 statusOperEvent,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_XtndStatOperSymbEvent (ViSession instrSession,
                                                      ViInt32 _VI_FAR list_ofReportedEvents[],
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SetMeasEnvironment (ViSession instrSession,
                                                   ViBoolean measureEnvironment,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadModMQuality_EX (ViSession instrSession,
                                                   ViReal64 _VI_FAR msPower[],
                                                   ViReal64 _VI_FAR waveFormQuality[],
                                                   ViReal64 _VI_FAR carrierFrequencyError[],
                                                   ViReal64 _VI_FAR transmitTimeError[],
                                                   ViReal64 _VI_FAR carrierFeedThrough[],
                                                   ViReal64 _VI_FAR sidebandSuppressLower[],
                                                   ViReal64 _VI_FAR sidebandSuppressUpper[],
                                                   ViReal64 _VI_FAR meas_out_ofTolerance[],
                                                   ViInt32 signalType,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchModMQuality_EX (ViSession instrSession,
                                                    ViReal64 _VI_FAR msPower[],
                                                    ViReal64 _VI_FAR waveFormQuality[],
                                                    ViReal64 _VI_FAR carrierFrequencyError[],
                                                    ViReal64 _VI_FAR transmitTimeError[],
                                                    ViReal64 _VI_FAR carrierFeedThrough[],
                                                    ViReal64 _VI_FAR sidebandSuppressLower[],
                                                    ViReal64 _VI_FAR sidebandSuppressUpper[],
                                                    ViReal64 _VI_FAR meas_out_ofTolerance[],
                                                    ViInt32 signalType,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SampleModMQuality_EX (ViSession instrSession,
                                                     ViReal64 _VI_FAR msPower[],
                                                     ViReal64 _VI_FAR waveFormQuality[],
                                                     ViReal64 _VI_FAR carrierFrequencyError[],
                                                     ViReal64 _VI_FAR transmitTimeError[],
                                                     ViReal64 _VI_FAR carrierFeedThrough[],
                                                     ViReal64 _VI_FAR sidebandSuppressLower[],
                                                     ViReal64 _VI_FAR sidebandSuppressUpper[],
                                                     ViReal64 _VI_FAR meas_out_ofTolerance[],
                                                     ViInt32 signalType,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcModMQualMatcLim_EX (ViSession instrSession,
                                                       ViReal64 _VI_FAR waveFormQuality[],
                                                       ViReal64 _VI_FAR carrierFrequencyError[],
                                                       ViReal64 _VI_FAR transmitTimeError[],
                                                       ViReal64 _VI_FAR carrierFeedThrough[],
                                                       ViReal64 _VI_FAR sidebandSuppressLower[],
                                                       ViReal64 _VI_FAR sidebandSuppressUpper[],
                                                       ViInt32 signalType,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadScalCDPowCDPW_EX (ViSession instrSession,
                                                     ViReal64 _VI_FAR MSPower[],
                                                     ViReal64 _VI_FAR carrierFeedThrough[],
                                                     ViReal64 _VI_FAR frequencyError[],
                                                     ViReal64 _VI_FAR rho[],
                                                     ViPReal64 outOfTolerance,
                                                     ViPInt32 currentStatistics,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchScalCDPowCDPW_EX (ViSession instrSession,
                                                      ViReal64 _VI_FAR MSPower[],
                                                      ViReal64 _VI_FAR carrierFeedThrough[],
                                                      ViReal64 _VI_FAR frequencyError[],
                                                      ViReal64 _VI_FAR rho[],
                                                      ViPReal64 outOfTolerance,
                                                      ViPInt32 currentStatistics,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SampleScalCDPowCDPW_EX (ViSession instrSession,
                                                       ViReal64 _VI_FAR MSPower[],
                                                       ViReal64 _VI_FAR carrierFeedThrough[],
                                                       ViReal64 _VI_FAR frequencyError[],
                                                       ViReal64 _VI_FAR rho[],
                                                       ViPReal64 outOfTolerance,
                                                       ViPInt32 currentStatistics,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcScalCDPWMatcLim_EX (ViSession instrSession,
                                                       ViReal64 _VI_FAR carrierFeedThrough[],
                                                       ViReal64 _VI_FAR frequencyError[],
                                                       ViReal64 _VI_FAR rho[],
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadScalCDPowPCDEP_EX (ViSession instrSession,
                                                      ViReal64 _VI_FAR MSPower[],
                                                      ViReal64 _VI_FAR carrierFeedThrough[],
                                                      ViReal64 _VI_FAR frequencyError[],
                                                      ViReal64 _VI_FAR rho[],
                                                      ViPReal64 outOfTolerance,
                                                      ViPInt32 currentStatistics,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchScalCDPowPCDEP_EX (ViSession instrSession,
                                                       ViReal64 _VI_FAR MSPower[],
                                                       ViReal64 _VI_FAR carrierFeedThrough[],
                                                       ViReal64 _VI_FAR frequencyError[],
                                                       ViReal64 _VI_FAR rho[],
                                                       ViPReal64 outOfTolerance,
                                                       ViPInt32 currentStatistics,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SampleScalCDPowPCDEP_EX (ViSession instrSession,
                                                        ViReal64 _VI_FAR MSPower[],
                                                        ViReal64 _VI_FAR carrierFeedThrough[],
                                                        ViReal64 _VI_FAR frequencyError[],
                                                        ViReal64 _VI_FAR rho[],
                                                        ViPReal64 outOfTolerance,
                                                        ViPInt32 currentStatistics,
                                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcScalPCDEPMatLim_EX (ViSession instrSession,
                                                       ViReal64 _VI_FAR carrierFeedThrough[],
                                                       ViReal64 _VI_FAR frequencyError[],
                                                       ViReal64 _VI_FAR rho[],
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadScalCDPowCHPW_EX (ViSession instrSession,
                                                     ViReal64 _VI_FAR MSPower[],
                                                     ViReal64 _VI_FAR carrierFeedThrough[],
                                                     ViReal64 _VI_FAR frequencyError[],
                                                     ViReal64 _VI_FAR rho[],
                                                     ViPReal64 outOfTolerance,
                                                     ViPInt32 currentStatistics,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchScalCDPowCHPW_EX (ViSession instrSession,
                                                      ViReal64 _VI_FAR MSPower[],
                                                      ViReal64 _VI_FAR carrierFeedThrough[],
                                                      ViReal64 _VI_FAR frequencyError[],
                                                      ViReal64 _VI_FAR rho[],
                                                      ViPReal64 outOfTolerance,
                                                      ViPInt32 currentStatistics,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SampleScalCDPowCHPW_EX (ViSession instrSession,
                                                       ViReal64 _VI_FAR MSPower[],
                                                       ViReal64 _VI_FAR carrierFeedThrough[],
                                                       ViReal64 _VI_FAR frequencyError[],
                                                       ViReal64 _VI_FAR rho[],
                                                       ViPReal64 outOfTolerance,
                                                       ViPInt32 currentStatistics,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcScalCHPWMatcLim_EX (ViSession instrSession,
                                                       ViReal64 _VI_FAR carrierFeedThrough[],
                                                       ViReal64 _VI_FAR frequencyError[],
                                                       ViReal64 _VI_FAR rho[],
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadOverview_EX (ViSession handle,
                                                ViReal64 _VI_FAR expected_Power[],
                                                ViReal64 _VI_FAR MSPower[],
                                                ViReal64 _VI_FAR freqErr[],
                                                ViReal64 _VI_FAR carrier_Freq[],
                                                ViReal64 _VI_FAR timeErr[],
                                                ViReal64 _VI_FAR RHO[],
                                                ViReal64 _VI_FAR ACPLow[],
                                                ViReal64 _VI_FAR ACPUp[],
                                                ViInt32 mode,
                                                ViChar _VI_FAR errMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchOverview_EX (ViSession handle,
                                                 ViReal64 _VI_FAR expected_Power[],
                                                 ViReal64 _VI_FAR MSPower[],
                                                 ViReal64 _VI_FAR freqErr[],
                                                 ViReal64 _VI_FAR carrier_Freq[],
                                                 ViReal64 _VI_FAR timeErr[],
                                                 ViReal64 _VI_FAR RHO[],
                                                 ViReal64 _VI_FAR ACPLow[],
                                                 ViReal64 _VI_FAR ACPUp[],
                                                 ViInt32 mode,
                                                 ViChar _VI_FAR errMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SampleOverview_EX (ViSession handle,
                                                  ViReal64 _VI_FAR expected_Power[],
                                                  ViReal64 _VI_FAR MSPower[],
                                                  ViReal64 _VI_FAR freqErr[],
                                                  ViReal64 _VI_FAR carrier_Freq[],
                                                  ViReal64 _VI_FAR timeErr[],
                                                  ViReal64 _VI_FAR RHO[],
                                                  ViReal64 _VI_FAR ACPLow[],
                                                  ViReal64 _VI_FAR ACPUp[],
                                                  ViInt32 mode,
                                                  ViChar _VI_FAR errMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcOverviewMatcLim_EX (ViSession instrSession,
                                                       ViReal64 _VI_FAR carrierFreqError[],
                                                       ViReal64 _VI_FAR txTimeError[],
                                                       ViReal64 _VI_FAR waveFormQuality[],
                                                       ViReal64 _VI_FAR ACPSBLow[],
                                                       ViReal64 _VI_FAR ACPSBUp[],
                                                       ViInt32 signalType,
                                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadMod_Overview_Ex (ViSession instrSession,
                                                    ViReal64 _VI_FAR EVM[],
                                                    ViReal64 _VI_FAR magnError[],
                                                    ViReal64 _VI_FAR phaseError[],
                                                    ViReal64 _VI_FAR carrierFeedthrough[],
                                                    ViReal64 _VI_FAR IQImbalance[],
                                                    ViReal64 _VI_FAR frequencyError[],
                                                    ViReal64 _VI_FAR transmitTimeError[],
                                                    ViReal64 _VI_FAR waveformQuality[],
                                                    ViReal64 _VI_FAR MSPower[],
                                                    ViPInt32 measCount,
                                                    ViPReal64 measOutOfTolerance,
                                                    ViInt32 signalType,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchMod_Overview_Ex (ViSession instrSession,
                                                     ViReal64 _VI_FAR EVM[],
                                                     ViReal64 _VI_FAR magnError[],
                                                     ViReal64 _VI_FAR phaseError[],
                                                     ViReal64 _VI_FAR carrierFeedthrough[],
                                                     ViReal64 _VI_FAR IQImbalance[],
                                                     ViReal64 _VI_FAR frequencyError[],
                                                     ViReal64 _VI_FAR transmitTimeError[],
                                                     ViReal64 _VI_FAR waveformQuality[],
                                                     ViReal64 _VI_FAR MSPower[],
                                                     ViPInt32 measCount,
                                                     ViPReal64 measOutOfTolerance,
                                                     ViInt32 signalType,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SampleMod_Overview_Ex (ViSession instrSession,
                                                      ViReal64 _VI_FAR EVM[],
                                                      ViReal64 _VI_FAR magnError[],
                                                      ViReal64 _VI_FAR phaseError[],
                                                      ViReal64 _VI_FAR carrierFeedthrough[],
                                                      ViReal64 _VI_FAR IQImbalance[],
                                                      ViReal64 _VI_FAR frequencyError[],
                                                      ViReal64 _VI_FAR transmitTimeError[],
                                                      ViReal64 _VI_FAR waveformQuality[],
                                                      ViReal64 _VI_FAR MSPower[],
                                                      ViPInt32 measCount,
                                                      ViPReal64 measOutOfTolerance,
                                                      ViInt32 signalType,
                                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcMod_Overview_Ex (ViSession instrSession,
                                                    ViReal64 _VI_FAR EVM[],
                                                    ViReal64 _VI_FAR magnError[],
                                                    ViReal64 _VI_FAR phaseError[],
                                                    ViReal64 _VI_FAR carrierFeedthrough[],
                                                    ViReal64 _VI_FAR IQImbalance[],
                                                    ViReal64 _VI_FAR frequencyError[],
                                                    ViReal64 _VI_FAR transmitTimeError[],
                                                    ViReal64 _VI_FAR waveformQuality[],
                                                    ViReal64 _VI_FAR MSPower[],
                                                    ViInt32 signalType,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadMod_Error_Ex (ViSession instrSession,
                                                 ViReal64 _VI_FAR peak[],
                                                 ViReal64 _VI_FAR RMS[],
                                                 ViReal64 _VI_FAR carrierFeedthrough[],
                                                 ViReal64 _VI_FAR IQImbalance[],
                                                 ViReal64 _VI_FAR freqError[],
                                                 ViReal64 _VI_FAR transmitTimeError[],
                                                 ViReal64 _VI_FAR waveformQuality[],
                                                 ViReal64 _VI_FAR MSPower[],
                                                 ViPInt32 measCount,
                                                 ViPReal64 measOutOfTolerance,
                                                 ViInt32 type, ViInt32 signalType,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchMod_Error_Ex (ViSession instrSession,
                                                  ViReal64 _VI_FAR peak[],
                                                  ViReal64 _VI_FAR RMS[],
                                                  ViReal64 _VI_FAR carrierFeedthrough[],
                                                  ViReal64 _VI_FAR IQImbalance[],
                                                  ViReal64 _VI_FAR freqError[],
                                                  ViReal64 _VI_FAR transmitTimeError[],
                                                  ViReal64 _VI_FAR waveformQuality[],
                                                  ViReal64 _VI_FAR MSPower[],
                                                  ViPInt32 measCount,
                                                  ViPReal64 measOutOfTolerance,
                                                  ViInt32 type, ViInt32 signalType,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SampleMod_Error_Ex (ViSession instrSession,
                                                   ViReal64 _VI_FAR peak[],
                                                   ViReal64 _VI_FAR RMS[],
                                                   ViReal64 _VI_FAR carrierFeedthrough[],
                                                   ViReal64 _VI_FAR IQImbalance[],
                                                   ViReal64 _VI_FAR freqError[],
                                                   ViReal64 _VI_FAR transmitTimeError[],
                                                   ViReal64 _VI_FAR waveformQuality[],
                                                   ViReal64 _VI_FAR MSPower[],
                                                   ViPInt32 measCount,
                                                   ViPReal64 measOutOfTolerance,
                                                   ViInt32 type, ViInt32 signalType,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcMod_Error_Ex (ViSession instrSession,
                                                 ViReal64 _VI_FAR peak[],
                                                 ViReal64 _VI_FAR RMS[],
                                                 ViReal64 _VI_FAR carrierFeedthrough[],
                                                 ViReal64 _VI_FAR IQImbalance[],
                                                 ViReal64 _VI_FAR freqError[],
                                                 ViReal64 _VI_FAR transmitTimeError[],
                                                 ViReal64 _VI_FAR waveformQuality[],
                                                 ViReal64 _VI_FAR MSPower[],
                                                 ViInt32 type, ViInt32 signalType,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadRQFpc_Ex (ViSession instrSession,
                                             ViPReal64 actualOutputPower,
                                             ViReal64 _VI_FAR FER[],
                                             ViInt32 _VI_FAR frameError[],
                                             ViInt32 _VI_FAR transmitFrame[],
                                             ViReal64 _VI_FAR confidence_level[],
                                             ViReal64 _VI_FAR adjustLevel[],
                                             ViReal64 _VI_FAR fwdChannelLevel[],
                                             ViReal64 _VI_FAR currentSetPoint[],
                                             ViReal64 _VI_FAR BSCalEbNt[],
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetcRQFpc_Ex (ViSession instrSession,
                                             ViPReal64 actualOutputPower,
                                             ViReal64 _VI_FAR FER[],
                                             ViInt32 _VI_FAR frameError[],
                                             ViInt32 _VI_FAR transmitFrame[],
                                             ViReal64 _VI_FAR confidence_level[],
                                             ViReal64 _VI_FAR adjustLevel[],
                                             ViReal64 _VI_FAR fwdChannelLevel[],
                                             ViReal64 _VI_FAR currentSetPoint[],
                                             ViReal64 _VI_FAR BSCalEbNt[],
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SampRQFpc_Ex (ViSession instrSession,
                                             ViPReal64 actualOutputPower,
                                             ViReal64 _VI_FAR FER[],
                                             ViInt32 _VI_FAR frameError[],
                                             ViInt32 _VI_FAR transmitFrame[],
                                             ViReal64 _VI_FAR confidence_level[],
                                             ViReal64 _VI_FAR adjustLevel[],
                                             ViReal64 _VI_FAR fwdChannelLevel[],
                                             ViReal64 _VI_FAR currentSetPoint[],
                                             ViReal64 _VI_FAR BSCalEbNt[],
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfMMONIPAddress (ViSession instrSession,
                                                  ViInt32 IPAddress1,
                                                  ViInt32 IPAddress2,
                                                  ViInt32 IPAddress3,
                                                  ViInt32 IPAddress4,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfMMONSmask (ViSession instrSession,
                                              ViInt32 IPAddress1,
                                              ViInt32 IPAddress2,
                                              ViInt32 IPAddress3,
                                              ViInt32 IPAddress4,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfMMONSgateway (ViSession instrSession,
                                                 ViInt32 IPAddress1,
                                                 ViInt32 IPAddress2,
                                                 ViInt32 IPAddress3,
                                                 ViInt32 IPAddress4,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_DefMMON (ViSession instrSession,
                                        ViInt32 defaultMessageMointorSetting,
                                        ViChar _VI_FAR errorMessage[]);

                                           
// For LabVIEW support
ViStatus _VI_FUNC RSCMU_CDMA2K_GetResourceName (ViSession instrSession,
                                              ViSession instrSessionBase,
                                              ViChar _VI_FAR sessionName[]);

#ifndef _REMVXIPNP

ViStatus _VI_FUNC RSCMU_GetInstrumentHandle (ViSession instrSession,
                                             ViSession *instrHandle);
ViStatus _VI_FUNC RSCMU_initCDMA2K (ViSession, ViSession, ViUInt32);
ViStatus _VI_FUNC RSCMU_init (ViRsrc, ViBoolean, ViBoolean, ViPSession);
ViStatus _VI_FUNC RSCMU_reset (ViSession);    
ViStatus _VI_FUNC RSCMU_self_test (ViSession, ViPInt16, ViChar[]);
ViStatus _VI_FUNC RSCMU_error_query (ViSession, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_error_message (ViSession, ViStatus, ViChar[]);
ViStatus _VI_FUNC RSCMU_revision_query (ViSession, ViChar[], ViChar[]);
ViStatus _VI_FUNC RSCMU_close (ViSession);

#endif

#ifdef _OUTSIDEVEE_
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadMod (ViSession instrSession,
                                  ERROR_MOD *Modulation,
                                  OVERVIEW *Overview, 
                                  ViInt32 type,
                                  ViInt32 signaltype, 
                                  ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchMod (ViSession instrSession,
                                   ERROR_MOD *Modulation,
                                   OVERVIEW *Overview, ViInt32 type,
                                   ViInt32 signaltype, ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SampleMod (ViSession instrSession,
                                    ERROR_MOD *Modulation,   
                                    OVERVIEW *Overview, ViInt32 type,
                                    ViInt32 signaltype, ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcModMatcLim (ViSession instrSession,
                                         ERROR_MOD *Modulation,
                                         OVERVIEW *Overview, ViInt32 type,
                                         ViInt32 signaltype,
                                         ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadScalCDPowPCDEP (ViSession instrSession,
                                                    CODE_DOMAIN_POWER *CDPW,
                                                ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchScalCDPowPCDEP (ViSession instrSession, 
                                                    CODE_DOMAIN_POWER *CDPW,
                                                     ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SampleScalCDPowPCDEP (ViSession instrSession,  
                                                    CODE_DOMAIN_POWER *CDPW,
                                                     ViChar errorMessage[]); 
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcScalCDPowPCDEPMatLim (ViSession instrSession,  
                                                        CODE_DOMAIN_POWER *CDPW,
                                                        ViChar errorMessage[]); 
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadScalCDPowCHPW (ViSession instrSession, 
                                                    CODE_DOMAIN_POWER *CDPW,
                                                    ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchScalCDPowCHPW (ViSession instrSession, 
                                                    CODE_DOMAIN_POWER *CDPW,
                                                    ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SampleScalCDPowCHPW (ViSession instrSession, 
                                                    CODE_DOMAIN_POWER *CDPW,
                                                    ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcScalCDPowCHPWMatcLim (ViSession instrSession,
                                                        CODE_DOMAIN_POWER *CDPW,
                                                          ViChar errorMessage[]);   
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadScalCDPowCDPW (ViSession instrSession,   
                                                  CODE_DOMAIN_POWER *CDPW,
                                                  ViChar errorMessage[]);   
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchScalCDPowCDPW (ViSession instrSession,  
                                                  CODE_DOMAIN_POWER *CDPW,
                                                  ViChar errorMessage[]);   
ViStatus _VI_FUNC RSCMU_CDMA2K_SampleScalCDPowCDPW (ViSession instrSession, 
                                                  CODE_DOMAIN_POWER *CDPW,
                                                  ViChar errorMessage[]);   
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcScalCDPowCDPWMatcLim (ViSession instrSession,  
                                                         CODE_DOMAIN_POWER *CDPW,
                                                         ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadModMQuality (ViSession instrSession,
                                                ModQualOver *modulationValue,
                                                ViInt32 signalType,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchModMQuality (ViSession instrSession,
                                                 ModQualOver *modulationValue,
                                                 ViInt32 signalType,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SampleModMQuality (ViSession instrSession,
                                                  ModQualOver *modulationValue,
                                                  ViInt32 signalType,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcModMQualMatcLim (ViSession instrSession,
                                                    ModQualOver *modulationValue,
                                                    ViInt32 signalType,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadScalCDPowCDPW (ViSession instrSession,
                                                  CODE_DOMAIN_POWER *codeDomainPower,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchScalCDPowCDPW (ViSession instrSession,
                                                   CODE_DOMAIN_POWER *codeDomainPower,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SampleScalCDPowCDPW (ViSession instrSession,
                                                    CODE_DOMAIN_POWER *codeDomainPower,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcScalCDPowCDPWMatcLim (ViSession instrSession,
                                                         CODE_DOMAIN_POWER *matchingLimit,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadScalCDPowPCDEP (ViSession instrSession,
                                                   CODE_DOMAIN_POWER *peakCodeDomainErrorPower,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchScalCDPowPCDEP (ViSession instrSession,
                                                    CODE_DOMAIN_POWER *peakCodeDomainErrorPower,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SampleScalCDPowPCDEP (ViSession instrSession,
                                                     CODE_DOMAIN_POWER *peakCodeDomainErrorPower,
                                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcScalCDPowPCDEPMatLim (ViSession instrSession,
                                                         CODE_DOMAIN_POWER *peakCodeDomainErrorPower,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadScalCDPowCHPW (ViSession instrSession,
                                                  CODE_DOMAIN_POWER *channelPowerOutput,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchScalCDPowCHPW (ViSession instrSession,
                                                   CODE_DOMAIN_POWER *channelPowerOutput,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SampleScalCDPowCHPW (ViSession instrSession,
                                                    CODE_DOMAIN_POWER *channelPowerOutput,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcScalCDPowCHPWMatcLim (ViSession instrSession,
                                                         CODE_DOMAIN_POWER *matchingLimit,
                                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadOverview (ViSession instrSession,
                                             ViInt32 signalType,
                                             OVERVIEW_C2K *overview,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchOverview (ViSession instrSession,
                                              ViInt32 signalType,
                                              OVERVIEW_C2K *overview,
                                              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SampleOverview (ViSession instrSession,
                                               ViInt32 signalType,
                                               OVERVIEW_C2K *overview,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcOverviewMatcLim (ViSession instrSession,
                                                    ViInt32 signalType,
                                                    OVERVIEW_C2K *overview,
                                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadMod (ViSession instrSession,
                                        ERROR_MOD *errorModulation,
                                        OVERVIEW *overview, ViInt32 type,
                                        ViInt32 signalType,
                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchMod (ViSession instrSession,
                                         ERROR_MOD *errorModulation,
                                         OVERVIEW *overview, ViInt32 type,
                                         ViInt32 signalType,
                                         ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SampleMod (ViSession instrSession,
                                          ERROR_MOD *errorModulation,
                                          OVERVIEW *overview, ViInt32 type,
                                          ViInt32 signalType,
                                          ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcModMatcLim (ViSession instrSession,
                                               ERROR_MOD *errorModulation,
                                               OVERVIEW *overview, ViInt32 type,
                                               ViInt32 signalType,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadRQFpc (ViSession instrSession,
                                          tFPC *outputData,
                                          ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchRQFpc (ViSession instrSession,
                                           tFPC *outputData,
                                           ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_CDMA2K_SampleRQFpc (ViSession instrSession,
                                            tFPC *outputData,
                                            ViChar _VI_FAR errorMessage[]);

#endif

#ifdef __cplusplus
    }
#endif
#endif  // _RSCMUC2K_H_


